// This file is generated with "update_icon_font.py" from FontAwesome's metadata.
#pragma once

struct Icon {
    unsigned short unicode;
    bool isBrand;
    const char *searchTerms;
};

constexpr Icon iconList[] = {
{0x30, false, "0|0|digit zero|nada|nil|none|nothing|nought|null|number zero|zero|zilch"},
{0x31, false, "1|1|digit one|first|number one|numeral one|one|primary|single|unit"},
{0x32, false, "2|2|digit two|number two|numeral 2|numeric two|second|two"},
{0x33, false, "3|3|digit three|number three|numeral three|third|three|triad|trio"},
{0x34, false, "4|4|digit four|four|number 4|number four|numeral four|numeric 4"},
{0x35, false, "5|digit five|digit symbol|figure 5|five|number five|number symbol|numeral 5|numeric 5"},
{0x36, false, "6|6|digit six|number 6|number six|numeral six|numeric 6|six"},
{0x37, false, "7|7|digit seven|number digit seven|number seven|numeral seven|numeric 7|seven"},
{0x38, false, "8|digit eight|eight|figure eight|number eight|numeral 8|numeric 8"},
{0x39, false, "9|digit nine|nine|number 9|number nine|numeral 9|numeric 9|symbol 9"},
{0x41, false, "a|alphabet|alphabet letter|character|latin letter|letter|letter a|lowercase a|text character|uppercase a"},
{0xf2b9, false, "address book|address|address book|contact|contact list|contacts|directory|employee|little black book|people|personal organizer|phone book|profile|rolodex|user|username"},
{0xf2bb, false, "address card|address|badge|business card|card|contact|contact card|credentials|employee|id|id card|identification|name card|personal info|profile|profile card|registration|user"},
{0xf34e, false, "alarm clock|alarm|alarm clock|alert|bedtime|clock|deadline|morning|reminder|ringing|schedule|snooze|stopwatch|time|timer|wake up|watch"},
{0xf037, false, "align center|align|center|formatting|justify-center|layout|middle|paragraph|text|text-align"},
{0xf039, false, "align justify|align|alignment|formatting|justified text|justify|layout|paragraph|text|text alignment"},
{0xf036, false, "align left|align|alignment|format|justify-left|left|left-align|paragraph|text|text-align-left"},
{0xf038, false, "align right|align|document|editor|formatting|justify-right|layout|paragraph|right|right-align|text"},
{0xf13d, false, "anchor|anchor|berth|boat|dock|embed|harbor|link|maritime|moor|nautical|navigation|port|sea|secure|ship|stable"},
{0xe4aa, false, "anchor circle check|anchor|approved|check|confirmed|enabled|marina|ok|okay|port|safe|secure|stable|valid|verified"},
{0xe4ab, false, "anchor circle exclamation|alert|anchor|attention|caution|error|exclamation|issue|marina|notification|port|problem|unstable|warning"},
{0xe4ac, false, "anchor circle xmark|anchor|cancel|close|delete|disable|error|marina|nautical|not secure|port|reject|remove|uncheck|xmark"},
{0xe4ad, false, "anchor lock|anchor|lock|locked|marina|padlock|port|privacy|protection|safe|secure|secure anchor|security"},
{0xf107, false, "angle down|arrowhead|caret|chevron down|collapse|down arrow|download|dropdown|expand|more|open|scroll down|show more|toggle"},
{0xf104, false, "angle left|angle bracket|arrow|arrow left|back|back button|caret|chevron left|direction|left|less than|navigation|previous|scroll left"},
{0xf105, false, "angle right|arrow|arrow right|caret|chevron right|forward|move right|navigation|next|next page|pointer right|right arrow|scroll right|slide right|triangle right"},
{0xf106, false, "angle up|arrow|arrowhead up|caret|chevron up|close|collapse|expand less|increase|move up|scroll up|up arrow|up triangle|upload"},
{0xf103, false, "angles down|arrow down|arrows|caret|chevrons down|collapse|double down|download|dropdown|expand|more|navigation|pointer down|scroll down"},
{0xf100, false, "angles left|arrows|back|caret|chevrons|double angle|fast backward|laquo|left|navigation|previous|quotation mark|rewind|skip back"},
{0xf101, false, "angles right|arrows|caret|chevrons right|double angle|fast forward|forward|more|next|next page|quotation mark|quote|raquo|right angle"},
{0xf102, false, "angles up|arrows|caret|chevrons|chevrons up|collapse|double up|expand|increase|move up|navigation up|scroll up|up arrows|upload"},
{0xf644, false, "ankh|amulet|ancient egypt|ankh|coptic christianity|copts|cross|crux ansata|egypt|egyptian cross|eternal life|key of life|life|religion|spiritual|symbol"},
{0xf5d1, false, "apple whole|apple|fall|fresh|fruit|green apple|healthy|juicy|natural|orchard|produce|red apple|seasonal|snack|vegan|vegetarian"},
{0xe845, false, "aquarius|air sign|aquarius|astrology|constellation|february|horoscope|january|sign|stars|water bearer|zodiac"},
{0xf557, false, "archway|arch|architecture|archway|doorway|entrance|gate|historic|landmark|monument|old city|passage|portal|stone arch"},
{0xe846, false, "aries|april|aries|astrology|constellation|fire sign|horoscope|march|ram|sign|stars|zodiac"},
{0xf063, false, "arrow down|arrow down|arrow pointing down|chevron down|descend|direction|down arrow|download|downward|downwards arrow|drop|move down|navigation down|scroll down"},
{0xf162, false, "arrow down 1 9|1-9|arrange|ascending|filter|number order|numbers|numeric|order|sort|sort by number|sort-ascending|sort-numeric-asc"},
{0xf886, false, "arrow down 9 1|9-1|arrange|arrow-down|descending|down|filter|numbers|numeric|order|sort|sort-numeric-desc"},
{0xf15d, false, "arrow down a z|a-z|alphabet|alphabetical|arrange|ascending|filter|letters|order|sort|sort-alpha-asc|sort-asc|sort-letters"},
{0xf175, false, "arrow down long|arrow|arrow-down|arrow-symbol|direction|down|download|download-arrow|downward|long-arrow-down|move-down"},
{0xf884, false, "arrow down short wide|arrange|arrow|descending|down|filter|order|short|sort|sort-amount-asc|wide"},
{0xe4af, false, "arrow down up across line|arrows|directional|exchange|move|navigation|reorder|swap|switch|transfer|up and down"},
{0xe4b0, false, "arrow down up lock|arrows|data transfer|exchange|lock|locked|padlock|privacy|protected|secure|security|transfer|up and down"},
{0xf160, false, "arrow down wide short|arrange|descending|down|filter|number|order|short arrow|sort|sort amount asc|sort descending|wide arrow"},
{0xf881, false, "arrow down z a|alphabetical|alphabetically descending|arrange|descending|filter|order|reverse alphabetical|sort|sort descending|sort reverse|sort z-a|z to a"},
{0xf060, false, "arrow left|arrow|arrow left|back|backward|direction|go back|left|navigation|previous|return|rewind|undo"},
{0xf177, false, "arrow left long|arrow|back|direction|go back|left|long arrow|navigation|previous|return|undo"},
{0xf245, false, "arrow pointer|UI pointer|arrow|arrow cursor|click|cursor|input device|mouse|mouse arrow|mouse pointer|navigation|pointer|pointer arrow|pointer icon|select"},
{0xf061, false, "arrow right|arrow|arrow right|arrowhead|continue|direction|forward|move right|navigation|next|next page|proceed|right|rightwards arrow"},
{0xf0ec, false, "arrow right arrow left|arrow|arrows|back-and-forth|bidirectional|exchange|flip|reciprocal|reverse|swap|switch|toggle|transfer"},
{0xf08b, false, "arrow right from bracket|arrow|arrow-right|exit|exit door|forward|leave|log off|log out|logoff|logout|next|outbox|send|sign out"},
{0xf178, false, "arrow right long|arrow|continue|direction|forward|long arrow|move|navigation|next|proceed|right"},
{0xf090, false, "arrow right to bracket|access|arrow|enter|forward|insert|join|log in|login|next|proceed|sign in|sign up|sign-in|sign-on|signin|signup|submit"},
{0xe4b3, false, "arrow right to city|arrival|arrow|building|city|direction|enter|move|navigation|right|urban"},
{0xf0e2, false, "arrow rotate left|anticlockwise|back|cancel|control z|history|previous|reset|return|reverse|rewind|rotate|swap|undo"},
{0xf01e, false, "arrow rotate right|clockwise|cycle|forward|redo|refresh|reload|reload page|renew|repeat|retry|rotate|sync|update"},
{0xe097, false, "arrow trend down|arrow|chart|decline|decrease|down|drop|falling|graph|line|loss|negative|stock|trend"},
{0xe098, false, "arrow trend up|arrow|chart|graph|growth|increase|performance|positive|progress|rising|stocks|trend|upward"},
{0xf149, false, "arrow turn down|arrow|arrow curve|arrow down|arrow turn|curve|direction|down|navigation|rotate|turn"},
{0xf148, false, "arrow turn up|arrow|arrow curve|arrow rotate|arrow turn|arrow up|curve|direction|rotate|turn|up"},
{0xf062, false, "arrow up|arrow|ascension|forward|higher|increase|rise|top|up|upgrade|upload|upwards"},
{0xf163, false, "arrow up 1 9|arrange|ascending|filter|increase|numbers|numeric|order|ranking|sequence|sort|sort-numeric-asc|up"},
{0xf887, false, "arrow up 9 1|arrange|ascending|filter|increase|numbers|numeric|order|sort|sort-numeric-asc|up"},
{0xf15e, false, "arrow up a z|a to z|alphabet|alphabetical|arrange|ascending|filter|letters|order|sort|sort-alpha-asc"},
{0xe09a, false, "arrow up from bracket|arrow|export|move up|outbox|send|send out|share|submit|transfer|upload"},
{0xe4b5, false, "arrow up from ground water|aquifer|groundwater|irrigation|spring|upward arrow|water flow|water rising|water source|water supply|water table|well"},
{0xe4b6, false, "arrow up from water pump|drainage|flood|groundwater|irrigation|plumbing|pump|submersible|sump pump|upgrade|upward arrow|water flow|water pump"},
{0xf176, false, "arrow up long|arrow|arrow-up|ascension|increase|long-arrow-up|move up|rise|up|upload|upward"},
{0xe4b7, false, "arrow up right dots|arrow|chart|direction|growth|improvement|increase|northeast|positive|progress|rising|statistics|trend|upgrade"},
{0xf08e, false, "arrow up right from square|arrow|export|external|launch|link|navigate|new|open|redirect|send|share|up-right"},
{0xf885, false, "arrow up short wide|arrange|arrow|ascending|expand|filter|increase|order|short|sort|sort-amount-desc|up|wide|widen"},
{0xf161, false, "arrow up wide short|arrange|arrow|expand|filter|increase|order|short|sort|sort-amount-desc|up|upgrade|wide|widen"},
{0xf882, false, "arrow up z a|alphabetical|arrange|descending|filter|order|reverse alphabetical|sort|sort-alpha-desc|z to a"},
{0xe4b8, false, "arrows down to line|arrow down|arrow pointing down|arrow to line|download|download arrow|downward|insert|move down|sink"},
{0xe4b9, false, "arrows down to people|audience|collaboration|community|focus|group|interaction|people|targeted|team|users"},
{0xf07e, false, "arrows left right|arrows|direction|drag|exchange|expand|horizontal|left|move|resize|right|shift|swap|wide"},
{0xe4ba, false, "arrows left right to line|adjust|arrows|direction|expand|gap|horizontal|interface|left|move|navigation|resize|right|swap|transfer"},
{0xf021, false, "arrows rotate|clockwise|cycle|exchange|refresh|reload|renew|repeat|reset|retry|rotate|rotation|swap|sync|turn|update"},
{0xe4bb, false, "arrows spin|circular|cycle|loop|refresh|reload|repeat|rotate|spin|sync|turning|whirl"},
{0xe4bc, false, "arrows split up and left|arrows|branching|direction|diverge|divide|flow|left|move|navigation|separate|split|up"},
{0xe4bd, false, "arrows to circle|aim|center|centralize|concentrate|converge|convergence|coordinate|coordination|direction|focal point|focus|hub|insert|pinpoint|target"},
{0xe4be, false, "arrows to dot|assembly point|center|centralize|collect|converge|focus|gather|hub|point|target"},
{0xe4bf, false, "arrows to eye|attention|center|focus|look|monitor|observation|target|view|vision|watch"},
{0xe4c0, false, "arrows turn right|arrows"},
{0xe4c1, false, "arrows turn to dots|arrows|change|cycle|destination|direction|dots|insert|loop|movement|navigation|nexus|point|rotate|turn"},
{0xf07d, false, "arrows up down|adjust|arrows|direction|down|drag|expand|move|reorder|resize|scroll|swap|up|vertical"},
{0xf047, false, "arrows up down left right|adjust|arrow|arrows|directions|down|drag|enlarge|expand|left|move|navigation|reorder|reposition|resize|right|up"},
{0xe4c2, false, "arrows up to line|arrow up|elevate|growth|improvement|increase|progress|rise|scale up|upgrade|upward"},
{0x2a, false, "asterisk|annotation|asterisk|emphasis|footnote|highlight|note|reference|required|star|symbol|wildcard"},
{0x40, false, "at|address|at|commercial at|contact|e-mail|email|handle|inbox|mail|symbol|username"},
{0xf5d2, false, "atom|atom|atom symbol|atomic|chemistry|electron|energy|experiment|isotope|molecule|neutron|nuclear|particle|physics|proton|quantum|research|science"},
{0xf29e, false, "audio description|accessibility|audio description|blind|descriptive audio|narration|video|visual aid|visually impaired"},
{0xe0a9, false, "austral sign|Argentine currency|Austral Sign|cash|currency|finance|monetary|money|payment|peso|symbol"},
{0xf559, false, "award|accolade|achievement|award|badge|certificate|commendation|honor|medal|praise|prize|recognition|reward|ribbon|trophy"},
{0x42, false, "b|alphabet|capital b|character|font|letter b|letterform|lowercase b|symbol|text|typography"},
{0xf77c, false, "baby|baby|baby face|baby icon|child|child icon|infant|infant icon|kid|little one|newborn|newborn baby|toddler"},
{0xf77d, false, "baby carriage|baby|buggy|carriage|infant|newborn|pram|push|pushchair|stroller|transport|walk|wheels"},
{0xf04a, false, "backward|arrow|back|back button|double|go back|previous|previous track|reverse|rewind|skip back"},
{0xf049, false, "backward fast|arrow|back|beginning|double arrow|fast backward|first|media control|music|previous|previous track|rewind|skip back|start|track|video"},
{0xf048, false, "backward step|back|backward|beginning|first|go back|previous|reverse|rewind|start|step back|undo"},
{0xf7e5, false, "bacon|bacon|breakfast|brunch|crispy|cured|deli|food|fried|grease|meat|pork|rasher|savory|snack|strip"},
{0xe059, false, "bacteria|antibiotic|antibody|bacteria|disease|germ|health|infection|microbe|microorganism|pathogen|sick|virus"},
{0xe05a, false, "bacterium|antibiotic|bacteria|bacterium|disease|germ|health|infection|microbe|microorganism|pathogen|sick"},
{0xf290, false, "bag shopping|bag|basket|buy|cart|checkout|grocery|purchase|retail|sale|shopping|shopping bag|shopping cart|shopping spree|shopping tote|store"},
{0xf666, false, "bahai|baha'i faith|bahai|bahai symbol|bahá'í|faith|nine-pointed star|religion|spiritual|star|symbol"},
{0xe0ac, false, "baht sign|baht|cash|currency|finance|money|payment|thai baht|thai currency|thailand|฿"},
{0xf05e, false, "ban|abort|ban|block|cancel|deny|disabled|entry|forbidden|hide|no|prohibit|prohibited|remove|slash|stop"},
{0xf54d, false, "ban smoking|ban|banned|cancel|circle|deny|disallowed|forbidden|no|no smoking|non-smoking|prohibited|restricted|slash|smoke-free|smoking|stop"},
{0xf462, false, "bandage|adhesive bandage|bandage|boo boo|first aid|healing|healthcare|injury|medical|ouch|patch|plaster|wound"},
{0xe2e6, false, "bangladeshi taka sign|bangladesh|bdt|cash|currency|financial|money|payment|price|taka|tk"},
{0xf02a, false, "barcode|barcode|barcode-scanner|code|inventory|label|laser|price|product|retail|scan|scanner|tracking|upc"},
{0xf0c9, false, "bars|bars|burger|burger menu|drag|hamburger|interface|list|menu|menu button|mobile menu|nav|navigation|options|panel|reorder|sidebar|toggle"},
{0xf828, false, "bars progress|bar chart|checklist|download|downloading|loading|loading indicator|poll|progress|progress bar|progress indicator|project management|status|task|to do"},
{0xf550, false, "bars staggered|bars|controls|flow|layout|list|menu|options|settings|staggered|timeline"},
{0xf433, false, "baseball|ball|baseball|bat|catcher|diamond|foul|glove|hardball|home run|league|mlb|pitcher|softball|sport|strike"},
{0xf432, false, "baseball bat ball|ball|baseball|baseball equipment|baseball game|baseball player|bat|hitter|league|mlb|slugger|softball|sport"},
{0xf291, false, "basket shopping|basket|buy|cart|checkout|goods|grocery|market|purchase|retail|shopping|shopping basket|shopping cart|store"},
{0xf434, false, "basketball|ball|basket|basketball|court|dribble|dunk|foul|hoop|jump shot|nba|player|rebound|slam dunk|sport|team"},
{0xf2cd, false, "bath|bath|bathroom|bathtub|clean|cleansing|hygiene|relaxation|shower|soak|spa|tub|wash|water"},
{0xf244, false, "battery empty|battery|charge|dead|drain|empty|energy|flat|low|power|status|zero"},
{0xf240, false, "battery full|battery|battery charge|battery icon|battery level|battery status|charge|energy|full|power|status"},
{0xf242, false, "battery half|battery|battery-status|charge|energy|half|half-full|level|medium|power|status"},
{0xf243, false, "battery quarter|almost empty|battery|charge|energy|half-full|level|low|power|quarter|status|weak"},
{0xf241, false, "battery three quarters|75%|battery|battery level|battery status|charge|energy|level|medium charge|partially charged|power|status|three quarters"},
{0xf236, false, "bed|bed frame|bedroom|furniture|hospital|hotel|lodging|mattress|nap|patient|relaxation|rest|sleep|sleeping|tired|travel"},
{0xf487, false, "bed pulse|ECG|EKG|bed|care|electrocardiogram|emergency|health|heartbeat|hospital|life-support|medical|monitoring|patient|pulse|vital"},
{0xf0fc, false, "beer mug empty|alcohol|ale|bar|beer|beverage|brew|brewery|drink|empty|foam|lager|mug|pint|stein"},
{0xf0f3, false, "bell|alarm|alert|bell|buzzer|call|chime|ding|notification|prompt|reminder|request|ring|signal|tone"},
{0xf562, false, "bell concierge|alert|assistance|attention|bell|bellhop|call|concierge|front desk|help|hotel|notification|receptionist|request|service|support"},
{0xf1f6, false, "bell slash|alert|bell|block|cancel|disable notifications|disabled|do not disturb|mute|no sound|notification|off|quiet|reminder|silent|sound off"},
{0xf55b, false, "bezier curve|anchor points|bezier|control points|curve|drawing|graphic design|illustration|line|path|pen tool|shape|smooth curve|vector"},
{0xf206, false, "bicycle|bicycle|bike|cycle|cycling|eco-friendly|exercise|pedal|ride|sport|transportation|two-wheeler|vehicle"},
{0xf1e5, false, "binoculars|binoculars|explore|glasses|inspection|look|magnifier|magnify|nature|observe|outdoor|scout|spyglass|survey|telescope|view|watch"},
{0xf780, false, "biohazard|biohazard|biohazard sign|contamination|danger|epidemic|hazard|hazardous waste|hazmat|infectious|medical|pandemic|quarantine|toxic|virus|warning"},
{0xe0b4, false, "bitcoin sign|bitcoin|bitcoin sign|blockchain|btc|coin|crypto|cryptocurrency|currency|digital currency"},
{0xf517, false, "blender|blend|blender|cocktail maker|crush|drink maker|food processor|kitchen appliance|milkshake|mixer|puree|shake|smoothie"},
{0xf6b6, false, "blender phone|appliance|beverage|blender|cocktail|drink|funny|kitchen|milkshake|mixer|phone|puree|silly|smoothie"},
{0xf781, false, "blog|article|blog|diary|entry|journal|log|online|personal|post|website|wordpress|writing"},
{0xf032, false, "bold|bold|emphasis|font|format|highlight|strong|style|text|typography|weight"},
{0xf0e7, false, "bolt|bolt|charge|electric|electricity|energy|flash|high voltage|lightning|power|strike|thunderbolt|weather|zap"},
{0xe0b7, false, "bolt lightning|bolt|electric|electricity|energy|flash|lightning|power|storm|strike|thunderbolt|weather|zap"},
{0xf1e2, false, "bomb|blast|bomb|boom|cartoon|danger|detonator|explosion|explosive|fuse|grenade|kaboom|warning"},
{0xf5d7, false, "bone|anatomy|bone|calcium|chew|dog|femur|joint|marrow|pet|skeletal|skeleton|tibia|treat"},
{0xf55c, false, "bong|apparatus|cannabis|herbal|marijuana|pipe|smoke|smoking|smoking device|tokes|water pipe|weed"},
{0xf02d, false, "book|book|diary|education|journal|knowledge|library|literature|manuscript|notebook|publication|reading|research|study|text|writing"},
{0xf558, false, "book atlas|atlas|book|directions|exploration|geography|globe|guide|knowledge|library|map|navigation|reference|research|travel|wayfinding"},
{0xf647, false, "book bible|bible|book|catholicism|christianity|faith|god|gospel|holy book|religion|scripture|testament"},
{0xe0bb, false, "book bookmark|book|bookmark|favorite|knowledge|library|reading|reference|research|save|study"},
{0xf66a, false, "book journal whills|ancient|book|force|jedi|journal|lore|scripture|scroll|sith|star wars|tome|whills|yoda"},
{0xf7e6, false, "book medical|appointment|chart|clinic|diary|documentation|file|health|history|hospital|journal|medical|notes|patient|record|research"},
{0xf518, false, "book open|book|education|guide|knowledge|library|literature|manual|notebook|open book|pages|reading|research|study|text"},
{0xf5da, false, "book open reader|book|education|flyer|library|literature|notebook|open book|pamphlet|reader|reading|research|study"},
{0xf687, false, "book quran|holy book|islam|islamic text|koran|muslim|muslim faith|quran|religion|sacred text|scripture"},
{0xf6b7, false, "book skull|Dungeons & Dragons|curses|d&d|dark arts|death|dnd|evil|fantasy|halloween|library|magic|necronomicon|occult|read|research|skull|sorcery|spellbook|witchcraft"},
{0xf827, false, "book tanakh|bible|book|faith|hebrew bible|jewish|judaism|old testament|religion|religious text|sacred text|scripture|spiritual|tanakh|torah"},
{0xf02e, false, "bookmark|bookmark|clip|favorite|flag|hold|keep|mark|marker|page|read|remember|research|ribbon|save|tag"},
{0xf84c, false, "border all|border|border-style|box|cell|cells|frame|grid|layout|outline|spreadsheet|square|table"},
{0xf850, false, "border none|border|borderless|cell|clear border|grid|no border|none|outline|remove border|stroke|table"},
{0xf853, false, "border top left|border|box|cell|corner|edge|grid|left|outline|stroke|table|top"},
{0xe4c3, false, "bore hole|bore|borehole|dig|drill|drilling|drilling rig|excavation|hole|shaft|tunnel|underground"},
{0xe4c4, false, "bottle droplet|alcohol|beverage|bottle|container|drink|droplet|fluid|liquid|oil|olive oil|pour|wine"},
{0xe4c5, false, "bottle water|beverage|bottle|container|drink|h2o|hydration|liquid|plastic|refreshment|water"},
{0xe4c6, false, "bowl food|bowl|cat food|dish|dog food|food|kibble|meal|pet bowl|pet food|rice|snack"},
{0xe2eb, false, "bowl rice|Asian cuisine|boiled|bowl|cooked rice|food|grain|meal|rice|side dish|steamed"},
{0xf436, false, "bowling ball|alley|ball|bowling|bowling ball|candlepin|game|gutter|lane|pins|roll|sports|strike|tenpin"},
{0xf466, false, "box|archive|box|carton|container|crate|delivery|gift box|moving|package|packing|parcel|shipping|storage|storage box"},
{0xf187, false, "box archive|archive|backup|box|container|delivery|file|folder|package|parcel|save|shipment|storage"},
{0xf49e, false, "box open|box|carton|container|crate|delivery|gift|open box|package|parcel|shipping|storage|unboxing|unpack"},
{0xe05b, false, "box tissue|allergy|box|cold|cough|covid-19|flu|hygiene|kleenex|mucus|nose|runny nose|sneeze|snot|tissue|tissues"},
{0xe4c7, false, "boxes packing|archive|box|container|delivery|moving|package|packing|parcel|shipping|storage|supplies"},
{0xf468, false, "boxes stacked|archives|boxes|carton|container|inventory|logistics|organizing|packing|shipping|stacked|storage|supply chain|warehouse"},
{0xf2a1, false, "braille|accessibility|alphabet|blind|braille|dots|raised|reading|tactile|touch|vision impaired|visually impaired"},
{0xf5dc, false, "brain|brain|cerebellum|cerebrum|creativity|genius|gray matter|idea|intellect|intelligence|knowledge|mind|noodle|scholar|smart|thinking|wit"},
{0xe46c, false, "brazilian real sign|brazil|brazilian currency|brazilian real|brazilian real sign|cash|currency|currency symbol|financial|money|payment|real"},
{0xf7ec, false, "bread slice|baked|bakery|baking|bread|breakfast|crust|dough|flour|gluten|grain|loaf|sandwich|slice|toast|wheat|yeast"},
{0xe4c8, false, "bridge|bridge|connection|crossing|infrastructure|overpass|pathway|river crossing|road|span|viaduct"},
{0xe4c9, false, "bridge circle check|active|approve|bridge|check|confirm|connection|enabled|ok|okay|pass|road|success|validate|verify|working"},
{0xe4ca, false, "bridge circle exclamation|affected|alert|bridge|caution|danger|exclamation|failure|problem|road|warning"},
{0xe4cb, false, "bridge circle xmark|block|bridge|cancel|close|crossing|delete|deny|no|reject|remove|road|stop|xmark"},
{0xe4cc, false, "bridge lock|access|barrier|bridge|closed|lock|locked|padlock|privacy|protection|quarantine|restricted|road|security"},
{0xe4ce, false, "bridge water|bridge|crossing|highway|overpass|river|road|span|structure|viaduct|water"},
{0xf0b1, false, "briefcase|bag|briefcase|business|career|case|contract|document|job|luggage|meeting|office|portfolio|professional|suitcase|work"},
{0xf469, false, "briefcase medical|clinic|doctor|doctor bag|emergency|emt|first aid|health|healthcare|hospital|medical|medical kit|medicine|nurse|paramedic|treatment"},
{0xf51a, false, "broom|broom|brush|clean|cleaning|dust|flying broom|halloween|household|janitor|magic broom|sweep|sweeping|tidy|witch"},
{0xf458, false, "broom ball|ball|bludger|broom|flying ball|golden snitch|harry potter|hogwarts|magical sport|quaffle|quidditch|sport|wizard"},
{0xf55d, false, "brush|art|artist|bristles|brushstroke|color|creative|design|drawing|handle|paint|painting|tool"},
{0xe4cf, false, "bucket|beach|bucket|carry|cleaning|container|gardening|pail|sand|sandcastle|scoop|water"},
{0xf188, false, "bug|beetle|bug|debug|defect|error|fix|glitch|insect|issue|problem|repair|report|troubleshooting"},
{0xe490, false, "bug slash|beetle|block|bug|cancel|disable|disabled|error|fix|glitch|insect|optimize|repair|report|warning"},
{0xe4d0, false, "bugs|bedbug|bug|creepy crawly|infestation|insect|lice|parasite|pest|pest control|ticks"},
{0xf1ad, false, "building|apartment|architecture|building|business|city|company|corporate|headquarters|office|office building|real estate|skyscraper|tower|urban|workplace"},
{0xe4d1, false, "building circle arrow right|arrow|building|city|delivery|distribution center|export|logistics|move|office|outbound|send|shipping|transfer|warehouse"},
{0xe4d2, false, "building circle check|approved|building|check|city|confirm|enabled|office|ok|okay|success|validate|verified|working"},
{0xe4d3, false, "building circle exclamation|affected|alert|building|caution|city|error|exclamation|failed|issue|office|problem|warning"},
{0xe4d4, false, "building circle xmark|block|building|cancel|city|close|delete|dismiss|error|no|office|reject|remove|stop|xmark"},
{0xf19c, false, "building columns|architecture|bank|building|classical|college|courthouse|courthouse|education|finance|government|institution|legal|museum|pillar|students|temple"},
{0xe4d5, false, "building flag|building|city|consulate|diplomatic|embassy|flag|government|headquarters|international|office|organization|united nations"},
{0xe4d6, false, "building lock|building|city|closed|lock|lockdown|locked|locked building|padlock|private|protected|quarantine|restricted|secure|security"},
{0xe4d7, false, "building ngo|building|charity|city|headquarters|institution|ngo|non governmental organization|nonprofit|office|organization"},
{0xe4d8, false, "building shield|building|city|defense|guard|law enforcement|police|protection|safety|secure|security|shield"},
{0xe4d9, false, "building un|UN|building|city|diplomacy|emblem|global|headquarters|international|office|organization|peacekeeping|united nations"},
{0xe4da, false, "building user|apartment|building|city|employee|occupant|office|person|profile|resident|tenant|user|workplace"},
{0xe4db, false, "building wheat|agriculture|barn|building|crop|farm|farming|grain|harvest|rural|silo|usda|wheat"},
{0xf0a1, false, "bullhorn|alert|amplify|announce|announcement|broadcast|bullhorn|call out|communication|loudspeaker|megaphone|message|promote|public address|share|speaker|volume"},
{0xf140, false, "bullseye|aim|archery|bullseye|dartboard|focus|goal|objective|precision|strategy|target"},
{0xf805, false, "burger|beef|bun|burger|cheeseburger|dinner|fast food|food|grill|hamburger|lunch|meal|patty|sandwich|takeaway"},
{0xe4dc, false, "burst|bang|blast|boom|burst|crash|detonation|explosion|fireworks|flare|impact|pop|spark"},
{0xf207, false, "bus|bus|coach|commuter|oncoming bus|passenger vehicle|public transportation|shuttle|transit|transport|travel|vehicle"},
{0xe81d, false, "bus side|bus|coach|commuter|mass transit|passenger bus|public transportation|shuttle|transit|travel|vehicle"},
{0xf55e, false, "bus simple|bus|bus stop|coach|commuter|mass transit|mta|public transportation|shuttle|transit|transport|travel|vehicle"},
{0xf64a, false, "business time|alarm|appointment|briefcase|business|clock|deadline|hours|office|reminder|schedule|time|timer|work"},
{0x43, false, "c|alphabet c|c alphabet character|c glyph|c symbol|capital c|character c|latin letter c|letter c|lowercase c"},
{0xf7da, false, "cable car|aerial tramway|cabin|cable car|cableway|gondola|lift|mountain|mountain cableway|ropeway|ski lift|tram|tramway|transport|trolley"},
{0xf1fd, false, "cake candles|anniversary|bakery|birthday|blow out candles|cake|candles|celebration|dessert|festive|frosting|holiday|party|pastry|sweet|treat"},
{0xf1ec, false, "calculator|addition|arithmetic|calculator|calculator app|calculator device|counting|digits|division|finance|math|math tool|multiplication|numbers|pocket calculator|subtraction"},
{0xf133, false, "calendar|agenda|appointment|calendar|date|day|deadline|event|month|planner|reminder|schedule|time|year"},
{0xf274, false, "calendar check|accept|agree|appointment|approved|booked|calendar|check|completed|confirm|confirmed|date|day|deadline|done|event|mark|meeting|month|planned|reminder|schedule|select|success|tick|time|todo|validate"},
{0xf783, false, "calendar day|appointment|calendar|date|day|event|focus|month|planner|reminder|schedule|single day|time|timeline|today|year"},
{0xf073, false, "calendar days|agenda|appointment|calendar|date|day|deadline|event|month|planner|reminder|schedule|time|timeline|year"},
{0xf272, false, "calendar minus|calendar|cancel|clear|date|day|delete|event|minus|month|reduce|remove|schedule|subtract|time|year"},
{0xf271, false, "calendar plus|add|appointment|calendar|create|date|day|event|month|new|plan|plus|reminder|schedule|time|year"},
{0xf784, false, "calendar week|agenda|appointment|calendar|date|day|event|month|period|planner|schedule|time|timeframe|today|week"},
{0xf273, false, "calendar xmark|appointment|calendar|cancel|cancelation|close|date|day|delete|event|month|remove|schedule|time|x|year"},
{0xf030, false, "camera|camera|camera icon|capture|film|image|lens|photo|photograph|photography|picture|recording|shutter|snapshot|video"},
{0xf083, false, "camera retro|analog|camera|classic|film|image|lens|old-fashioned|photo|photography|picture|record|retro|shutter|snapshot|vintage"},
{0xe0d8, false, "camera rotate|camera|flip|flip camera|front-facing|image|photo|rotate|rotate camera|selfie|switch"},
{0xf6bb, false, "campground|campfire|campground|camping|campsite|forest|hiking|nature|outdoors|teepee|tent|tipi|wilderness"},
{0xe847, false, "cancer|astrology|cancer|constellation|crab|horoscope|july|june|sign|stars|water sign|zodiac"},
{0xf786, false, "candy cane|candy|cane|christmas|festive|holiday|mint|peppermint|striped|sweet|treat|winter|xmas"},
{0xf55f, false, "cannabis|bud|cannabis|cbd|chronic|ganja|hemp|indica|marijuana|mary jane|pot|reefer|sativa|spliff|thc|weed"},
{0xe848, false, "capricorn|astrology|capricorn|constellation|december|earth sign|goat|horoscope|january|sea|sea goat|sign|stars|zodiac"},
{0xf46b, false, "capsules|capsules|drugs|health|medication|medicine|pharmaceuticals|pharmacy|pills|prescription|tablets|treatment"},
{0xf1b9, false, "car|auto|automobile|car|commute|driving|motorcar|ride|road trip|sedan|transportation|travel|vehicle"},
{0xf5df, false, "car battery|auto|automotive|battery|battery-pack|car|charge|electric|energy|ignition|mechanic|power|starter|vehicle"},
{0xf5e1, false, "car burst|accident|auto|automobile|car|collision|crash|damage|insurance|transportation|vehicle|wreck"},
{0xe4dd, false, "car on|alarm|alert|anti-theft|car|carjack|immobilizer|security|theft|vehicle|warning"},
{0xf5de, false, "car rear|auto|automobile|back|car|coupe|driving|hatchback|motor vehicle|rear view|road|sedan|transportation|travel|vehicle"},
{0xf5e4, false, "car side|auto|automobile|car|coupe|driving|hatchback|motorcar|ride|road|sedan|transport|transportation|travel|vehicle"},
{0xe4de, false, "car tunnel|car|driving|highway|motorway|passage|road|transportation|tunnel|underpass|vehicle"},
{0xf8ff, false, "caravan|camper|camper trailer|camping|caravan trailer|mobile home|motorhome|recreational vehicle|road trip|rv|towable|trailer|travel|vacation"},
{0xf0d7, false, "caret down|arrow|chevron|down|dropdown|expand|indicator|menu|more|navigation|pointer|toggle|triangle"},
{0xf0d9, false, "caret left|arrow|back|chevron|direction|left|navigation|pointer|previous|rewind|triangle"},
{0xf0da, false, "caret right|arrow|chevron|forward|move|navigation|next|play|pointer|right|skip|triangle"},
{0xf0d8, false, "caret up|arrow|caret|chevron|collapse|expand|increase|navigation|pointer|triangle|up|up arrow|upgrade"},
{0xf787, false, "carrot|Bugs Bunny|carrot|food|garden|healthy|orange|produce|root vegetable|snack|vegan|vegetable"},
{0xf218, false, "cart arrow down|add to cart|arrow down|basket|buy|cart|checkout|download|insert|order|purchase|save|shopping"},
{0xf474, false, "cart flatbed|carry|cart|delivery|dolly|flatbed|hand truck|inventory|logistics|shipping|transport|trolley|warehouse"},
{0xf59d, false, "cart flatbed suitcase|airport|airport cart|bag|baggage|carry-on|flatbed|luggage|suitcase|suitcase trolley|travel|travel bag|trolley"},
{0xf217, false, "cart plus|add|add to cart|buy|cart|ecommerce|increase|new item|plus|positive|purchase|shopping|shopping basket"},
{0xf07a, false, "cart shopping|add to cart|basket|buy|cart|cart icon|checkout|ecommerce|grocery|payment|purchase|retail|shop|shopping cart|store|trolley"},
{0xf788, false, "cash register|buy|cash|cha-ching|change|checkout|commerce|machine|pay|payment|purchase|register|retail|store|transaction"},
{0xf6be, false, "cat|animal|cat|claw|cute|domestic|feline|fur|kitten|kitty|mammal|meow|pet|pet animal|whiskers"},
{0xe0df, false, "cedi sign|cash|cedi|currency|currency sign|currency symbol|financial|ghana|ghanaian cedi|money|payment"},
{0xe3f5, false, "cent sign|cash|cent|cent sign|cents|coin|currency|currency symbol|finance|money|payment"},
{0xf0a3, false, "certificate|achievement|award|badge|certificate|certification|diploma|document|endorsement|guarantee|official|quality|recognition|seal|star|verified"},
{0xf6c0, false, "chair|armchair|bench|chair|dining chair|furniture|office chair|recliner|seat|seating|sitting|stool"},
{0xf51b, false, "chalkboard|blackboard|board|chalk|chalkboard|classroom|education|learning|lesson|presentation|school|teaching|writing"},
{0xf51c, false, "chalkboard user|blackboard|classroom|education|instructor|learning|lecture|professor|school|teacher|whiteboard|writing"},
{0xf79f, false, "champagne glasses|alcohol|anniversary|bar|beverage|celebrate|celebration|champagne|cheers|clink|clinking glasses|drink|festive|glass|holiday|new year's eve|party|sparkling wine|toast|wedding"},
{0xf5e7, false, "charging station|battery charging|car charger|charge|charging|charging station|electric car|electric vehicle|ev|ev charger|plug-in|power station|tesla|vehicle"},
{0xf1fe, false, "chart area|analytics|area|business|chart|data|graph|growth|metrics|performance|report|revenue|statistics|trend|visualization"},
{0xf080, false, "chart bar|analytics|bar|chart|comparison|dashboard|data|graph|metrics|performance|progress|report|statistics|trends|visualization"},
{0xe0e3, false, "chart column|analytics|bar|bar chart|chart|column chart|compare|dashboard|data|graph|measure|performance|report|statistics|trend|visualize"},
{0xe695, false, "chart diagram|algorithm|analytics|chart|connections|data|diagram|flow|graph|network|nodes|process|structure|workflow"},
{0xe0e4, false, "chart gantt|chart|gantt|graph|management|performance|planning|progress|project|schedule|statistics|tasks|timeline|tracking|trend|workflow"},
{0xf201, false, "chart line|activity|analytics|chart|dashboard|data|gain|graph|growth|increase|line|performance|progress|report|revenue|statistics|trend"},
{0xf200, false, "chart pie|analytics|chart|circle|data|diagram|distribution|graph|infographic|performance|pie|pie chart|report|revenue|segments|statistics"},
{0xe473, false, "chart simple|analytics|bar|chart|column|data|graph|infographic|metrics|performance|progress|report|revenue|statistics|trend|visualization"},
{0xf00c, false, "check|accept|agree|approved|check|check mark|checkmark|completed|confirm|correct|done|enable|ok|select|success|tick|true|validate|verified|yes"},
{0xf560, false, "check double|accept|agree|approved|checkmark|completed|confirm|correct|done|done twice|double check|enable|finished|ok|select|select all|success|tick|validate|verified"},
{0xf772, false, "check to slot|accept|approve|ballot|cast|checkmark|election|enable|mark|positive|select|validate|vote|voting|yes"},
{0xf7ef, false, "cheese|cheddar|cheese|curd|dairy|dairy product|dairy wedge|food|gouda|parmesan|sandwich|slice|snack|swiss|wedge"},
{0xf439, false, "chess|bishop|board|checkmate|chess|chess piece|competition|game|king|knight|match|pawn|queen|rook|strategy|tournament"},
{0xf43a, false, "chess bishop|bishop|black bishop|board game|checkmate|chess|chess piece|chessboard|game piece|strategy"},
{0xf43c, false, "chess board|board|checkers|checkmate|chess|chess game|chess match|chess piece|chess set|chessboard|chessboard pattern|game|strategy"},
{0xf43f, false, "chess king|board game|checkmate|chess|chess king|chess piece|chess strategy|chessboard|game|king|king piece|strategy"},
{0xf441, false, "chess knight|board game|checkmate|chess|chess match|chess piece|chessboard|game piece|horse|knight|strategy"},
{0xf443, false, "chess pawn|board game|checkmate|chess|chess pawn|expendable|game piece|pawn|piece|sacrifice|strategy"},
{0xf445, false, "chess queen|board game|checkmate|chess|chess piece|chess queen|chess set|chessboard|game|queen|queen piece|strategy"},
{0xf447, false, "chess rook|board game|castle|checkmate|chess piece|chess strategy|chessboard|defense|game piece|rook|strategy|tower"},
{0xf078, false, "chevron down|arrow|chevron|collapse|down|dropdown|expand|indicator|more|navigation|toggle"},
{0xf053, false, "chevron left|angle bracket|arrow|back|caret|chevron|go back|left|navigation|previous|slide back"},
{0xf054, false, "chevron right|angle bracket|arrow|arrowhead|caret|chevron|forward|navigation|next|pointer|right|slide"},
{0xf077, false, "chevron up|arrow|back|chevron|collapse|expand|increase|previous|scroll up|up|upload"},
{0xf1ae, false, "child|baby|boy|child|girl|infant|kid|minor|preschooler|toddler|young|youngster|youth"},
{0xe4e0, false, "child combatant|armed child|child combatant|child fighter|child in conflict|child militia|child soldier|child soldier icon|child war|child with weapon"},
{0xe59c, false, "child dress|child|children|clothing|dress|garment|kid|kidswear|outfit|toddler|young|youth"},
{0xe59d, false, "child reaching|boy|child|girl|kid|playful|reaching|toddler|young|youth"},
{0xe4e1, false, "children|boy|child|children|family|friends|girl|kid|kids|play|together|young|youth"},
{0xf51d, false, "church|Christian|building|cathedral|chapel|church|community|congregation|cross|faith|house of worship|religion|spirituality|worship"},
{0xf111, false, "circle|black circle|blue circle|brown circle|circle|diameter|dot|ellipse|fill|geometric|green circle|indicator|notification|orange circle|progress|purple circle|red circle|round|shape|status|white circle|yellow circle"},
{0xf0ab, false, "circle arrow down|arrow|arrow down|circle arrow|download|download button|download icon|downward|get file|import|save"},
{0xf0a8, false, "circle arrow left|arrow|back|backward|go back|left|navigate left|previous|return|rewind|undo"},
{0xf0a9, false, "circle arrow right|arrow|circle|continue|direction|forward|move|navigation|next|proceed|right"},
{0xf0aa, false, "circle arrow up|arrow|arrow up|ascend|direction|increase|move up|up arrow|upgrade|upload|upward"},
{0xf058, false, "circle check|accept|agree|approve|check|confirm|correct|done|enable|ok|select|success|tick|validate|yes"},
{0xf13a, false, "circle chevron down|arrow|chevron|collapse|down|dropdown|expand|menu|more|navigation|toggle"},
{0xf137, false, "circle chevron left|arrow|back|caret|chevron|direction|left|navigation|pointer|previous|rewind|slide"},
{0xf138, false, "circle chevron right|arrow|chevron|continue|direction|forward|navigation|next|next step|proceed|right"},
{0xf139, false, "circle chevron up|arrow|chevron|collapse|expand|increase|move up|navigate up|scroll up|up|upload"},
{0xf4b9, false, "circle dollar to slot|cash|charity|coin|contribute|donation|funding|generosity|gift|give|insert|money|payment|premium|slot machine|tip"},
{0xf192, false, "circle dot|bullseye|button|circle|dot|focus|indicator|marker|notification|point|radio|radio button|target"},
{0xf358, false, "circle down|arrow-circle-down|arrow-down|circle-arrow-down|circle-download|download|download-button|download-circle|downward-arrow|save|save-file"},
{0xf06a, false, "circle exclamation|alert|attention|caution|danger|error|exclamation|important|issue|notice|notification|notify|problem|required|urgent|warning"},
{0xf47e, false, "circle h|circled H|clinic|covid-19|emergency|health|healthcare|hospital|letter H|map|medical"},
{0xf042, false, "circle half stroke|adjust|brightness|circle|contrast|dark|fill|half|half circle|left half|light|mode|pie|progress|saturation|stroke|theme|toggle"},
{0xf05a, false, "circle info|about|data|details|explanation|facts|guidance|help|info|information|more|support"},
{0xf359, false, "circle left|arrow|arrow-circle-left|back|circle|go back|left|navigation|previous|return|undo"},
{0xf056, false, "circle minus|block|cancel|circle|close|delete|disable|hide|minus|negative|remove|subtract|symbol"},
{0xe4e2, false, "circle nodes|cluster|connect|connection|diagram|dots|graph|linked|mesh|network|nodes|points|relationship|web"},
{0xf1ce, false, "circle notch|buffering|circle|circle-o-notch|loading|notch|progress|round|spinner|wait"},
{0xf28b, false, "circle pause|break|halt|hold|media control|pause|pause button|stop|temporary stop|wait|waiting"},
{0xf144, false, "circle play|audio|clip|media|movie|music|play|sound|start|streaming|video|watch"},
{0xf055, false, "circle plus|add|button|circle|create|expand|increase|more|new|plus|positive|symbol"},
{0xf059, false, "circle question|ask|assist|confusion|doubt|faq|help|info|information|inquiry|query|question|question-mark|support|unknown"},
{0xf7ba, false, "circle radiation|alert|biohazard|caution|danger|hazard|nuclear|radiation|radioactive|sign|toxic|warning"},
{0xf35a, false, "circle right|arrow|arrow-circle-o-right|circle|continue|direction|forward|move|navigation|next|proceed|right"},
{0xf28d, false, "circle stop|block|cancel|circle|deny|disallow|forbidden|halt|no|pause|prevent|prohibit|stop"},
{0xf35b, false, "circle up|arrow|arrow-circle-up|circle|direction up|increase|move up|up|upgrade|upload|upload arrow"},
{0xf2bd, false, "circle user|account|avatar|contact|employee|individual|member|people|person|profile|user|username"},
{0xf057, false, "circle xmark|cancel|close|cross|dismiss|error|exit|fail|incorrect|no|reject|remove|stop|wrong|xmark"},
{0xf64f, false, "city|architecture|block|buildings|city|cityscape|downtown|metropolis|neighborhood|skyline|skyscrapers|urban|windows"},
{0xe131, false, "clapperboard|camera|cinema|clapper|clapper board|clapperboard|director|film|movie|production|recording|shoot|slate|video"},
{0xf328, false, "clipboard|board|checklist|clipboard|copy|document|file|memo|notepad|notes|paper|paste|record|task|writing"},
{0xf46c, false, "clipboard check|approve|check|checkmark|clipboard|complete|confirm|done|finish|ok|success|task|todo|validate|yes"},
{0xf46d, false, "clipboard list|agenda|checklist|clipboard|completed|done|finished|list|notes|plan|schedule|summary|survey|tasks|tick|todo|wishlist"},
{0xe4e3, false, "clipboard question|assistance|checklist|clipboard|doubt|faq|form|help|inquiry|interview|query|question|support|task"},
{0xf7f3, false, "clipboard user|account|attendance|employee|identity|list|person|personnel|profile|record|roster|staff|user"},
{0xf017, false, "clock|4|4:00|alarm|clock|four|four o’clock|hour|late|minute|o'clock|pending|schedule|ticking|time|timer|timestamp|watch"},
{0xf1da, false, "clock rotate left|back|clock|history|pending|refresh|reset|reverse|rewind|time|undo|waiting"},
{0xf24d, false, "clone|add|backup|clone|copy|copy-paste|duplicate|mirror|new|repeat|replicate|replicate"},
{0xf20a, false, "closed captioning|accessibility|captions|cc|closed caption|closed captions|deaf|hearing impaired|subtitle|subtitles|text|transcript|video"},
{0xe135, false, "closed captioning slash|captions off|cc|closed captioning|deaf|disabled|hearing impaired|mute captions|no captions|no subtitles|subtitles off|subtitling"},
{0xf0c2, false, "cloud|atmosphere|backup|cloud|data|fog|internet|network|online|overcast|save|sky|storage|upload|weather"},
{0xf0ed, false, "cloud arrow down|arrow|backup|cloud|data|download|file|import|network|save|storage|sync|transfer|upload"},
{0xf0ee, false, "cloud arrow up|backup|cloud|cloud upload|import|save|send|sync|transfer|update|upgrade|upload"},
{0xf76c, false, "cloud bolt|bolt|cloud|electric|energy|lightning|lightning bolt|power|precipitation|rain|storm|thunder|thunderstorm|weather"},
{0xf73b, false, "cloud meatball|FLDSMDFR|cloud|dinner|food|italian|meal|meatball|pasta|sauce|spaghetti|storm|weather"},
{0xf6c3, false, "cloud moon|crescent|dusk|evening|lunar|moon|night|nighttime|partly cloudy|sky|twilight|weather"},
{0xf73c, false, "cloud moon rain|crescent|drizzle|evening|moon|night|partly cloudy|precipitation|rain|showers|sky|storm|weather"},
{0xf73d, false, "cloud rain|cloud|drizzle|precipitation|rain|rainy|shower|sky|storm|thunderstorm|weather|wet"},
{0xf740, false, "cloud showers heavy|cloud|downpour|heavy rain|precipitation|rain|showers|storm|thunderstorm|weather|wet"},
{0xe4e4, false, "cloud showers water|cloud|downpour|drizzle|precipitation|rain|rainfall|shower|storm|thunderstorm|water|weather|wet"},
{0xf6c4, false, "cloud sun|clear sky|cloud|daytime|forecast|mild weather|outdoors|overcast|partly cloudy|spring|summer|sun|sun behind cloud|weather"},
{0xf743, false, "cloud sun rain|cloud|day|drizzle|mixed weather|overcast|partly sunny|precipitation|rain|shower|storm|summer|sun|sun behind rain cloud|sunshower|weather"},
{0xe139, false, "clover|charm|clover|fortune|four leaf|four-leaf|good luck|ireland|irish|leaf|leprechaun|luck|lucky|shamrock|st patrick|st patrick's day"},
{0xf121, false, "code|backend|brackets|code|coding|developer|development|frontend|html|markup|mysql|programming|script|software|sql|syntax"},
{0xf126, false, "code branch|branch|code|commit|development|git|github|merge|programming|rebase|repository|software|source control|vcs|version"},
{0xf386, false, "code commit|branch|changeset|code|commit|git|github|merge|push|repository|revision|source control|vcs|version"},
{0xe13a, false, "code compare|changes|code|compare|diff|git|github|merge|repository|review|revision|svn|update|version"},
{0xe13b, false, "code fork|branch|clone|code management|fork|git|github|repository|source control|split|svn|version"},
{0xf387, false, "code merge|branch|code integration|collaboration|commit|git|github|merge|pr|pull request|rebase|svn|vcs|version control"},
{0xe13c, false, "code pull request|branch|code review|git|github|merge|pr|pull request|svn|version control"},
{0xf51e, false, "coins|cash|change|coins|currency|dime|finance|gold|money|nickel|payment|penny|premium|quarter|savings|silver|wealth"},
{0xe140, false, "colon sign|colon|cost|currency|currency symbol|financial|money sign|price|punctuation|symbol"},
{0xf075, false, "comment|chat|comment|conversation|discussion|feedback|message|note|notification|reply|response|sms|speech bubble|talk|texting"},
{0xf651, false, "comment dollar|billing|bubble|chat|comment|conversation|dollar|feedback|finance|invoice|message|money|pay|payment|salary|speech|transfer"},
{0xf4ad, false, "comment dots|bubble|chat|comment|conversation|dialog|discussion|feedback|input|message|note|reply|sms|speech balloon|texting|typing"},
{0xf7f5, false, "comment medical|advice|answer|bubble|chat|commenting|conversation|diagnose|diagnosis|doctor|feedback|medical|message|note|notification|prescription|report|speech|talking|texting"},
{0xe696, false, "comment nodes|ai|algorithm|artificial intelligence|cluster|connection|data|graph|language|machine learning|model|network|neural|nodes|technology"},
{0xf4b3, false, "comment slash|block|cancel|chat|comment|conversation|disabled|feedback|message|muted|no comment|quiet|silent|slash|speech|texting"},
{0xf7cd, false, "comment sms|bubble|chat|comment|conversation|message|mobile message|notification|phone|reply|sms|speech bubble|text message|texting"},
{0xf086, false, "comments|chat|comment|communication|conversation|dialogue|discussion|feedback|message|notification|reply|sms|speech bubbles|talk|texting"},
{0xf653, false, "comments dollar|billing|chat|comment|comments|conversation|discussion|dollar|feedback|finance|inquiry|message|money|payment|salary|support|transaction"},
{0xf51f, false, "compact disc|album|blu-ray|bluray|cd|compact disc|disc|disk|dvd|media|movie|music|optical disc|record|video|vinyl"},
{0xf14e, false, "compass|adventure|compass|directions|explore|guide|location|magnetic|map|navigation|north|orienteering|path|route|travel|wayfinding"},
{0xf568, false, "compass drafting|architecture|blueprint|compass|design|drafting|drawing|engineering|geometry|measurement|plot|plotting|technical drawing"},
{0xf066, false, "compress|collapse|compress|condense|contract|minimize|narrow|reduce|shrink|smaller|tighten|zoom out"},
{0xe4e5, false, "computer|computer|cpu|desktop|device|hardware|monitor|pc|screen|technology|workstation"},
{0xf8cc, false, "computer mouse|USB mouse|click|computer|computer accessory|cursor|device|hardware|input|mouse|peripheral|pointing device|scroll wheel|trackball|wireless mouse"},
{0xf563, false, "cookie|baked good|biscuit|chocolate|chocolate chip|cookie|dessert|eat|pastry|snack|sweet|treat"},
{0xf564, false, "cookie bite|baked good|bite|bitten|chocolate chip|cookie|dessert|eating|food|snack|snacktime|sweet|treat"},
{0xf0c5, false, "copy|clipboard|clone|copy|document|duplicate|file|paper|paste|replicate|replicate|replicate"},
{0xf1f9, false, "copyright|c|copyright|copyright symbol|intellectual property|legal|license|mark|protection|registered|rights|trademark"},
{0xf4b8, false, "couch|chair|couch|cushion|furniture|living room|lounge|loveseat|relax|seating|sofa"},
{0xf6c8, false, "cow|agriculture|animal|beef|bovine|cattle|cow|dairy|farm|herd|livestock|mammal|milk|moo"},
{0xf09d, false, "credit card|billing|buy|card|charge|checkout|credit card|debit card|finance|money|pay|payment|plastic card|purchase|transaction|wallet"},
{0xf125, false, "crop|adjust|crop|cut|edit|frame|image|modify|photo|picture|resize|shrink|trim"},
{0xf565, false, "crop simple|adjust|crop|cut|edit|frame|image|modify|photo|resize|shape|trim"},
{0xf654, false, "cross|catholicism|christian|christianity|church|cross|crucifix|cruciform|faith|holy|jesus|religion|salvation|spirituality|symbol|worship"},
{0xf05b, false, "crosshairs|GPS|aim|bullseye|center|crosshair|focus|location|marker|pinpoint|position|precision|reticle|scope|sight|target"},
{0xf520, false, "crow|animal|bird|blackbird|crow|halloween|nature|raven|spooky|wildlife|winged creature"},
{0xf521, false, "crown|VIP|award|champion|crown|honor|king|luxury|monarchy|prize|queen|regal|royal|ruler|tiara|winner"},
{0xf7f7, false, "crutch|assistive device|cane|disability|injury|medical|mobility|rehabilitation|support|walking aid"},
{0xe152, false, "cruzeiro sign|BRL|Brazilian currency|Brazilian real|Cruzeiro|cash|currency|currency sign|currency symbol|finance|money"},
{0xf1b2, false, "cube|3d|block|box|container|cube|dice|figure|geometric|object|package|shape|solid|square|tesseract"},
{0xf1b3, false, "cubes|3d|block|box|cube|dice|geometric|grid|package|shape|square|stack"},
{0xe4e6, false, "cubes stacked|3d|blocks|building|construction|cubes|geometric|modular|stack|sugar cubes|toy"},
{0x44, false, "d|alphabet|capital d|character|letter d|lowercase d|symbol|text"},
{0xf1c0, false, "database|backend|cloud|data|database|directory|information|memory|mysql|records|server|sql|storage|table"},
{0xf55a, false, "delete left|backspace|backspace key|backspace symbol|delete|delete left|erase|erase to the left|keyboard|remove|undo"},
{0xf747, false, "democrat|blue party|democrat|democratic party|donkey|election|government|left|left-wing|liberal|political party|politics|progressives|united states|usa"},
{0xf390, false, "desktop|all-in-one|computer|desktop|desktop computer|device|display|hardware|imac|monitor|pc|screen|workstation"},
{0xf655, false, "dharmachakra|Buddhist|Indian religion|buddhism|buddhist|dharma wheel|dharmachakra|enlightenment|karma|meditation|religion|sacred symbol|spirituality|teachings|wheel of dharma"},
{0xe476, false, "diagram next|cells|chart|diagram|flowchart|gantt|next|process|row|sequence|subtask|successor|table|task"},
{0xe477, false, "diagram predecessor|cells|chart|dependency|gantt|predecessor|previous|project|row|schedule|subtask|table|task|timeline"},
{0xf542, false, "diagram project|chart|connections|diagram|flowchart|graph|network|nodes|pert|planning|process|project|statistics|workflow"},
{0xe47a, false, "diagram successor|cells|chart|dependency|diagram|gantt|next|row|subtask|successor|table|task"},
{0xf219, false, "diamond|ace|card|cards|diamond|diamond suit|game|gem|gemstone|jewel|luxury|playing card|poker|precious|sparkle|suit"},
{0xf5eb, false, "diamond turn right|arrow|direction|map|navigation|right turn|road|route|sign|traffic|turn"},
{0xf522, false, "dice|board game|chance|cube|dice|dice game|die|gambling|game|gaming|luck|random|roll|tabletop|throw"},
{0xf6cf, false, "dice d20|Dungeons & Dragons|chance|d&d|d20|dice|dnd|fantasy|game|role-playing|roll|rpg|tabletop|twenty-sided"},
{0xf6d1, false, "dice d6|Dungeons & Dragons|RPG|chance|d&d|dice|die|dnd|fantasy|gambling|game|gaming|role-playing|roll|six-sided|tabletop"},
{0xf523, false, "dice five|board game|chance|dice|dice game|die|die face 5|five|gambling|game|luck|random|roll|tabletop|throw"},
{0xf524, false, "dice four|4|board game|chance|dice|dice face|die|four|gambling|game|luck|roll|tabletop"},
{0xf525, false, "dice one|chance|dice|dice roll|die|dot|face one|gambling|game|luck|number one|one|pip|random|roll|single dot"},
{0xf526, false, "dice six|board game|chance|dice|dice game|die|die face 6|gambling|game|probability|random|roll|six|six-sided|tabletop"},
{0xf527, false, "dice three|board game|chance|dice|dice game|die|gambling|game|luck|number three|random|roll|tabletop|three"},
{0xf528, false, "dice two|board game|chance|dice|dice game|die face 2|gambling|game|luck|play|random|roll|tabletop|throw|two"},
{0xf7fa, false, "disease|bacteria|cancer|contagion|coronavirus|covid-19|epidemic|flu|health|illness|infection|medical|pandemic|pathogen|sickness|symptom|virus"},
{0xe163, false, "display|computer|desktop|device|display|electronic|imac|interface|lcd|led|monitor|panel|screen|tech|visual"},
{0xf529, false, "divide|arithmetic|calculation|divide|divide symbol|division|division sign|fraction|math|math operation|math symbol|operator|quotient|÷"},
{0xf471, false, "dna|biologist|biology|chromosome|dna|double helix|gene|genetic|genetics|genome|helix|heredity|life|molecule|protein|science"},
{0xf6d3, false, "dog|animal|bark|canine|companion|dog|domestic animal|mammal|pet|pooch|puppy|woof"},
{0x24, false, "dollar sign|budget|cash|cost|currency|dollar|dollar sign|finance|income|investment|money|payment|premium|price|revenue|salary"},
{0xf472, false, "dolly|carry|cart|delivery|dolly|hand truck|moving|shipping|transport|trolley|warehouse"},
{0xe169, false, "dong sign|cash|currency|currency symbol|dong|finance|money|payment|vietnam|vietnamese currency"},
{0xf52a, false, "door closed|access|barrier|closed|door|doorway|entrance|exit|locked|privacy|secure"},
{0xf52b, false, "door open|access|door|doorway|entrance|entry|exit|open|open door|passage|welcome"},
{0xf4ba, false, "dove|bird|dove|flying|freedom|love|nature|peace|symbol|white bird|wildlife"},
{0xf422, false, "down left and up right to center|center|collapse|compress|contract|fullscreen|inward|minimize|reduce|resize|scale|shrink|size|smaller|zoom out"},
{0xf309, false, "down long|arrow|arrow-down|arrow-pointing-down|download|download-arrow|download-button|downward|long-arrow-down|save"},
{0xf019, false, "download|arrow down|download|export|get file|hard drive|import|retrieve|save|transfer"},
{0xf6d5, false, "dragon|Dungeons & Dragons|creature|d&d|dnd|dragon|fairy tale|fantasy|fire|legend|lizard|medieval|monster|mythical|serpent"},
{0xf5ee, false, "draw polygon|anchors|drawing|geometry|graphic|lines|object|path|polygon|shape|vector"},
{0xf043, false, "droplet|blood|drip|drop|droplet|fluid|liquid|moisture|oil|raindrop|sweat|tear|water|waterdrop"},
{0xf5c7, false, "droplet slash|blocked|cancel|disabled|drop|droplet|muted|no drop|no water|off|raindrop|remove|slash|stop|waterdrop"},
{0xf569, false, "drum|band|beat|drum|drummer|drums|drumsticks|instrument|kit|music|musical instrument|percussion|rhythm|snare|sound"},
{0xf56a, false, "drum steelpan|Caribbean|band|calypso|festival|instrument|music|pan drum|percussion|sound|steel drum|steelpan|tropical"},
{0xf6d7, false, "drumstick bite|barbecue|bite|bone|chicken|dinner|drumstick|food|grilled|leg|meat|poultry|snack|turkey"},
{0xf44b, false, "dumbbell|dumbbell|exercise|fitness|gym|lifting|muscle|sports|strength|training|weight|weightlifting|workout"},
{0xf793, false, "dumpster|bin|commercial waste|container|dumpster|dumpster bin|garbage|junk|refuse|rubbish|trash|trash container|waste"},
{0xf794, false, "dumpster fire|blaze|burning|chaotic|crisis|danger|disaster|dumpster|emergency|euphemism|fire|flames|hot|meltdown|trash|waste"},
{0xf6d9, false, "dungeon|Dungeons & Dragons|RPG|castle|d&d|dnd|door|dungeon|dungeon door|entrance|fantasy|fortress|gate|medieval|role-playing"},
{0x45, false, "e|alphabet e|capital e|character e|e symbol|latin letter e|letter e|lowercase e"},
{0xf2a4, false, "ear deaf|accessibility|deaf|disability|ear|hearing impaired|hearing loss|mute|no sound|sign language"},
{0xf2a2, false, "ear listen|amplify|audio|deaf|ear|earphone|headphone|headset|hearing|hearing aid|listen|listen closely|sound|volume"},
{0xf57c, false, "earth africa|africa|continent|earth|geography|global|globe|gps|international|localize|location|map|place|planet|travel|world"},
{0xf57d, false, "earth americas|america|americas|earth|global|globe|gps|language|localize|location|map|place|planet|translate|travel|world"},
{0xf57e, false, "earth asia|asia|australia|earth|global|globe|gps|language|localize|location|map|place|planet|translate|travel|world"},
{0xf7a2, false, "earth europe|country|earth|europe|global|globe|gps|language|localize|location|map|place|planet|translate|travel|world"},
{0xe47b, false, "earth oceania|australia|continent|country|earth|geography|global|globe|island|location|map|melanesia|micronesia|new zealand|oceania|pacific|polynesia|region|travel|world"},
{0xf7fb, false, "egg|baking|breakfast|chicken|egg|farm|food|fresh|natural|omelette|oval|poultry|protein|shell|yolk"},
{0xf052, false, "eject|abort|cancel|cd|disc|discard|eject|eject button|exit|media|remove|stop|unload"},
{0xe16d, false, "elevator|accessibility|building transport|elevator|elevator button|elevator car|elevator shaft|hoist|lift|passenger lift|people mover|vertical transport|wheelchair accessible"},
{0xf141, false, "ellipsis|actions|dots|dots menu|ellipsis|horizontal dots|kebab|menu|more|navigation|options|overflow|settings|three dots|vertical dots"},
{0xf142, false, "ellipsis vertical|dots|kebab|list|menu|more|nav|navigation|options|overflow|reorder|settings|vertical dots"},
{0xf0e0, false, "envelope|contact|correspondence|e-mail|email|envelope|inbox|letter|mail|message|newsletter|notification|postal|receive|send|support"},
{0xe4e8, false, "envelope circle check|approved|check|confirmed|delivered|email|envelope|mail|ok|okay|read|sent|success|validated|verified"},
{0xf2b6, false, "envelope open|communication|correspondence|e-mail|email|inbox|letter|mail|message|newsletter|notification|offer|open mail|support"},
{0xf658, false, "envelope open text|communication|correspondence|document|e-mail|email|inbox|letter|mail|message|newsletter|notification|open mail|reading mail|support|update"},
{0xf674, false, "envelopes bulk|bulk mail|correspondence|envelopes|letters|mail|mailing|newsletter|package|post office|postal|send|shipment|usps"},
{0x3d, false, "equals|arithmetic|balance|comparison|equal sign|equal to|equals|equals sign|equation|equivalence|match|math"},
{0xf12d, false, "eraser|art|clean|correction|delete|drawing|erase|pencil|remove|rubber|wipe"},
{0xf796, false, "ethernet|cable|cat5|cat6|connection|ethernet|ethernet cable|ethernet port|hardware|internet|lan|network|network cable|rj45|wired|wired connection"},
{0xf153, false, "euro sign|cash|currency|euro|euro currency|euro sign|european currency|financial|money|payment|symbol"},
{0x21, false, "exclamation|alert|attention|caution|danger|emphasis|error|exclamation|exclamation mark|important|notice|notification|notify|problem|punctuation|required|symbol|urgent|warning"},
{0xf065, false, "expand|arrows|bigger|enlarge|expand|fullscreen|fullscreen mode|increase|maximize|open|resize|scale|stretch|viewfinder|zoom"},
{0xe4e9, false, "explosion|bang|blast|blast-off|boom|burst|crash|detonation|eruption|explosion|impact|shockwave"},
{0xf06e, false, "eye|eye|focus|glimpse|look|observe|peek|see|sight|stare|view|visible|vision|watch"},
{0xf1fb, false, "eye dropper|color|dropper|eyedropper|eyedropper-tool|paint|pick|pipette|sample|select|tool"},
{0xf2a8, false, "eye low vision|accessibility|blind|disability|eye|eye disability|impaired vision|low vision|sight|vision loss|visual impairment"},
{0xf070, false, "eye slash|blocked|conceal|disable|eye|hidden|hide|invisible|no-view|obscured|privacy|privacy-mode|security|toggle|unseen"},
{0x46, false, "f|alphabet f|character f|f glyph|f symbol|latin letter f|letter|letter f"},
{0xf556, false, "face angry|angry|annoyed|disapprove|displeased|emoticon|emotion|face|frowning|frustrated|glare|mad|rage|upset"},
{0xf567, false, "face dizzy|confused|dazed|dizzy|dizzy face|emoticon|face|faint|sick|unwell|woozy|woozy face"},
{0xf579, false, "face flushed|bashful|blushing|embarrassed|emoticon|face|flushed|overwhelmed|red-faced|shy|surprised"},
{0xf119, false, "face frown|disappointed|disapprove|displeased|emoticon|face|frown|frowning face|negative|sad|unhappy|unhappy emoji|unhappy face"},
{0xf57a, false, "face frown open|disappointed|disapprove|displeased|emoticon|expression|face|frown|negative|open mouth|sad|unhappy|upset"},
{0xf57f, false, "face grimace|anxious|awkward|cringe|emoticon|expression|face|grimace|grimacing face|nervous|teeth|uncomfortable|uneasy|worried"},
{0xf580, false, "face grin|amusement|cheerful|emoji|expression|face|grin|grinning|happy|joy|laugh|pleased|smile"},
{0xf582, false, "face grin beam|beam|cheerful|delighted|emoticon|eyes closed|face|grin|happy|joy|laugh|open mouth|smile|smiling face"},
{0xf583, false, "face grin beam sweat|anxious|awkward|beam|embarrassed|emoticon|face|grin|nervous|relief|smile|sweat|uncomfortable"},
{0xf584, false, "face grin hearts|admiration|adoration|affection|crush|emoji|emoticon|face|heart-eyes|infatuation|love|smile|smiling"},
{0xf585, false, "face grin squint|amusement|emoticon|face|grin|happy|joy|laugh|laughing|playful|satisfied|smile|squint"},
{0xf586, false, "face grin squint tears|emoji|face|funny|grin|happy|humor|joy|laugh|laughing|rofl|rolling on the floor laughing|smile|squint|tears"},
{0xf587, false, "face grin stars|amazed|celebrity|emoticon|excited|face|grin|happy|impressed|joyful|smiling|star|star-struck|starry-eyed|vip"},
{0xf588, false, "face grin tears|LOL|crying with laughter|emoji|face|funny|grin|happy|joy|laugh|laughing|smile|tear|tears of joy"},
{0xf589, false, "face grin tongue|cheeky|emoji|face|funny|goofy|grin|joking|laugh|lighthearted|playful|silly|teasing|tongue"},
{0xf58a, false, "face grin tongue squint|emoji|face|funny|goofy|grin|joking|laugh|playful|silly|silly face|squint|teasing|tongue"},
{0xf58b, false, "face grin tongue wink|LOL|cheeky|emoji|emoticon|face|funny|grin|joke|laugh|playful|silly|teasing|tongue|wink|winking face"},
{0xf581, false, "face grin wide|big eyes|cheerful|emoticon|excited|face|grin|happy|joyful|laugh|open mouth|smile|wide grin"},
{0xf58c, false, "face grin wink|cheeky|emoticon|face|flirt|grin|happy|mischievous|playful|smile|wink"},
{0xf596, false, "face kiss|affection|beso|blowing a kiss|emoji|face|flirt|hug and kiss|kiss|kissing face|love|romantic|smooch"},
{0xf597, false, "face kiss beam|affection|blowing kiss|emoji|emoticon|eyes closed|face|happy|kiss|kissing face|love|smile|smooch"},
{0xf598, false, "face kiss wink heart|affection|blowing a kiss|emoji|emoticon|face|flirt|heart|kiss|love|smooch|wink"},
{0xf599, false, "face laugh|amusement|chuckle|emoji|face|funny|grin|happy|humor|joy|laugh|laughter|smile"},
{0xf59a, false, "face laugh beam|amusement|beaming face|cheerful|emoji|fun|grin|happy|humor|joy|laugh|laughing face|laughter|smile|smiling eyes"},
{0xf59b, false, "face laugh squint|LOL|amused|emoticon|face|funny|grin|happy|joy|laugh|laughing|smile|squint"},
{0xf59c, false, "face laugh wink|LOL|emoticon|face|funny|happy|humor|joking|laugh|playful|smile|wink"},
{0xf11a, false, "face meh|apathetic|bland|deadpan|default|emoticon|emotion|expression|face|indifferent|meh|neutral|neutral face|rating|unamused|unimpressed"},
{0xf5a4, false, "face meh blank|blank|deadpan|emotionless|expressionless|face|indifferent|meh|neutral|no mouth|quiet|silent|stoic|unimpressed"},
{0xf5a5, false, "face rolling eyes|annoyed|dismissive|emoji|exasperated|expression|eye roll|eyeroll|face|reaction|rolling eyes|sarcastic|unimpressed"},
{0xf5b3, false, "face sad cry|crying|emoticon|emotional|face|sad face|sobbing|tearful|tears|unhappy|upset"},
{0xf5b4, false, "face sad tear|crying|distress|emoticon|emotional|face|grief|sad|sorrow|tear|tears|unhappy|upset"},
{0xf118, false, "face smile|approve|cheerful|content|emoticon|face|friendly|happy|joy|pleased|positive|satisfied|slightly smiling face|smile"},
{0xf5b8, false, "face smile beam|beaming|blush|cheerful|delighted|emoticon|face|grin|happiness|happy|joyful|pleased|positive|smile|smiling"},
{0xf4da, false, "face smile wink|cheeky|emoticon|face|flirt|fun|happy|mischievous|playful|smile|teasing|wink|winking face"},
{0xf5c2, false, "face surprise|astonished|emoji|expression|face|open mouth|reaction|shocked|startled|surprised|wow"},
{0xf5c8, false, "face tired|drained|emoticon|exhausted|face|fatigued|frustrated|grumpy|sleepy|tired|upset|weary|worn out"},
{0xf863, false, "fan|air|airflow|blade|blower|breeze|ceiling fan|cool air|cooling|electric fan|fan|hot air|ventilation"},
{0xe005, false, "faucet|bathroom|drinking|drip|household|hygiene|kitchen|plumbing|potable|potable water|sanitation|sink|tap|water"},
{0xe006, false, "faucet drip|bathroom|drinking|drip|faucet|household|hygiene|kitchen|leak|plumbing|potable|potable water|sanitation|sink|tap|water"},
{0xf1ac, false, "fax|business|communication|copy|document|facsimile|fax|fax machine|message|office|send|transmit"},
{0xf52d, false, "feather|bird|delicate|feather|flight|light|pen|plumage|plume|plume|plume|plume|quill|writing"},
{0xf56b, false, "feather pointed|bird|calligraphy|feather|ink|light|pen|plume|plume feather|plume pen|quill|writing"},
{0xe4ea, false, "ferry|barge|boat|commute|crossing|ferry|ferryboat|passenger|ship|transport|travel|vehicle|watercraft"},
{0xf15b, false, "file|blank|cv|document|file|form|new|page|page facing up|paper|pdf|report|resume|sheet|text"},
{0xf56d, false, "file arrow down|archive|arrow-down|document|download|export|file|import|insert|save|upload"},
{0xf574, false, "file arrow up|arrow-up|document|export|file|import|page|save|send|update|upgrade|upload"},
{0xf1c7, false, "file audio|audio|document|file|mp3|music|play|recording|sound|track|waveform"},
{0xe5a0, false, "file circle check|approved|check|checkmark|complete|confirm|document|done|file|ok|okay|paper|success|validated|verified"},
{0xe4eb, false, "file circle exclamation|alert|document|error|exclamation|failed|file|issue|paper|problem|warning"},
{0xe4ed, false, "file circle minus|cancel|circle|delete|discard|document|erase|file|file-remove|minus|paper|remove|subtract"},
{0xe494, false, "file circle plus|add|blank|circle|create|document|file|insert|new|page|paper|pdf|plus|sheet|upload"},
{0xe4ef, false, "file circle question|document|file|file-help|file-question|help|info|inquiry|paper|question|support|unknown"},
{0xe5a1, false, "file circle xmark|cancel|close|cross|delete|document|error|file|invalid|no|paper|reject|remove|xmark"},
{0xf1c9, false, "file code|code|css|development|document|file|html|markup|mysql|programming|script|sql"},
{0xf56c, false, "file contract|agreement|binding|contract|deal|document|file|form|legal|paperwork|signature|terms"},
{0xf6dd, false, "file csv|comma-separated|csv|data|document|export|file|import|spreadsheet|table|values"},
{0xf1c3, false, "file excel|csv|data|document|excel|microsoft excel|numbers|sheet|spreadsheet|table|workbook|xls|xlsx"},
{0xf56e, false, "file export|document|download|export|file|output|save|send|share|transfer|upload"},
{0xe697, false, "file fragment|block|chunk|data|document|file|fragment|incomplete|partial|piece|segment"},
{0xe698, false, "file half dashed|dashed|data|document|file|form|fragment|incomplete|outline|partial|piece|sheet"},
{0xf1c5, false, "file image|document|document with image|file|graphic|image|image file|img|jpg|photo|photo file|picture|picture file|png"},
{0xf56f, false, "file import|add|bring in|document|file|import|input|insert|load|transfer|upload"},
{0xf570, false, "file invoice|account|bill|billing|charge|document|expense|financial|invoice|payment|receipt|statement|transaction"},
{0xf571, false, "file invoice dollar|$|accounting|bill|charge|cost|document|dollar|earnings|finance|invoice|money|payment|receipt|revenue|salary|usd"},
{0xf15c, false, "file lines|document|file|file-text|form|invoice|new document|page|paper|pdf|report|sheet|text"},
{0xf477, false, "file medical|chart|clinic|document|file|health|healthcare|history|hospital|medical|patient|prescription|record|report"},
{0xf1c1, false, "file pdf|acrobat|attachment|document|ebook|file|pdf|portable document format|preview|report|save"},
{0xf31c, false, "file pen|compose|document|draft|edit|file|memo|modify|note|pen|pencil|text|update|write"},
{0xf1c4, false, "file powerpoint|deck|document|file|keynote|microsoft|office|powerpoint|ppt|presentation|slide|slideshow"},
{0xf572, false, "file prescription|document|drugs|healthcare|medical|medication|medicine|pharmacy|prescription|rx|script|treatment"},
{0xe4f0, false, "file shield|antivirus|data|defense|document|file|locked|privacy|protect|protection|safe|safeguard|safety|secure|security|shield"},
{0xf573, false, "file signature|John Hancock|approval|autograph|contract|document|endorsement|handwriting|name|sign|signature"},
{0xf1c8, false, "file video|clip|file|film|footage|m4v|media|movie|mp4|play|playback|recording|video"},
{0xf478, false, "file waveform|audio|data|document|file|music|recording|signal|sound|track|wave|waveform"},
{0xf1c2, false, "file word|doc|document|editable|file|letter|office|page|paper|report|text|word|word processing|writing"},
{0xf1c6, false, "file zipper|.zip|archive|archive file|bundle|compress|compressed|compression|download|extractor|file|folder|packed|packing|zip|zipped file"},
{0xf575, false, "fill|bucket|bucket fill|color fill|coloring|fill|paint|paint bucket|paint can|paint tool"},
{0xf576, false, "fill drip|bucket|color|drip|drop|liquid|paint|paint bucket|paint drip|paint spill|pouring|spill"},
{0xf008, false, "film|cinema|clip|film|film strip|footage|frames|media|movie|movie reel|projector|recording|video"},
{0xf0b0, false, "filter|adjust|criteria|filter|funnel|narrow|options|refine|selection|settings|sort"},
{0xf662, false, "filter circle dollar|cost|dollar|filter|finance|money|options|payment|premium|price|sort"},
{0xe17b, false, "filter circle xmark|block|cancel|clear|close|delete|erase|filter|funnel|options|remove|reset|stop|xmark"},
{0xf577, false, "fingerprint|authentication|biometric|fingerprint|id|identification|lock|privacy|security|touch|unique|unlock"},
{0xf06d, false, "fire|blaze|burn|burning|campfire|fire|flame|flame icon|flame symbol|heat|hot|ignition|popular|spark|tool|wildfire"},
{0xe4f1, false, "fire burner|burner|burner flame|cook|cooking|cooktop|fire|flame|gas|heat|hob|kitchen|range|stove"},
{0xf134, false, "fire extinguisher|blaze|burn|emergency|extinguisher|fire|fire extinguisher|firefighting|flame|heat|hot|put out|quench|rescue|safety|smoke"},
{0xf7e4, false, "fire flame curved|blaze|burn|burning|fire|fire hazard|flame|flame icon|flame symbol|heat|hot|ignition|popular|wildfire"},
{0xf46a, false, "fire flame simple|blaze|burn|caliente|energy|fire|flame|gas|heat|hot|ignition|warm"},
{0xf578, false, "fish|Pisces|animal|aquarium|aquatic|fish|fishing|goldfish|marine|ocean|pet|seafood|swimming|zodiac"},
{0xe4f2, false, "fish fins|Pisces|aquatic|fins|fish|fishing|marine|ocean|seafood|swim|water"},
{0xf024, false, "flag|alert|banner|country|flag|marker|nation|notification|notify|pennant|pole|report|signal|symbol|waving"},
{0xf11e, false, "flag checkered|checkered|chequered|competition|end|finish|flag|flag icon|flagpole|motorsport|race|race flag|racing|signal|victory|winner"},
{0xf74d, false, "flag usa|american flag|betsy ross|country|flag|national emblem|old glory|patriotism|stars|stars and stripes|stripes|united states|usa"},
{0xf0c3, false, "flask|beaker|chemistry|experiment|flask|lab|laboratory|liquid|potion|research|science|test tube|vial"},
{0xe4f3, false, "flask vial|ampule|beaker|chemical|chemistry|experiment|experimental|flask|lab|laboratory|liquid|potion|science|test|test tube|vial"},
{0xf0c7, false, "floppy disk|archive|backup|computer|data|disk|floppy|floppy disk|legacy|memory|old school|retro|save|save icon|storage"},
{0xe184, false, "florin sign|cash|currency|euro alternative|finance|financial symbol|florin|money|payment|symbol|trade"},
{0xf07b, false, "folder|archive|directory|document|documents|file|file folder|file organizer|files|filing|folder|folder icon|folder symbol|storage"},
{0xe185, false, "folder closed|archive|closed folder|directory|documents|file cabinet|file folder|filing|folder|organize|storage"},
{0xf65d, false, "folder minus|archive|delete|directory|document|file|folder|folder-remove|minus|negative|reduce|remove|remove-file|subtract"},
{0xf07c, false, "folder open|archive|directory|document|file|file folder|folder|folder icon|folder open|folder view|open|open file folder|open folder"},
{0xf65e, false, "folder plus|add|archive|create|directory|document|expand|file|folder|insert|new|open|plus|positive|save|upload"},
{0xf802, false, "folder tree|archive|directory|documents|file|files|folder|folders|hierarchy|organization|structure|tree"},
{0xf031, false, "font|alphabet|character|font style|glyph|letter|print|script|text|type|typeface|typography|writing"},
{0xf2b4, false, "font awesome|branding|fa|font-awesome|icon set|logo|typeface"},
{0xf44e, false, "football|american football|ball|field|football|game|gridiron|helmet|nfl|pigskin|quarterback|sport|sports|tackle|team|touchdown"},
{0xf04e, false, "forward|advance|ahead|arrow|continue|double|fast|fast-forward|forward|move|next|play|right|skip"},
{0xf050, false, "forward fast|arrow|fast-forward|forward|media|next|next scene|next track|playback|quick|skip|speed|triangle"},
{0xf051, false, "forward step|advance|end|fast-forward|forward|last|move ahead|next|skip|step"},
{0xe18f, false, "franc sign|Swiss franc|currency|currency symbol|franc|franc currency|franc icon|franc money|franc sign|franc symbol|money"},
{0xf52e, false, "frog|amphibian|bullfrog|croak|frog|green|hop|kermit|kiss|leap|pond|prince|ribbit|tadpole|toad|wart"},
{0xf1e3, false, "futbol|ball|football|football game|football sport|soccer|soccer ball|soccer ball graphic|soccer ball icon|soccer ball symbol|soccer game|soccer sport|sports"},
{0x47, false, "g|alphabet|capital g|character|glyph|letter g|lowercase g|text symbol|typography"},
{0xf11b, false, "gamepad|arcade|console|controller|d-pad|game controller|gamepad|gaming|joystick|play|video game|video games"},
{0xf52f, false, "gas pump|car|diesel|filling station|fuel|fuel pump|gas|gas dispenser|gas nozzle|gas pump handle|gas station|gasoline|petrol|petrol station|pump|refuel"},
{0xf624, false, "gauge|dashboard|dial|gauge|gauge cluster|indicator|measurement|meter|odometer|performance|speed|speedometer|tachometer"},
{0xf625, false, "gauge high|dashboard|dial|fast|gauge|indicator|measurement|meter|performance|rpm|speed|speedometer|tachometer"},
{0xf629, false, "gauge simple|dashboard|dial|fast|gauge|indicator|instrument|measurement|meter|odometer|performance|speed|speedometer"},
{0xf62a, false, "gauge simple high|dashboard|dial|fast|gauge|high|indicator|measurement|meter|performance|quick|speed|speedometer"},
{0xf0e3, false, "gavel|auction|court|decision|gavel|hammer|judge|judge's hammer|justice|law|lawyer|legal|ruling|verdict"},
{0xf013, false, "gear|adjust|cog|cogwheel|configuration|control|gear|mechanical|modify|options|preferences|settings|setup|sprocket|tool|wheel"},
{0xf085, false, "gears|adjust|cog|cogwheel|configuration|gears|machinery|mechanical|options|process|settings|sprocket|system|tools|wheel"},
{0xf3a5, false, "gem|crystal|diamond|emerald|gem|gem stone|gemstone|jewel|jewelry|luxury|precious|ruby|sapphire|treasure|valuable"},
{0xe849, false, "gemini|air sign|astrology|constellation|gemini|horoscope|june|may|sign|stars|twin|twins|zodiac"},
{0xf22d, false, "genderless|androgynous|asexual|gender|gender neutral|genderless|identity|neutral|nonbinary|sexless|unisex"},
{0xf6e2, false, "ghost|apparition|blinky|clyde|creature|face|fantasy|floating|ghost|halloween|inky|monster|pacman|phantom|pinky|specter|spirit|spooky|supernatural|wraith"},
{0xf06b, false, "gift|birthday|box|celebration|christmas|festive|generosity|gift|giving|holiday|party|present|surprise|wrapped|xmas"},
{0xf79c, false, "gifts|box|celebration|christmas|generosity|gift|giving|holiday|party|present|surprise|wrapped|xmas"},
{0xe4f4, false, "glass water|beverage|cold drink|cup|drink|glass|hydration|liquid|potable|refreshment|water"},
{0xe4f5, false, "glass water droplet|beverage|clean|drink|droplet|glass|hydration|liquid|potable|pure|refreshment|water"},
{0xf530, false, "glasses|eyeglasses|eyewear|frames|glasses|hipster|nerd|reading|sight|spectacles|vision"},
{0xf0ac, false, "globe|coordinates|country|earth|global|globe|gps|internet|language|localize|location|map|meridians|network|online|place|planet|translate|travel|world|www"},
{0xf450, false, "golf ball tee|ball|golf|golf ball|golf club|golf course|golf game|golf shot|golf swing|golf tee|golfing|sport|sports equipment|tee"},
{0xf664, false, "gopuram|architecture|entrance|gateway|hinduism|landmark|monument|ornate|religious|sacred|south india|temple|tower"},
{0xf19d, false, "graduation cap|academic|cap|celebration|ceremony|college|commencement|diploma|education|graduate|graduation|hat|learning|mortarboard|school|student"},
{0x3e, false, "greater than|arithmetic|comparison|comparison operator|greater than|greater-than sign|inequality|math|more than|operator|symbol"},
{0xf532, false, "greater than equal|arithmetic|compare|comparison|greater than or equal to|inequality|logic|math|math symbol|operator|symbol"},
{0xf58d, false, "grip|UI|control|dots|drag|drop|grab|grip|handle|interface|menu|move|reorder|resize|toolbar|widget"},
{0xf7a4, false, "grip lines|UI control|drag|drag handle|draggable|drop|grab|grabber|grip|handle|interface element|move|reorder|resize"},
{0xf7a5, false, "grip lines vertical|UI element|affordance|control|drag|drop|grab|grip|handle|interface|move|reorder|resize|slider|vertical lines"},
{0xf58e, false, "grip vertical|drag|drag handle|drop|grab|grabber|grip|handle|interface element|move|reorder|resize|vertical bars"},
{0xe4f6, false, "group arrows rotate|community|cycle|engagement|loop|refresh|reload|repeat|rotate|spin|sync|update"},
{0xe19a, false, "guarani sign|Paraguay|cash|currency|currency sign|financial|guarani|money|payment|sign|symbol"},
{0xf7a6, false, "guitar|acoustic|band|chord|electric|guitar|instrument|melody|music|musician|rock|rock and roll|song|stringed|strings"},
{0xe19b, false, "gun|defense|firearm|firearm weapon|gunfire|handgun|pistol|revolver|security|shooter|shooting|trigger|weapon"},
{0x48, false, "h|alphabet|capital h|character|letter h|lowercase h|symbol|typography"},
{0xf6e3, false, "hammer|DIY|building|carpentry|construction|equipment|fix|hammer|hardware|maintenance|manual tool|repair|tool|toolset|workshop"},
{0xf665, false, "hamsa|amulet|blessing|evil eye|good luck|hand|islam|jewish|judaism|middle east|muslim|north africa|protection|spirituality|talisman"},
{0xf256, false, "hand|backhand|gesture|halt|hand|high five|palm|raised hand|request|roshambo|signal|stop|wave"},
{0xf255, false, "hand back fist|closed hand|fist|game|gesture|hand|punch|rock|roshambo|strike"},
{0xf461, false, "hand dots|allergy|dermatology|dots|eczema|freckles|hand|hives|irritation|palm|pox|rash|skin|spots"},
{0xf6de, false, "hand fist|Dungeons & Dragons|boxing|clenched|combat|d&d|dnd|fantasy|fight|fist|hand|ki|martial arts|monk|power|punch|raised fist|resistance|strength|unarmed combat"},
{0xf4bd, false, "hand holding|assistance|carrying|grasp|hand|help|hold|lift|offering|palm|protection|support"},
{0xf4c0, false, "hand holding dollar|cash|cost|dollar|donate|donation|earnings|finance|giving|investment|money|payment|premium|price|revenue|salary|wage"},
{0xf4c1, false, "hand holding droplet|blood|care|carry|covid-19|drop|drought|grow|hand|health|lift|protection|sanitation|support|water"},
{0xe4f7, false, "hand holding hand|care|compassion|friendship|give|help|hold|partnership|protect|solidarity|support|teamwork|together|unity"},
{0xf4be, false, "hand holding heart|care|charity|compassion|donate|gift|giving|hand|heart|help|holding|kindness|love|support|volunteer"},
{0xe05c, false, "hand holding medical|aid|assistance|care|charity|covid-19|donate|healing|health|help|medical|protection|support"},
{0xf258, false, "hand lizard|claw|game|hand gesture|lizard|reptile|rock paper scissors|roshambo|sign"},
{0xf806, false, "hand middle finger|disrespect|finger|flip the bird|gesture|hand|hate|insult|middle finger|obscene|offensive|rude|swear|vulgar"},
{0xf25b, false, "hand peace|gesture|hand|peace|peace sign|sign|symbol|truce|two fingers|v|victory|victory hand"},
{0xf0a7, false, "hand point down|arrow|click|cursor|direction|down|finger|gesture|hand|indicator|point|pointing|select|tap"},
{0xf0a5, false, "hand point left|arrow|back|direction|finger|gesture|hand|indicate|left|point|pointer|previous|select"},
{0xf0a4, false, "hand point right|arrow|direction|finger|forward|gesture|hand|next|point|pointer|right"},
{0xf0a6, false, "hand point up|click|direction|finger|gesture|hand|index|indicate|point up|pointing up|request|select|up|upgrade"},
{0xf25a, false, "hand pointer|click|cursor|gesture|hand|hand-cursor|interact|pointer|select|tap|touch"},
{0xf257, false, "hand scissors|cut|fingers|game|hand gesture|peace sign|rock paper scissors|roshambo|scissors|victory"},
{0xe05d, false, "hand sparkles|clean|disinfect|fresh|glow|handwashing|hygiene|magic|palm|sanitizer|shiny|sparkle|wash"},
{0xf259, false, "hand spock|finger|gesture|greeting|hand|hello|live long|peace|prosper|salute|sci-fi|sign|spock|star trek|vulcan|vulcan salute"},
{0xe4f8, false, "handcuffs|arrest|criminal|cuffs|detention|handcuffs|jail|law enforcement|police|prisoner|restraint|security|shackles|wrist"},
{0xf2a7, false, "hands|asl|communication|deaf|fingers|gesture|hand signal|hands|manual|palm|sign language|translate"},
{0xf2a3, false, "hands asl interpreting|asl|communication|deaf|fingerspelling|gesture|hand|interpreting|language|sign language|translate"},
{0xe4f9, false, "hands bound|abduction|bound|captivity|handcuffs|hands tied|kidnapping|prisoner|restrained|tied|wrists"},
{0xe05e, false, "hands bubbles|bubbles|clean|germ|handwashing|health|hygiene|protection|sanitizer|soap|wash"},
{0xe1a8, false, "hands clapping|applause|approval|celebrate|cheer|clap|clapping|congratulations|hands|ovation|praise"},
{0xf4c2, false, "hands holding|assistance|care|carry|giving|hands|help|hold|lift|offering|protection|support"},
{0xe4fa, false, "hands holding child|care|child|family|give|guardian|help|hold|love|nurture|parent|protect|safety|shelter|support"},
{0xe4fb, false, "hands holding circle|care|charity|circle|community|giving|hands|help|holding|protection|safety|support"},
{0xf684, false, "hands praying|blessing|devotion|faith|gesture|hands|hope|kneel|meditate|pray|prayer|praying|religion|spirituality|worship"},
{0xf2b5, false, "handshake|agreement|alliance|collaboration|contract|cooperation|deal|greeting|handshake|meeting|negotiation|partnership|trust|welcome"},
{0xf4c4, false, "handshake angle|agreement|aid|assistance|collaboration|cooperation|deal|greeting|handshake|partnership|support|teamwork|volunteering"},
{0xe060, false, "handshake slash|avoid|broken|cancel|covid-19|disabled|handshake|no handshake|prevent|prohibition|social distance|stop"},
{0xf6e6, false, "hanukiah|candelabrum|candle|candlestick|celebration|dreidel|eight-branch menorah|festival|hanukiah|hanukkah|holiday|jewish|judaism|light|menorah|religious symbol|ritual|tradition"},
{0xf0a0, false, "hard drive|backup|computer|data|device|disk|drive|hard disk|hard drive|hardware|hdd|save|storage|storage device"},
{0x23, false, "hashtag|grid|hashtag|instagram|label|metadata|number sign|pound sign|sharp|social media|tag|topic|trending|twitter"},
{0xf8c0, false, "hat cowboy|buckaroo|cattle|cowboy|frontier|hat|horseman|jackeroo|old west|pardner|ranch|rancher|rodeo|western|wrangler"},
{0xf8c1, false, "hat cowboy side|buckaroo|cowboy|frontier|hat|horseman|old west|pardner|ranch|rancher|rodeo|side profile|western|wild west|wrangler"},
{0xf6e8, false, "hat wizard|accessory|costume|d&d|dnd|dungeons & dragons|fantasy|halloween|hat|headwear|mage|magic|pointy hat|witch|wizard"},
{0xe061, false, "head side cough|cold|cough|covid-19|flu|germs|health|illness|infection|lungs|medical|respiratory|sick|symptom|virus"},
{0xe062, false, "head side cough slash|cough|covid-19|germs|health|illness|infection|lungs|respiratory|sick|symptom|virus"},
{0xe063, false, "head side mask|airborne|breath|coronavirus|covid-19|face mask|filter|flu|health|hygiene|infection|mask|medical mask|pandemic|pollution|protection|respirator|safety|sneeze|virus"},
{0xe064, false, "head side virus|cold|contagious|coronavirus|covid-19|disease|fever|flu|headache|illness|infection|pandemic|sick|symptom|virus"},
{0xf1dc, false, "heading|caption|format|header|heading|headline|label|section|text|title"},
{0xf025, false, "headphones|audio|audio device|earbuds|earphones|headphones|headset|listen|music|music player|sound|stereo"},
{0xf590, false, "headset|audio|call center|communication|customer service|gamer|gaming|headphones|headset mic|listen|live chat|microphone|sound|support|telemarketer"},
{0xf004, false, "heart|affection|card|emotion|favorite|heart|heart suit|like|love|passion|playing card|relationship|romance|symbol|valentine|wishlist"},
{0xe4fc, false, "heart circle bolt|bolt|cardiogram|cardiology|ekg|electric|energy|health|heart|heartbeat|love|medical|pacemaker|pulse"},
{0xe4fd, false, "heart circle check|approve|check|confirm|enabled|favorite|heart|love|ok|okay|positive|success|validate|verified"},
{0xe4fe, false, "heart circle exclamation|alert|attention|caution|error|exclamation|favorite|heart|important|love|warning"},
{0xe4ff, false, "heart circle minus|circle|delete|dislike|favorite|heart|love|minus|remove|subtract|unfavorite|unlike"},
{0xe500, false, "heart circle plus|add|care|favorite|follow|health|heart|like|love|new|plus|save|support"},
{0xe501, false, "heart circle xmark|cancel|close|delete|dislike|favorite|heart|love|negative|no|reject|remove|uncheck|xmark"},
{0xf7a9, false, "heart crack|break|breakup|broken heart|crushed|dislike|dumped|emotional pain|grief|heartbreak|hurt|love lost|lovesick|relationship|sadness|sorrow"},
{0xf21e, false, "heart pulse|cardiology|ekg|electrocardiogram|health|heart rate|heartbeat|lifeline|medical|monitor|pulse|rhythm|vital signs"},
{0xf533, false, "helicopter|aircraft|airwolf|apache|aviation|chopper|flight|fly|helicopter|military|rescue|rotorcraft|transport|travel|vehicle"},
{0xe502, false, "helicopter symbol|air ambulance|aircraft|chopper|helicopter|heliport|landing pad|medevac|rescue|rotorcraft|whirlybird"},
{0xf807, false, "helmet safety|caution|construction|hardhat|headgear|helmet|industrial|protection|safety|safety-gear|worker"},
{0xe503, false, "helmet un|UN|UN peacekeeper|blue helmet|helmet|international organization|military|peace mission|peacekeeper|peacekeeping|protective gear|soldier|united nations"},
{0xf312, false, "hexagon|badge|cell|emblem|geometry|hexagon|hexagonal|honeycomb|polygon|shape|six-sided|tile"},
{0xe699, false, "hexagon nodes|ai|artificial intelligence|cluster|connection|data|graph|hexagon|language|llm|machine learning|model|network|neural|neural network|nodes"},
{0xe69a, false, "hexagon nodes bolt|AI|LLM|artificial intelligence|bolt|cluster|connection|data|electric|graph|language|lightning|model|network|neural|nodes"},
{0xf591, false, "highlighter|annotate|color|draw|edit|emphasize|highlight|marker|note|pen|underline|write"},
{0xe507, false, "hill avalanche|avalanche|hazard|landslide|mountain|mudslide|natural disaster|slope|snow|snowslide|winter"},
{0xe508, false, "hill rockslide|avalanche|debris flow|earth movement|erosion|hill collapse|landslide|mudslide|natural disaster|rockslide|slope failure"},
{0xf6ed, false, "hippo|African animal|animal|fauna|hippo|hippopotamus|large animal|mammal|river horse|safari|wildlife"},
{0xf453, false, "hockey puck|hockey|ice|ice hockey|nhl|puck|puck shot|rink|sport|stick and puck|winter sport"},
{0xf7aa, false, "holly berry|berry|christmas|decoration|festive|flora|greenery|holiday|holly|plant|seasonal|winter|xmas"},
{0xf6f0, false, "horse|animal|equestrian|equine|foal|horse|livestock|mammal|mare|neigh|pony|racehorse|racing|stallion"},
{0xf7ab, false, "horse head|animal|equestrian|equus|foal|horse|livestock|mammal|mare|neigh|pony|stallion"},
{0xf0f8, false, "hospital|ER|ambulance|building|clinic|covid-19|doctor|emergency|health|healthcare|hospital|medical center|medicine|nurse|treatment"},
{0xf80d, false, "hospital user|covid-19|doctor|health professional|healthcare|hospital|medical|nurse|patient|primary care|staff|user"},
{0xf593, false, "hot tub person|bath|bathing|hot tub|jacuzzi|leisure|person|relaxation|soak|spa|wellness"},
{0xf80f, false, "hotdog|bun|chili|fast food|frankfurt|frankfurter|hot dog|hotdog|kosher|polish|sandwich|sausage|snack|street food|vienna|weiner"},
{0xf594, false, "hotel|accommodation|building|check-in|hospitality|hotel|inn|lodging|motel|overnight|resort|room|stay|travel|vacation"},
{0xf254, false, "hourglass|countdown|hourglass|hourglass not done|loading|minute|sand|stopwatch|time|timer|waiting"},
{0xf253, false, "hourglass end|complete|countdown|elapsed|end|finished|hourglass|hourglass done|sand|time|timer|waiting"},
{0xf252, false, "hourglass half|clock|countdown|delay|hourglass|hourglass-half|pending|sand|stopwatch|time|timer|waiting"},
{0xf251, false, "hourglass start|clock|countdown|duration|elapsed|hourglass|sand|stopwatch|time|timer|waiting"},
{0xf015, false, "house|abode|building|domicile|dwelling|home|house|living place|main|property|real estate|residence|shelter"},
{0xe3af, false, "house chimney|abode|building|chimney|dwelling|hearth|home|house|main house|residence|rooftop|smoke"},
{0xf6f1, false, "house chimney crack|broken|building|chimney|crack|damage|disaster|earthquake|hazard|home|house|insurance|repair|structural"},
{0xf7f2, false, "house chimney medical|clinic|covid-19|doctor|general practitioner|health center|health office|healthcare|hospital|house call|infirmary|medical|medical office|outpatient|telemedicine"},
{0xe065, false, "house chimney user|family|home|house|isolation|occupant|person|quarantine|resident|shelter|stay-at-home|user"},
{0xe00d, false, "house chimney window|abode|building|chimney|domestic|dwelling|family|home|house|property|real estate|residence|shelter|window"},
{0xe509, false, "house circle check|approved|check|confirmed|enabled|home|house|ok|okay|residence|safe|secure|validate|verified"},
{0xe50a, false, "house circle exclamation|abode|alert|caution|error|exclamation|home|house|issue|notification|problem|residence|warning"},
{0xe50b, false, "house circle xmark|abandon|cancel|cancelation|circle-x|clear|close|delete|deny|home|house|no|reject|remove|uncheck|xmark"},
{0xe3b1, false, "house crack|broken|building|collapse|crack|damage|disaster|earthquake|home|house|insurance|repair|structural"},
{0xe50c, false, "house fire|alarm|blaze|burning|disaster|emergency|fire|hazard|home|house|rescue|smoke"},
{0xe50d, false, "house flag|accommodation|cabin|camp|campsite|flag|home|house|lodging|residence|shelter|travel|vacation"},
{0xe50e, false, "house flood water|damage|disaster|emergency|flood|home|house|leak|overflow|property loss|storm|water|wet"},
{0xe50f, false, "house flood water circle arrow right|arrow|damage|disaster|emergency|evacuation|flood|home|house|insurance|moving out|natural disaster|right|water"},
{0xe066, false, "house laptop|computer|device|home computer|home office|laptop|online work|remote work|telecommute|telework|virtual office|work from home"},
{0xe510, false, "house lock|home|house|lock|lockdown|locked|padlock|privacy|protected|quarantine|secure|security"},
{0xe3b2, false, "house medical|clinic|covid-19|doctor|emergency|facility|general practitioner|health|healthcare|hospital|infirmary|medical|medicine|office|outpatient|treatment"},
{0xe511, false, "house medical circle check|approved|check|clinic|confirmed|enable|health|hospital|medical|ok|okay|safe|valid|verified|working"},
{0xe512, false, "house medical circle exclamation|alert|care|clinic|emergency|exclamation|health|hospital|medical|urgent|warning"},
{0xe513, false, "house medical circle xmark|cancel|clinic|close|cross|delete|health|hospital|medical|no|remove|stop|xmark"},
{0xe514, false, "house medical flag|aid|clinic|emergency|field hospital|first aid|health|healthcare|hospital|infirmary|medical|medical flag|medical tent"},
{0xe012, false, "house signal|building|connect|connection|family|home|house|internet|network|residence|signal|smart home|wifi|wireless"},
{0xe515, false, "house tsunami|disaster|emergency|flood|house|natural disaster|storm surge|tidal wave|tsunami|water damage|wave"},
{0xe1b0, false, "house user|account|family|home|house|household|occupant|person|profile|resident|user"},
{0xf6f2, false, "hryvnia sign|UAH|Ukrainian currency|cash|currency|currency symbol|finance|hryvnia|hryvnia sign|money"},
{0xf751, false, "hurricane|coriolis effect|cyclone|eye|hurricane|natural disaster|severe weather|storm|tropical cyclone|typhoon|weather|wind"},
{0x49, false, "i|alphabet|capital i|character|letter i|lowercase i|symbol|text|typography"},
{0xf246, false, "i cursor|cursor|editing|i-beam|insertion|text|text-caret|text-editing|typing|write|writing"},
{0xf810, false, "ice cream|chocolate|cold|cone|dessert|frozen|frozen yogurt|gelato|ice cream|scoop|snack|sorbet|summer|sweet|treat|vanilla"},
{0xf7ad, false, "icicles|chilly|cold|drip|freeze|frost|frozen|hanging|ice|icicle|sharp|winter"},
{0xf86d, false, "icons|bolt|electricity|emoji|energy|flash|icon|lightning|power|sign|symbol"},
{0xf2c1, false, "id badge|badge|card|contact|credential|id|identification|identity|license|name tag|profile|user|username"},
{0xf2c2, false, "id card|badge|card|contact|credentials|demographics|document|id|identification|identity|license|personal|profile|registration|user|username"},
{0xf47f, false, "id card clip|badge|card|contact|credentials|demographics|document|id|identification|identity|license|pass|profile|user|username"},
{0xf7ae, false, "igloo|arctic|cold|dome|home|house|ice|igloo|inuit|shelter|snow|snow house|winter"},
{0xf03e, false, "image|gallery|image|image file|landscape|photo|photo album|photograph|picture|picture frame|snapshot"},
{0xf3e0, false, "image portrait|avatar|id|image|img|photo|picture|portrait|profile|selfie|user|username"},
{0xf302, false, "images|album|gallery|image|landscape|media|photo|photo album|photo gallery|photograph|picture|picture frame|snapshot"},
{0xf01c, false, "inbox|archive|box|delivery|email|folder|inbox|incoming|letters|mail|message|post|tray"},
{0xf03c, false, "indent|align|format|indent|justify|layout|margin|paragraph|spacing|tab|text-indent"},
{0xe1bc, false, "indian rupee sign|INR|Indian Rupee|Indian currency|currency|financial|money|payment|price|rupee|rupee symbol"},
{0xf275, false, "industry|assembly|building|facility|factory|industrial|industry|manufacturing|mill|plant|production|warehouse|workshop"},
{0xf534, false, "infinity|continuous|endless|eternity|forever|infinite|infinity|loop|math|symbol|timeless|unbounded|universal"},
{0xf129, false, "info|about|data|details|explanation|facts|guidance|help|info|information|more|support"},
{0xf033, false, "italic|emphasis|emphasis-style|font|format|formatting|italic|slant|style|text|type|typography"},
{0x4a, false, "j|Latin letter|alphabet|capital j|character|letter j|lowercase j|symbol|text|typography"},
{0xe516, false, "jar|bottle|canning|container|food|glass|jam|jar|jelly|preserve|storage"},
{0xe517, false, "jar wheat|baking|cereal|flour|food container|grain|harvest|ingredient|jar|pantry|storage|wheat"},
{0xf669, false, "jedi|fantasy|force|galactic republic|jedi|jedi council|jedi knight|jedi master|jedi order|lightsaber|padawan|sci-fi|skywalker|space opera|star wars|yoda"},
{0xf0fb, false, "jet fighter|aircraft|airforce|airplane|aviation|combat|fast|fighter|fly|jet|maverick|military|pilot|plane|top gun|warplane"},
{0xe518, false, "jet fighter up|aircraft|airforce|airplane|aviation|combat|fast|fighter|fly|jet|military|pilot|plane|top gun|travel|warplane"},
{0xf595, false, "joint|blunt|cannabis|doobie|ganja|herb|joint cigarette|marijuana|pot|reefer|roach|rolled cigarette|smoke|smoking|spliff|weed"},
{0xe519, false, "jug detergent|bottle|cleaning|detergent|fabric softener|jug|laundry|liquid detergent|soap|stain remover|wash"},
{0x4b, false, "k|alphabet|capital k|character|letter k|lowercase k|symbol|typography"},
{0xf66b, false, "kaaba|cube|hajj|holy site|islam|kaaba|mecca|mosque|muslim|pilgrimage|religion|sacred|worship"},
{0xf084, false, "key|access|authentication|credential|key|keyhole|lock|passcode|password|private|secret|secure|security|unlock"},
{0xf11c, false, "keyboard|accessory|computer|data entry|device|hardware|input|keyboard|keypad|keys|text|type|typing|write"},
{0xf66d, false, "khanda|Adi Shakti|Sikh emblem|Sikh symbol|chakkar|double-edged sword|emblem|faith|khanda|religion|sikh|sikhism|spiritual|sword|symbol|warrior emblem"},
{0xe1c4, false, "kip sign|cash|currency|currency symbol|kip|kip sign|laos|laos kip|laotian currency|laotian kip|money"},
{0xf479, false, "kit medical|aid|doctor|emergency|emt|first aid|health|healthcare|hospital|kit|medical|medicine|nurse|rescue|treatment"},
{0xe51a, false, "kitchen set|bake|chef|cook|cooking utensils|cookware|frying pan|kitchen|kitchenware|meal prep|pan|pot|skillet|stove"},
{0xf535, false, "kiwi bird|animal|bird|birdwatching|endangered|fauna|flightless|kiwi|native|new zealand|wildlife"},
{0x4c, false, "l|Latin letter|alphabet|capital L|character|letter L|lowercase L|symbol"},
{0xe51b, false, "land mine on|battlefield|bomb|danger|explosion|explosive|hazard|landmine|military|mine|threat|war|weapon"},
{0xf66f, false, "landmark|architecture|attraction|building|culture|famous|heritage|historic|memorial|monument|notable|politics|site|society|tourist"},
{0xf752, false, "landmark dome|architecture|building|capitol|dome|government|heritage|historic|landmark|monument|parliament|political|structure"},
{0xe51c, false, "landmark flag|building|capitol|flag|government|historic|landmark|memorial|monument|national|patriotic|symbol"},
{0xf1ab, false, "language|alphabet|communication|dialect|idiom|language|linguistics|localization|localize|speech|text|translate|translation|vernacular|words"},
{0xf109, false, "laptop|computer|dell|device|electronics|laptop|mac|macbook|notebook|pc|personal computer|portable|technology"},
{0xf5fc, false, "laptop code|code|coding|computer|developer|development|device|laptop|mac|macbook|machine|pc|programming|programming language|software|tech"},
{0xe51d, false, "laptop file|computer|digital file|document|education|file|laptop|learning|online learning|remote work|report|screen|technology|work from home"},
{0xf812, false, "laptop medical|computer|device|digital health|ehr|electronic health records|health|healthcare|history|laptop|medical|medical records|patient|telemedicine"},
{0xe1c8, false, "lari sign|Georgian currency|cash|currency|currency sign|financial|lari|money|payment|price|symbol"},
{0xf5fd, false, "layer group|arrangement|category|cluster|collection|group|layers|map|organize|overlay|panel|set|stack"},
{0xf06c, false, "leaf|botany|eco|environment|flora|foliage|garden|green|herb|leaf|natural|nature|organic|plant|sustainable|vegan"},
{0xf30a, false, "left long|arrow-left|back|go back|left|long arrow|previous|return|rewind|undo"},
{0xf337, false, "left right|adjust|arrow|arrows-h|direction|drag|expand|horizontal|left arrow|left-right|move|resize|right arrow|slider|wide"},
{0xf094, false, "lemon|citrus|citrus fruit|fruit|lemon|lemonade|refreshing|sour|summer|tart|vitamin C|yellow"},
{0xe84a, false, "leo|astrology|august|constellation|fire sign|horoscope|july|leo|lion|sign|stars|zodiac"},
{0x3c, false, "less than|arithmetic|comparison|comparison operator|inequality|less than|less-than sign|math|math symbol|operator|symbol"},
{0xf537, false, "less than equal|arithmetic|compare|comparison|inequality|less than or equal|math|math operator|relational operator|symbol"},
{0xe84b, false, "libra|air sign|astrology|constellation|horoscope|libra|october|scales|september|sign|stars|zodiac"},
{0xf1cd, false, "life ring|coast guard|emergency|flotation|help|life preserver|lifebuoy|lifesaver|overboard|rescue|safety|save|support"},
{0xf0eb, false, "lightbulb|bright|bulb|concept|creativity|electric|electricity|energy|idea|innovation|inspiration|invention|lamp|light|light bulb|thinking"},
{0xe51e, false, "lines leaning|angled|canted|diagonal|domino|falling|imbalance|leaning|leaning tower|slanted|sloping|tilted|tipped"},
{0xf0c1, false, "link|attach|attachment|bond|chain|connect|connection|fasten|hyperlink|join|link|url"},
{0xf127, false, "link slash|attachment|broken|broken link|cancel|chain|disable|disabled|disconnect|link|remove|slash|unlink"},
{0xf195, false, "lira sign|cash|currency|finance|lira|money|payment|symbol|turkish currency|turkish lira|turkish money"},
{0xf03a, false, "list|bullet|checklist|completed|done|finished|items|list|ol|ordered|outline|points|summary|tasks|todo|ul|unordered"},
{0xf0ae, false, "list check|approve|checklist|completed|done|mark|progress|project management|summary|task list|tick|to do|verify"},
{0xf0cb, false, "list ol|checklist|items|list|numbered list|numbers|ol|ordered list|outline|sequence|steps|tasks|todo"},
{0xf0ca, false, "list ul|bullet|checklist|items|list|points|summary|survey|tasks|todo|ul|unordered|unordered list"},
{0xe1d3, false, "litecoin sign|LTC|blockchain|coin|crypto|cryptocurrency|currency|digital currency|litecoin|token"},
{0xf124, false, "location arrow|address|arrow|compass|coordinate|direction|gps|location|map|navigation|place|pointer|route|travel|waypoint"},
{0xf601, false, "location crosshairs|coordinate|crosshairs|find|geolocation|gps|location|map|navigation|pinpoint|place|position|target|tracking|where"},
{0xf3c5, false, "location dot|address|coordinates|destination|geotag|gps|location|map|map marker|marker|navigation|pin|place|point of interest|position|route|spot|travel|waypoint"},
{0xf041, false, "location pin|address|coordinates|destination|drop|gps|location|map|map marker|marker|navigation|pin|place|point of interest|position|route|spot|travel|waypoint"},
{0xe51f, false, "location pin lock|location|lock|lockdown|locked|map|padlock|pin|privacy|protected|quarantine|restricted|secure"},
{0xf023, false, "lock|access|authentication|closed|lock|locked|padlock|password|privacy|private|protect|safety|secure|security"},
{0xf3c1, false, "lock open|access|authorized|lock|open|open lock|padlock|permission|privacy|protection|safe|security|unlock|unlocked"},
{0xe520, false, "locust|biblical plague|crop damage|grasshopper|horde|infestation|insect|locust|outbreak|pest|plague|swarm"},
{0xf604, false, "lungs|air|anatomy|breath|breathing|covid-19|exhale|health|inhale|lung|lungs|medicine|organ|pulmonary|respiration|respiratory"},
{0xe067, false, "lungs virus|breath|coronavirus|covid-19|disease|flu|health|illness|infection|lungs|pandemic|respiratory|respiratory illness|sickness|virus|virus infection"},
{0x4d, false, "m|alphabet|capital M|character|initial|letter M|lowercase m|symbol|text|typography"},
{0xf076, false, "magnet|attract|attraction|force|horseshoe|iron|lodestone|magnet|magnetic|metal|north pole|polarity|pull|south pole|tool"},
{0xf002, false, "magnifying glass|bigger|enlarge|find|glass|inspect|inspection|magnifier|magnify|magnifying glass|preview|search|tool|zoom"},
{0xe521, false, "magnifying glass arrow right|arrow|explore|find|forward|go|lookup|magnifier|next|proceed|search"},
{0xe522, false, "magnifying glass chart|analysis|analytics|chart|data|graph|inspect|magnifier|magnifying glass|market|overview|report|revenue|search|statistics|trends"},
{0xf688, false, "magnifying glass dollar|analyze|budget|cost|currency|dollar|finance|find|inspect|magnifier|magnify|money|price|search|zoom"},
{0xf689, false, "magnifying glass location|area|detect|explore|find|location|magnifier|magnify|map|navigation|pinpoint|place|search|spot|zoom"},
{0xf010, false, "magnifying glass minus|decrease|magnifier|minimize|minus|reduce|search less|shrink|smaller|zoom out|zoom-out icon"},
{0xf00e, false, "magnifying glass plus|add|bigger|enlarge|find|magnify|magnifying glass|plus|positive|search|zoom|zoom in"},
{0xe1d5, false, "manat sign|Azerbaijan currency|Turkmenistan currency|currency|currency symbol|financial symbol|manat|manat sign|money"},
{0xf279, false, "map|address|atlas|chart|coordinates|destination|directions|gps|guide|location|map|navigation|pin|place|point of interest|position|route|travel|world|world map"},
{0xf59f, false, "map location|address|coordinates|destination|geolocation|gps|location|map|map marker|marker|navigation|pin|place|point of interest|position|route|spot|travel|waypoint"},
{0xf5a0, false, "map location dot|address|coordinates|destination|drop pin|find|geolocation|gps|location|map|map marker|marker|navigation|pin|place|point of interest|position|route|spot|travel|waypoint"},
{0xf276, false, "map pin|address|coordinates|destination|droppin|geo|gps|location|location marker|map|map marker|map pin|marker|navigation|pin|place|position|pushpin|spot|travel|waypoint"},
{0xf5a1, false, "marker|annotate|coloring|draw|edit|highlight|marker|marker pen|marker tip|modify|pen|sharpie|sketch|update|write"},
{0xf222, false, "mars|gender|male|male gender|male gender symbol|male icon|male sex|male sign|male symbol|man|mars|masculinity"},
{0xf224, false, "mars and venus|Mars and Venus|female|gender|gender diversity|gender equality|gender identity|gender signs|gender symbols|intersex|male|male and female|transgender"},
{0xe523, false, "mars and venus burst|astrology|burst|conflict|female|gender|love|male|mars|relationship|symbols|venus"},
{0xf227, false, "mars double|LGBTQ|double male|gay|gender|male|male couple|male gender|male symbol|masculinity|men|same-sex male"},
{0xf229, false, "mars stroke|accessibility|disability|gender|health|male|medical|sign|stroke|symbol|transgender"},
{0xf22b, false, "mars stroke right|gender|gender male|gender symbol|horizontal male|male|male sign|male symbol|mars|masculinity|right stroke"},
{0xf22a, false, "mars stroke up|Mars|arrow|gender|gender symbol|male|male gender|masculine|stroke|symbol|up"},
{0xf57b, false, "martini glass|alcohol|bar|beverage|celebration|cocktail|cocktail glass|drink|drinkware|glass|happy hour|liquor|martini|party"},
{0xf561, false, "martini glass citrus|alcohol|bar|beverage|citrus|cocktail|drink|gin|glass|lemon|lime|margarita|martini|party|refreshment|vodka"},
{0xf000, false, "martini glass empty|alcohol|bar|beverage|celebration|cocktail|drink|glass|liquor|martini|nightlife|party|spirits"},
{0xf6fa, false, "mask|carnival|costume|costume party|disguise|disguise accessory|festival|halloween|mask|masquerade|party|secret|superhero"},
{0xe1d7, false, "mask face|breath|coronavirus|covid-19|face mask|filter|flu|health|infection|mask|medical mask|pandemic|protection|respirator|safety|surgical mask|virus"},
{0xe524, false, "mask ventilator|airway|breathing|breathing apparatus|gas mask|life support|medical mask|oxygen|respirator|respiratory support|ventilation|ventilator"},
{0xf630, false, "masks theater|acting|arts|comedy|drama|masks|performance|performance art|play|stage|theater|theatre|theatrical|tragedy"},
{0xe525, false, "mattress pillow|bed|bedding|comfort|mattress|mattress pad|nap|pillow|rest|sleep|sleeping pad"},
{0xf31e, false, "maximize|arrows|bigger|enlarge|expand|full screen|fullscreen|grow|increase|maximize|open|resize|scale|stretch|zoom in"},
{0xf5a2, false, "medal|achievement|award|badge|bronze medal|champion|gold medal|honor|medal|prize|quality|ribbon|silver medal|sports medal|trophy|winner"},
{0xf538, false, "memory|DIMM|RAM|chip|computer|hardware|memory|memory card|memory module|module|stick|technology|volatile"},
{0xf676, false, "menorah|candle|candles|celebration|festival of lights|hanukkah|jewish|jewish holiday|judaism|light|menorah|menorah candleholder|oil lamp|religious"},
{0xf223, false, "mercury|alchemy|astrology|gender|hybrid|mercury|messenger|planet|roman god|symbol|transgender"},
{0xf27a, false, "message|bubble|chat|comment|conversation|discussion|feedback|message|note|notification|reply|sms|speech|talk|text|texting"},
{0xf753, false, "meteor|asteroid|blaze|comet|falling star|fireball|impact|meteor|meteor shower|meteorite|shooting star|sky|space|streak"},
{0xf2db, false, "microchip|chip|circuit|computer|cpu|device|electronic|hardware|microprocessor|motherboard|processor|semiconductor|silicon|technology"},
{0xf130, false, "microphone|audio|broadcast|karaoke|microphone|music|podcast|record|recording|sing|sound|speech|talk|talking|vocal|voice"},
{0xf3c9, false, "microphone lines|audio|broadcast|karaoke|mic|microphone|music|podcast|recording|sing|sound|speech|studio|talking|vocal|voice"},
{0xf539, false, "microphone lines slash|audio|disabled|microphone|mute|muted|no sound|off|podcast|record|silence|sing|sound|voice"},
{0xf131, false, "microphone slash|audio off|disable|disabled|microphone|mute|muted|no sound|podcast|record|silence|sing|sound off|voice off"},
{0xf610, false, "microscope|analysis|biology|chemistry|experiment|investigation|laboratory|lens|magnification|magnify|microscope|optics|research|science|study|tool"},
{0xe1ed, false, "mill sign|currency|finance|financial symbol|measurement|mill sign|monetary unit|money|symbol|unit"},
{0xf78c, false, "minimize|collapse|contract|downsize|hide|minimize|reduce|screen|shrink|smaller|window"},
{0xf068, false, "minus|collapse|dash|delete|hide|math|minimize|minus|minus sign|negative|reduce|remove|shrink|sign|subtract|−"},
{0xf7b5, false, "mitten|clothing|cold|cozy|frost|glove|handwear|knitted|mitten|protection|seasonal|snow|warmth|winter"},
{0xf3ce, false, "mobile|android|call|cell|cell phone|cellular|device|handset|mobile|mobile phone|number|phone|screen|smartphone|telephone|text"},
{0xf10b, false, "mobile button|apple|call|cell phone|contact|device|dial|handset|iphone|mobile|number|phone|screen|smartphone|telephone"},
{0xe527, false, "mobile retro|call|cellphone|cellular|classic phone|communication|handset|mobile|old-fashioned|phone|retro phone|vintage"},
{0xf3cf, false, "mobile screen|android|call|cell phone|communication|device|digital device|handset|ios|mobile|mobile device|phone|screen|smartphone|text|touchscreen"},
{0xf3cd, false, "mobile screen button|apple|call|cell phone|communication|device|handset|iphone|mobile|number|phone|screen|smartphone|telephone|touchscreen"},
{0xe816, false, "mobile vibrate|alert|call|cell phone|device|haptic|message|mobile|notification|phone|ring|silent|smartphone|text|vibrate|vibration"},
{0xf0d6, false, "money bill|bill|buy|cash|currency|earnings|finance|funds|income|money|payment|price|purchase|revenue|salary|wallet"},
{0xf3d1, false, "money bill 1|bill|buy|cash|checkout|currency|dollar|finance|money|paycheck|payment|premium|price|purchase|salary"},
{0xf53b, false, "money bill 1 wave|banknote|bill|cash|currency|earnings|finance|funds|income|money|pay|payment|price|purchase|salary|wallet"},
{0xe528, false, "money bill transfer|bank|currency|deposit|exchange|funds|money|payment|receive|salary|send|transaction|transfer|wire|withdrawal"},
{0xe529, false, "money bill trend up|bank|bonds|earnings|finance|growth|income|inflation|investment|market|money|profit|revenue|salary|stocks|trade"},
{0xf53a, false, "money bill wave|bills|buy|cash|currency|earnings|finance|funds|money|paycheck|payment|price|purchase|salary|transaction|wallet"},
{0xe52a, false, "money bill wheat|agribusiness|agriculture|crops|economy|farming|finance|food|grain|harvest|income|investment|money|payment|subsidy|wheat"},
{0xe1f3, false, "money bills|atm|bills|cash|currency|dollars|finance|funds|income|investment|money|payment|revenue|salary"},
{0xf53c, false, "money check|bank check|billing|buy|check|checkout|cheque|finance|invoice|money|paycheck|payment|paystub|purchase|salary|transaction"},
{0xf53d, false, "money check dollar|bank check|billing|cash|checkbook|cheque|dollar|finance|funds|invoice|money|pay|paycheck|payment|salary|transaction"},
{0xf5a6, false, "monument|building|commemorative|famous|heritage|historic|iconic|landmark|memorial|monument|monumental|notable|statue|tourist attraction"},
{0xf186, false, "moon|crescent|crescent moon|dark|dark mode|evening|lunar|moon|moonlight|night|night mode|nighttime|nighttime symbol|sleep"},
{0xf5a7, false, "mortar pestle|apothecary|cooking|crush|grind|herbal|herbs|kitchen|medical|medicine|mix|pharmacy|prescription|spices"},
{0xf678, false, "mosque|Islam|Islamic architecture|Muslim|building|dome|landmark|minaret|mosque|prayer|religion|worship"},
{0xe52b, false, "mosquito|West Nile|Zika|bite|bloodsucker|bug|dengue|disease|insect|malaria|mosquito|mosquito bite|nuisance|pest"},
{0xe52c, false, "mosquito net|bug net|bug screen|camping|insect net|insect screen|malaria prevention|mosquito|mosquito bite|mosquito net|net|outdoor gear|pest control|protection|sleeping net"},
{0xf21c, false, "motorcycle|bike|chopper|cruiser|motorbike|motorcycle|motorized bike|racing|scooter|transportation|two-wheeler|vehicle"},
{0xe52d, false, "mound|barrier|dirt|earth|embankment|heap|hill|mound|pile|soil|speedbump"},
{0xf6fc, false, "mountain|climbing|glacier|hiking|hill|landscape|mountain|nature|outdoor|peak|snow|snow-capped|summit|travel|view"},
{0xe52e, false, "mountain city|adventure|city|landscape|mountain|nature|outdoors|rural|skyline|town|travel|urban|village"},
{0xe52f, false, "mountain sun|adventure|hiking|landscape|mountain|nature|outdoors|scenic|sun|sunrise|sunset|travel|view|wilderness"},
{0xf7b6, false, "mug hot|beverage|cappuccino|cocoa|coffee|cozy|cup|drink|hot|hot beverage|hot chocolate|latte|morning|mug|steam|steaming|tea|warm drink|warmth"},
{0xf0f4, false, "mug saucer|autumn|beverage|breakfast|cafe|coffee|cozy|cup|drink|fall|hot drink|morning|mug|saucer|seasonal|tea|warm"},
{0xf001, false, "music|audio|lyrics|melody|music|musical note|note|sing|song|sound|tune"},
{0x4e, false, "n|Latin letter|alphabet|character|letter|lowercase n|nay|no|uppercase n"},
{0xe1f6, false, "naira sign|Nigerian currency|cash|currency|currency symbol|financial|money|naira|naira sign|payment|₦"},
{0xf6ff, false, "network wired|cable|communication|computer|connection|data|ethernet|internet|intranet|lan|network|router|switch|wired"},
{0xf22c, false, "neuter|gender|gender icon|gender neutral|gender symbol|genderless|neuter|neutral gender|no gender|non-binary|unisex"},
{0xf1ea, false, "newspaper|article|bulletin|editorial|gazette|headline|journalism|media|news|newsletter|newspaper|paper|periodical|press|publication|report"},
{0xe807, false, "non binary|LGBTQ|gender|gender identity|genderfluid|genderqueer|identity|nb|non-binary|nonbinary|queer"},
{0xf53e, false, "not equal|arithmetic|compare|comparison|difference|inequality|math|math symbol|not equal|symbol"},
{0xe1fe, false, "notdef|404|absent|broken|close|error|fail|invalid|missing|not found|unavailable"},
{0xf249, false, "note sticky|annotation|label|memo|message|note|paper|post-it|reminder|sticker|sticky note"},
{0xf481, false, "notes medical|chart|clinic|clipboard|doctor|ehr|health|healthcare|history|hospital|medical|notes|patient|prescription|records|treatment"},
{0x4f, false, "o|alphabet|character|latin letter|letter|letter o|symbol|text|typeface|typography|vowel"},
{0xf247, false, "object group|cluster|collection|combine|copy|design|group|layers|merge|objects|select"},
{0xf248, false, "object ungroup|break apart|design|divide|layers|objects|select|separate|split|ungroup"},
{0xf306, false, "octagon|geometric|octagon|octagonal|polygon|road sign|shape|stop|stop sign|symbol|traffic|warning"},
{0xf613, false, "oil can|automotive|engine oil|grease|lubricant|maintenance|motor oil|oil|oil bottle|oil can|oil change|oil container|oil dispenser|petroleum"},
{0xe532, false, "oil well|drilling|energy|extraction|fossil fuel|oil|oil drilling|oil rig|oil well|petroleum|rig"},
{0xf679, false, "om|Buddhism|Hindu|Hinduism|Jainism|chant|mantra|meditation|om|religion|sacred|spirituality|symbol"},
{0xf700, false, "otter|animal|aquatic|cute|fishing|fur|mammal|nature|otter|playful|river|wildlife"},
{0xf03b, false, "outdent|align left|decrease indent|formatting|indent less|margin|outdent|paragraph|tab|text"},
{0x50, false, "p|alphabet p|capital p|character p|letter p|lowercase p|text p"},
{0xf815, false, "pager|alert|beeper|communication|message|notification|old technology|page|pager|pager device|wireless device"},
{0xf5aa, false, "paint roller|DIY|brush|coating|color|decoration|home improvement|paint|paintbrush|painting|renovation|roller|tool|wall"},
{0xf1fc, false, "paintbrush|acrylic|art|artist|brush|color|creativity|design|drawing|fill|paint|paintbrush|painting|pigment|tool|watercolor"},
{0xf53f, false, "palette|acrylic|art|artist palette|brush|color|colors|creativity|design|drawing|paint|paintbrush|painting|palette|pigment|watercolor"},
{0xf482, false, "pallet|boxes|cargo|crates|delivery|freight|inventory|loading|logistics|packaging|pallet|shipping|storage|supply chain|transport|warehouse"},
{0xe209, false, "panorama|horizon|image|landscape|nature|outdoors|panorama|photo|picture|scenic|view|wide|wide-angle"},
{0xf1d8, false, "paper plane|air|communication|delivery|flight|float|folded paper|mail|message|paper|paper aeroplane|paper airplane|plane|send|send message"},
{0xf0c6, false, "paperclip|attach|attachment|binder|clip|document|fasten|file|hold|office|paperclip|paperclip icon|pin"},
{0xf4cd, false, "parachute box|aid|airlift|assistance|delivery|drop|emergency|humanitarian|package|parachute|relief|rescue|supplies"},
{0xf1dd, false, "paragraph|edit|formatting|mark|paragraph|paragraph break|pilcrow|symbol|text|writing"},
{0xf5ab, false, "passport|border|citizenship|document|id|identification|immigration|international|passport|passport control|travel|travel document|visa"},
{0xf0ea, false, "paste|clipboard|clipboard-insert|clipboard-paste|content|document|input|insert|paper|paste|text"},
{0xf04c, false, "pause|break|double bar|freeze|hold|interrupt|pause|pause button|stop|vertical bars|wait"},
{0xf1b0, false, "paw|animal|cat|claw|dog|footprint|mammal|paw|paw pad|paw print|pawprint|pet|print"},
{0xf67c, false, "peace|antiwar|calm|ceasefire|harmony|nonviolence|pacifism|peace|peace symbol|protest|serenity|tranquility"},
{0xf304, false, "pen|ballpoint|compose|drawing|edit|handwriting|modify|note|pen|signature|sketch|update|write"},
{0xf305, false, "pen clip|annotate|compose|create|draw|edit|modify|note|pen|pencil|update|write"},
{0xf5ac, false, "pen fancy|black nib|calligraphy|design|drawing|edit|fountain pen|handwriting|ink|modify|nib|pen|signature|stylus|update|write"},
{0xf5ad, false, "pen nib|calligraphy|design|drawing|edit|handwriting|modify|nib|pen|sketch|update|write"},
{0xf5ae, false, "pen ruler|architecture|creativity|design|draft|draw|edit|measurement|modify|pencil|plan|ruler|sketch"},
{0xf044, false, "pen to square|annotate|change|compose|document|draft|edit|form|input|modify|note|pen|pencil|signature|update|write"},
{0xf303, false, "pencil|annotate|compose|design|draft|draw|edit|modify|note|pencil|sketch|update|write"},
{0xe790, false, "pentagon|5|figure|five|geometric|pentagon|pentagonal|polygon|shape|sided shape"},
{0xe068, false, "people arrows|arrows|communication|connection|conversation|discussion|exchange|group|interaction|isolation|people|separate|social distancing|users"},
{0xf4ce, false, "people carry box|box|carrying|collaboration|group|help|moving|people|support|teamwork|transport"},
{0xe533, false, "people group|community|crowd|family|gathering|group|members|people|social|team|together|users"},
{0xe534, false, "people line|community|crowd|group|people|team|together|users"},
{0xe535, false, "people pulling|cooperation|effort|forced return|group|pulling|struggle|teamwork|tugging|yanking"},
{0xe536, false, "people robbery|burglary|criminal|hands up|hold up|looting|mugging|robbery|robbery suspect|steal|theft"},
{0xe537, false, "people roof|community|crowd|family|group|home|housing|manage|people|protection|safe|shelter|support|together"},
{0xf816, false, "pepper hot|capsicum|cayenne|chili|chili pepper|chilli|fiery|habanero|heat|hot|hot pepper|jalapeno|pepper|peppercorn|red pepper|spicy|spicy food|tabasco"},
{0x25, false, "percent|discount|fraction|interest rate|percent|percent off|percent sign|percent symbol|percent value|percentage|proportion|rate|ratio|tax rate"},
{0xf183, false, "person|avatar|figure|human|individual|man|person|profile|standing|user|woman"},
{0xe538, false, "person arrow down to line|access|arrow down|arrow to line|download|enter|insert|login|person|sign in|user"},
{0xe539, false, "person arrow up from line|arrow|growth|increase|person|profile|promotion|rise|upgrade|upward|user"},
{0xf84a, false, "person biking|bicycle|bike|biking|cycling|cyclist|exercise|fitness|outdoors|pedal|person biking|recreation|wheel"},
{0xf756, false, "person booth|ballot|changing room|curtain|election|polling|privacy|vote|voter|voting|voting booth"},
{0xe53a, false, "person breastfeeding|baby|breastfeeding|child|feeding|infant|lactation|mother|nursing|nutrition|parent|sustenance"},
{0xe53b, false, "person burst|abuse|accident|burst|crash|danger|emergency|explode|harm|impact|injury|shock|trauma|violence"},
{0xe53c, false, "person cane|aging|assistance|cane|disabled|elderly|mobility|old|senior|staff|support|walking stick"},
{0xe53d, false, "person chalkboard|blackboard|chalkboard|classroom|education|instructor|lecture|lesson|presentation|seminar|speaker|teacher|teaching|training"},
{0xe53e, false, "person circle check|account|active|approved|check|confirmed|enabled|ok|okay|profile|success|user|validated|verified|verified user"},
{0xe53f, false, "person circle exclamation|account|alert|attention|error|exclamation|failed|issue|missing|person|problem|profile|user|warning"},
{0xe540, false, "person circle minus|account removal|delete|delete user|minus|person|profile|remove|remove account|remove user|subtract|user|user minus"},
{0xe541, false, "person circle plus|account|add|contact|create|friend|member|new|person|plus|profile|register|sign up|user"},
{0xe542, false, "person circle question|account|assistance|faq|help|inquiry|profile|question|support|unknown|user"},
{0xe543, false, "person circle xmark|avatar|ban|block|cancel|circle|close|delete|disable|person|profile|remove|user|xmark"},
{0xf85e, false, "person digging|construction|digging|digging site|digging worker|excavation|labor|maintenance|manual labor|shovel|site work|work|worker"},
{0xf470, false, "person dots from line|allergy|connection|diagnosis|dots|linked|network|person|profile|user"},
{0xf182, false, "person dress|clothing|dress|female|female avatar|person|skirt|user|woman"},
{0xe544, false, "person dress burst|accident|blast|burst|crash|danger|dress|explosion|hazard|injury|person|violence"},
{0xe545, false, "person drowning|danger|distress|drown|drowning|emergency|hazard|help|lifesaver|swim|water rescue"},
{0xe546, false, "person falling|accident|danger|fall|falling person|hazard|injury|slip|trip|tumble"},
{0xe547, false, "person falling burst|accident|collapse|danger|emergency|fall|hazard|injury|slip|trip|tumble"},
{0xe548, false, "person half dress|clothing|gender|gender fluid|gender identity|half dress|man|nonbinary|person|restroom|transgender|unisex|woman"},
{0xe549, false, "person harassing|abuse|attack|bully|harass|harassment|insult|intimidation|mistreat|scream|shout|verbal abuse|yell"},
{0xf6ec, false, "person hiking|adventure|autumn|backpack|exercise|fall|hike|hiking|mountain|nature|outdoors|summer|trail|trekking|walk"},
{0xe54a, false, "person military pointing|army|commander|guard|military|officer|pointing|salute|service|soldier|troops"},
{0xe54b, false, "person military rifle|armed forces|army|combat|gun|infantry|military|rifle|soldier|war|weapon"},
{0xe54c, false, "person military to person|change|civilian|identity|military|person|role|service member|soldier|transfer|transition|user"},
{0xf683, false, "person praying|devotion|faith|gratitude|kneel|meditate|place of worship|prayer|praying|religion|spiritual|thank|worship"},
{0xe31e, false, "person pregnant|baby|birth|expecting|maternity|parent|pregnant|pregnant woman|woman"},
{0xe54d, false, "person rays|affected|focus|highlight|person|rays|shine|spotlight|user"},
{0xe54e, false, "person rifle|army|combatant|firearm|gun|infantry|military|rifle|shooter|soldier|war"},
{0xf70c, false, "person running|athletic|escape|exercise|fitness|flee|jogging|marathon|person running|race|run|runner|running|sprint|track|workout"},
{0xe54f, false, "person shelter|home|house|indoors|occupant|person|protection|refuge|roof|safe|safety|shelter"},
{0xf7c5, false, "person skating|figure skating|ice skating|olympics|rink|skater|skating|winter sports"},
{0xf7c9, false, "person skiing|alpine|cold weather|downhill|mountain|olympics|ski|skier|skiing|slope|snow|snow sport|winter"},
{0xf7ca, false, "person skiing nordic|athlete|cold weather|cross country|nordic skiing|olympics|outdoor|ski|snow|winter sports"},
{0xf7ce, false, "person snowboarding|athlete|olympics|snow|snow sport|snowboard|snowboarder|snowboarding|sport|winter|winter sports"},
{0xf5c4, false, "person swimming|aquatic|exercise|freestyle|lap swimming|ocean|pool|sea|sport|swim|swimmer|swimming|water"},
{0xe5a9, false, "person through window|break-in|burglary|door|exit|forced entry|intrusion|leave|looking|peeking|person|through|window"},
{0xf554, false, "person walking|crosswalk|exercise|hike|move|pedestrian|person walking|stroll|walk|walking|walking activity|workout"},
{0xe551, false, "person walking arrow loop left|arrow|back|follow|go back|loop|person|return|reverse|rewind|undo|walking"},
{0xe552, false, "person walking arrow right|arrow|continue|direction|exit|forward|leave|move|next|person|proceed|right|walk"},
{0xe553, false, "person walking dashed line arrow right|arrow|dashed line|direction|exit|follow|forward|move|next|path|pedestrian|proceed|route|walking"},
{0xe554, false, "person walking luggage|bag|baggage|briefcase|carry-on|luggage|rolling|suitcase|travel|traveler|walking"},
{0xf29d, false, "person walking with cane|accessibility|blind|cane|disabled|elderly|mobility aid|person|senior|visually impaired|walking|walking stick"},
{0xe221, false, "peseta sign|cash|currency|finance|money|old currency|payment|peseta|peseta sign|spanish currency|symbol"},
{0xe222, false, "peso sign|currency|currency sign|currency symbol|money|peso|peso coin|peso currency|peso peso currency|peso peso moneda|peso sign|peso symbol"},
{0xf095, false, "phone|call|communication|contact|dial|earphone|handset|landline|mobile|phone|receiver|support|talk|telephone|voice"},
{0xf879, false, "phone flip|call|communication|flip phone|handset|mobile|phone|receiver|support|telephone|voice"},
{0xf3dd, false, "phone slash|block|call|cancel|disabled|disconnect|end-call|handset|mute|no-sound|off|phone|reject|silent|telephone|voice"},
{0xf2a0, false, "phone volume|audio|call|communication|handset|phone|ringing|ringtone|sound|speaker|support|talk|telephone|voice|volume"},
{0xf87c, false, "photo film|camera|film|gallery|image|media|movie|photo|photograph|picture|reel|snapshot|video"},
{0xe80b, false, "picture in picture|floating|media|minimize|multitasking|overlay|picture-in-picture|pip|popout|resize|screen|secondary window|small screen|video|window"},
{0xf4d3, false, "piggy bank|budget|cash|coin|deposit|finance|money|piggy|piggy bank|save|savings"},
{0xf484, false, "pills|capsules|drugs|health|medication|medicine|pharmaceuticals|pharmacy|pills|prescription|supplements|tablets|vitamins"},
{0xe84c, false, "pisces|astrology|constellation|february|fish|horoscope|march|pisces|sign|stars|water sign|zodiac"},
{0xf818, false, "pizza slice|cheese|chicago|dinner|fast food|food|italian|lunch|mozzarella|new york|pepperoni|pie|pizza|slice|snack|teenage mutant ninja turtles|tomato"},
{0xf67f, false, "place of worship|building|chapel|church|faith|holy place|mosque|religion|sanctuary|spiritual|synagogue|temple|worship"},
{0xf072, false, "plane|aircraft|airplane|airport|arrival|departure|flight|fly|journey|plane|transportation|travel|trip"},
{0xf5af, false, "plane arrival|aeroplane|airplane|airport|arrival|arrivals|destination|flight|fly|incoming|land|landing|plane|touch down|travel|trip"},
{0xe555, false, "plane circle check|active|airplane|airport|approved|available|check|confirmed|enabled|flight|fly|ok|okay|travel|validated"},
{0xe556, false, "plane circle exclamation|affected|airplane|airport|alert|canceled|delay|exclamation|flight|issue|problem|travel|warning"},
{0xe557, false, "plane circle xmark|airplane|blocked|cancel|delete|flight|no fly|prohibited|reject|remove|stop|travel|xmark"},
{0xf5b0, false, "plane departure|aeroplane|airplane|airplane departure|airport|boarding|departing|departure|flight|fly|leaving|plane|takeoff|taking off|terminal|travel|trip"},
{0xe558, false, "plane lock|airplane|airport|flight|grounded|lockdown|locked|no-fly|padlock|privacy|quarantine|restricted|security|travel"},
{0xe069, false, "plane slash|airplane mode|airplane off|disabled|flight canceled|flight delayed|flight off|grounded|no airplane|no flights|no plane|no signal|no travel|offline|travel off"},
{0xe22d, false, "plane up|aircraft|airplane|aviation|departure|flight|flying|plane|sky|takeoff|travel"},
{0xe5aa, false, "plant wilt|agriculture|drooping|drought|dry|dying|garden|leaf|plant|shriveled|vegetation|wilt|withered"},
{0xe55a, false, "plate wheat|agriculture|bowl|bread|cereal|crop|farming|food|grain|harvest|hunger|meal|nutrition|plate|rations|wheat"},
{0xf04b, false, "play|arrow|audio|forward|go|media|music|play|play button|playback|press|right|sound|start|triangle|video"},
{0xf1e6, false, "plug|adapter|cable|charge|charging|connect|connector|electric|electricity|energy|outlet|plug|plug-in|power|power cord|socket"},
{0xe55b, false, "plug circle bolt|bolt|charge|current|electric|electricity|energy|lightning|outlet|plug|power|socket"},
{0xe55c, false, "plug circle check|active|check|connected|electric|electricity|enabled|ok|okay|plug|power|validate|verified|working"},
{0xe55d, false, "plug circle exclamation|alert|caution|disconnected|electric|electricity|error|exclamation|failure|issue|outage|plug|power|problem|warning"},
{0xe55e, false, "plug circle minus|disable|disconnect|electric|electricity|minus|outlet|plug|power|power off|remove|socket|unplug"},
{0xe55f, false, "plug circle plus|add|charging|connect|electric|electricity|energy|insert|plug|plus|power|socket|supply"},
{0xe560, false, "plug circle xmark|cancel|close|disable|disconnect|electric|electricity|error|outage|plug|power|remove|stop|unplug|xmark"},
{0x2b, false, "plus|add|create|expand|icon|increase|math|more|new|plus|plus sign|positive|sign|symbol"},
{0xe43c, false, "plus minus|add|adjust|arithmetic|math|plus minus|plus-minus|positive negative|sign|subtract|symbol|toggle"},
{0xf2ce, false, "podcast|audio|broadcast|conversation|episode|interview|media|music|radio|recording|show|sound|streaming|talk"},
{0xf2fe, false, "poo|crap|dung|emoji|excrement|feces|funny|pile of poo|poo|poop|poop emoji|shit|smelly|stink|turd|waste"},
{0xf75a, false, "poo storm|bad smell|chaos|cloud|disaster|euphemism|foul|lightning|mess|poop|shit|storm|turd"},
{0xf619, false, "poop|brown|cartoon|crap|dung|excrement|feces|funny|pile|poop|poop emoji|shit|stink|turd"},
{0xf011, false, "power off|button|computer|device|off|power|power symbol|reboot|restart|shutdown|toggle|turn off"},
{0xf5b1, false, "prescription|doctor|dosage|drugs|healthcare|medical|medication|medicine|pharmacy|pill|prescription|rx|script|treatment"},
{0xf485, false, "prescription bottle|bottle|drugs|drugstore|healthcare|medical|medication|medicine|pharmacy|pill|prescription|rx|treatment"},
{0xf486, false, "prescription bottle medical|bottle|drugs|healthcare|medical|medication|medicine|pharmacy|pills|prescription|rx"},
{0xf02f, false, "print|business|computer|copy|document|hard copy|office|output|paper|print|print icon|print screen|printer|printer icon|printing"},
{0xe06a, false, "pump medical|anti-bacterial|clean|covid-19|disinfect|dispenser|hand sanitizer|hand soap|hand wash|hygiene|medical|pump bottle|sanitizer|soap"},
{0xe06b, false, "pump soap|antibacterial|clean|covid-19|disinfect|germ protection|hand sanitizer|hand soap|handwash|hygiene|pump bottle|sanitizer|soap"},
{0xf12e, false, "puzzle piece|add-on|addon|block|clue|connect|fitting|game|interlocking|jigsaw|part|piece|puzzle|puzzle piece|section|segment"},
{0x51, false, "q|alphabet|capital q|character|glyph|letter q|lowercase q|symbol|text|typography"},
{0xf029, false, "qrcode|barcode|code|data|info|information|matrix|qr|qr-code|qrcode|quick response|scan|scanner|tag"},
{0x3f, false, "question|ask|faq|help|information|inquiry|punctuation|query|question|question mark|request|support|symbol|unknown"},
{0xf10d, false, "quote left|citation|dialogue|left quote|mention|note|phrase|quotation|quotation mark|quote|speech|text"},
{0xf10e, false, "quote right|citation|double quote|mention|note|phrase|quotation|quote|right quote|speech|text|type"},
{0x52, false, "r|alphabet|capital r|character|latin r|letter r|lowercase r|symbol|text|typeface|typography"},
{0xf7b9, false, "radiation|biohazard|contamination|danger|deadly|fallout|hazard|nuclear|radiation|radioactive|toxic|warning"},
{0xf8d7, false, "radio|am|antenna|audio|broadcast|fm|frequency|music|news|radio|receiver|signal|station|transmission|tuner|wave"},
{0xf75b, false, "rainbow|arc|colors|hope|leprechaun|nature|pot of gold|prism|rain|rainbow|sky|spectrum|sunlight|weather"},
{0xe561, false, "ranking star|achievement|award|best|first place|medal|podium|prize|quality|ranking|rating|star|success|top|win|winner"},
{0xf543, false, "receipt|accounting|bill|bookkeeping|check|coupon|expense|invoice|money|payment|proof|receipt|record|transaction"},
{0xf8d9, false, "record vinyl|LP|album|analog|audio|classic|disc|groove|music|phonograph|record|retro|sound|turntable|vinyl"},
{0xf641, false, "rectangle ad|ad|advertisement|announcement|banner|commercial|flyer|marketing|media|newspaper|poster|promotion|publicity"},
{0xf022, false, "rectangle list|checklist|completed|done|finished|items|list|notes|outline|summary|tasks|todo"},
{0xf410, false, "rectangle xmark|cancel|clear|close|delete|dismiss|exit|rectangle|reject|remove|stop|window|xmark"},
{0xf1b8, false, "recycle|compost|eco-friendly|environmental|garbage|recycle|recycle bin|recycling|recycling logo|recycling symbol|reuse|sustainability|trash|waste"},
{0xf25d, false, "registered|copyright-related|intellectual property|legal|mark|r|registered|symbol|trademark"},
{0xf363, false, "repeat|arrow|clockwise|cycle|loop|refresh|reload|repeat|replay|retry|switch"},
{0xf3e5, false, "reply|answer|chat|comment|conversation|email|feedback|mail|message|reply|respond|respond to|response"},
{0xf122, false, "reply all|answer|conversation|email|inbox|mail|message|reply|reply all|respond|send"},
{0xf75e, false, "republican|GOP|america|conservative|election|elephant|political party|politics|red party|republican|republican party|right|right side|right-wing|usa"},
{0xf7bd, false, "restroom|bathroom|facilities|john|lavatory|loo|powder room|restroom|toilet|washroom|water closet|wc"},
{0xf079, false, "retweet|cycle|exchange|forward|refresh|reload|renew|repeat|repost|retry|retweet|share|swap|twitter"},
{0xf4d6, false, "ribbon|achievement|award|awareness|badge|cause|celebration|decoration|honor|lapel|medal|pin|prize|reminder|ribbon"},
{0xf2f5, false, "right from bracket|arrow|exit|forward|leave|log off|log out|logoff|logout|next|outbox|quit|send|sign out|sign-out"},
{0xf362, false, "right left|arrow|arrows|bidirectional|exchange|flip|horizontal|left-right|reverse|swap|switch|transfer"},
{0xf30b, false, "right long|arrow|arrow-right|continue|direction|forward|move right|navigation|next|next step|proceed|right arrow|rightward"},
{0xf2f6, false, "right to bracket|arrow|arrow right|bracket|enter|enter bracket|join|log in|login|login arrow|sign in|sign up|sign-in|sign-in arrow|signin|signup"},
{0xf70b, false, "ring|Dungeons & Dragons|Gollum|band|binding|circle|commitment|d&d|dnd|engagement|fantasy|gold|jewelry|loop|magic|marriage|precious|promise|ring|treasure|wedding"},
{0xf018, false, "road|avenue|boulevard|drive|highway|lane|motorway|path|pavement|road|roadway|route|street|street map|traffic|travel"},
{0xe562, false, "road barrier|barricade|barrier|block|caution|closed|construction|detour|no entry|obstacle|roadblock|traffic control"},
{0xe563, false, "road bridge|bridge|crossing|highway|infrastructure|overpass|road|roadway|transportation|travel|viaduct"},
{0xe564, false, "road circle check|accessible|active|check|clear|confirm|enabled|freeway|highway|ok|okay|open|pavement|road|validate|verify|working"},
{0xe565, false, "road circle exclamation|affected|alert|caution|construction|danger|detour|exclamation|freeway|highway|incident|pavement|road|sign|traffic|warning"},
{0xe566, false, "road circle xmark|blocked|cancel|closed|deny|forbidden|freeway|highway|no entry|pavement|remove|restrict|road|route|street|xmark"},
{0xe567, false, "road lock|barrier|blocked|closed|freeway|highway|lock|lockdown|padlock|pavement|privacy|quarantine|restricted|road|security"},
{0xe568, false, "road spikes|barrier|law enforcement|police|road spikes|roadblock|security|spike strip|spike strip roadblock|tire spikes|traffic control|vehicle stop"},
{0xf544, false, "robot|ai|android|android face|artificial intelligence|automate|automation|bot|computer|cyborg|futuristic|machine|robot|technology"},
{0xf135, false, "rocket|astronaut|booster|exploration|flight|launch|missile|nasa|orbit|propulsion|rocket|shuttle|space|spacecraft"},
{0xf2f1, false, "rotate|arrow|clockwise|counterclockwise|cycle|exchange|refresh|reload|reset|retry|rotate|rotation|spin|swap|turn|update"},
{0xf2ea, false, "rotate left|back|cancel|counterclockwise|reset|reverse|revert|rewind|rotate|turn left|undo"},
{0xf2f9, false, "rotate right|clockwise|forward|refresh|reload|renew|repeat|retry|right|rotate|rotate-clockwise|spin|turn"},
{0xf4d7, false, "route|course|directions|itinerary|journey|map|navigation|path|route planning|travel|wayfinding"},
{0xf09e, false, "rss|blog|broadcast|channel|feed|headlines|journal|news|podcast|rss|subscribe|updates"},
{0xf158, false, "ruble sign|currency|currency symbol|money|rouble|ruble|ruble sign|ruble symbol|russian currency|russian ruble|₽"},
{0xe569, false, "rug|area rug|carpet|decorative rug|floor covering|mat|rug|tapestry|textile|throw|woven rug"},
{0xf545, false, "ruler|design|draft|drawing tool|geometry|length|measure|measurement|planning|ruler|ruler icon|ruler tool|scale|straight edge|straight ruler"},
{0xf546, false, "ruler combined|blueprint|design|dimensions|draft|drawing|length|measure|measurement|planning|ruler|scale|size"},
{0xf547, false, "ruler horizontal|design|dimensions|draft|horizontal ruler|layout|length|measure|measurement|planning|ruler|ruler tool|scale"},
{0xf548, false, "ruler vertical|design|dimension|draft|length|measure|measurement|planning|ruler|ruler tool|scale|size|vertical"},
{0xf156, false, "rupee sign|INR|cash|cost|currency|finance|financial|indian currency|money|payment|price|rupee|rupee sign|rupees"},
{0xe23d, false, "rupiah sign|IDR|Indonesian rupiah|cash|currency|currency sign|finance|money|payment|rupiah|symbol"},
{0x53, false, "s|alphabet|character|initial|letter|letter s|lowercase s|symbol|text|typography|uppercase s"},
{0xf81d, false, "sack dollar|bag|burlap|cash|currency|dollar|finance|money|money bag|moneybag|payment|salary|savings|usd|wealth"},
{0xe56a, false, "sack xmark|bag|block|cancel|close|delete|deny|money bag|no entry|reject|remove|sack|sack with x|xmark"},
{0xe84d, false, "sagittarius|archer|astrology|centaur|constellation|december|fire sign|horoscope|november|sagittarius|sign|stars|zodiac"},
{0xe445, false, "sailboat|boat|dinghy|marine|mast|nautical|regatta|sail|sailboat|sailing|vessel|watercraft|yacht"},
{0xf7bf, false, "satellite|GPS|broadcast|communications|orbit|satellite|satellite antenna|satellite dish|satellite network|signal|space|telemetry|transmission"},
{0xf7c0, false, "satellite dish|SETI|antenna|broadcast|communications|dish|radar|receiver|satellite|satellite antenna|satellite dish|saucer|signal|space|telecom|transmission|wireless"},
{0xf24e, false, "scale balanced|Libra|balance|courtroom|equality|equilibrium|fairness|judge|justice|law|legal|measurement|scales|weight|zodiac"},
{0xf515, false, "scale unbalanced|balance|fairness|imbalance|inequality|judgment|justice|law|legal|measure|scale|unbalanced|uneven|weight"},
{0xf516, false, "scale unbalanced flip|balance|court|fairness|inequality|judge|justice|law|legal|measurement|scale|unbalanced|uneven|weight"},
{0xf549, false, "school|academic|campus|classroom|college|education|institution|learning|lecture|school|school building|schoolhouse|student|study|teacher|university"},
{0xe56b, false, "school circle check|approved|check|checkmark|confirm|education|enable|ok|okay|school|schoolhouse|success|validated|verified|working"},
{0xe56c, false, "school circle exclamation|alert|attention|caution|error|exclamation|issue|problem|school|schoolhouse|warning"},
{0xe56d, false, "school circle xmark|cancel|close|delete|dismiss|education|error|reject|remove|school|schoolhouse|xmark"},
{0xe56e, false, "school flag|academic|campus|classroom|education|flag|learning|school|schoolhouse|student|teaching"},
{0xe56f, false, "school lock|closed|lock|lockdown|locked|padlock|privacy|quarantine|restricted|safety|school|schoolhouse|security"},
{0xf0c4, false, "scissors|clip|craft|cut|cutting|modify|office|safety scissors|school|scissors|scissors tool|shear|snip|tool|trim"},
{0xe84e, false, "scorpio|astrology|constellation|horoscope|november|october|scorpio|scorpion|sign|stars|water sign|zodiac"},
{0xf54a, false, "screwdriver|DIY|adjust|configuration|construction|equipment|fix|hardware|loosen|maintenance|mechanic|repair|screwdriver|settings|tighten|tool|toolset"},
{0xf7d9, false, "screwdriver wrench|adjust|admin|build|configuration|equipment|fix|fix-it|handyman|hardware|maintenance|repair|screwdriver|service|settings|tools|wrench"},
{0xf70e, false, "scroll|Dungeons & Dragons|announcement|d&d|dnd|document|fantasy|letter|manuscript|message|paper|parchment|scholar|script|scroll"},
{0xf6a0, false, "scroll torah|hebrew|holy book|jewish|judaism|law|old testament|parchment|religion|scripture|scroll|synagogue|text|torah"},
{0xf7c2, false, "sd card|backup|data|flash card|image|img|memory card|micro sd|photo|portable storage|save|sd card|storage"},
{0xe447, false, "section|citation|document|law|legal|paragraph|reference|section sign|silcrow|symbol|text|writing"},
{0xf4d8, false, "seedling|agriculture|eco|environment|farming|garden|green|growth|nature|plant|sapling|seedling|sprout|vegan|young"},
{0xe820, false, "septagon|7|figure|geometric|heptagon|polygon|septagonal|seven|shape|sided"},
{0xf233, false, "server|backend|cloud|computer|cpu|data center|database|hardware|hosting|mysql|network|rack|server|sql|storage|web server"},
{0xf61f, false, "shapes|blocks|build|circle|figures|forms|geometric|polygons|shapes|square|triangle"},
{0xf064, false, "share|broadcast|communicate|distribute|export|forward|link|post|send|share|social|upload"},
{0xf14d, false, "share from square|arrow|distribute|export|forward|link|send|send-to|share|social|upload"},
{0xf1e0, false, "share nodes|broadcast|communication|connect|distribute|forward|link|network|nodes|send|share|social"},
{0xe571, false, "sheet plastic|barrier|clear cover|film|plastic|plastic wrap|protective cover|sheet|shield|tarp|tarpaulin|waterproof|wrap"},
{0xf20b, false, "shekel sign|currency|finance|ils|israeli currency|israeli shekel|money|new shekel|nis|shekel|sheqel|symbol"},
{0xf132, false, "shield|achievement|armor|award|block|cleric|defend|defense|holy|paladin|protect|safety|security|shield|weapon|winner"},
{0xe572, false, "shield cat|animal|cat|defense|feline|guard|pet|protection|safety|shield|veterinary"},
{0xe573, false, "shield dog|animal|canine|dog|guard|pet|protection|safety|security|shield|veterinary"},
{0xf3ed, false, "shield halved|achievement|armor|award|barrier|block|cleric|defense|guard|holy|paladin|privacy|protect|security|shield|weapon|winner"},
{0xe574, false, "shield heart|favorite|heart|love|protect|protection|safe|safety|secure|shield|wishlist"},
{0xe06c, false, "shield virus|antibodies|barrier|coronavirus|covid-19|disease|flu|health|infection|pandemic|protect|protection|safety|shield|vaccine|virus"},
{0xf21a, false, "ship|boat|cargo|cruise|ferry|maritime|nautical|ocean|passenger|sailing|sea|ship|transport|vessel|water"},
{0xf553, false, "shirt|apparel|casual wear|clothing|garment|outfit|shirt|short sleeve|t-shirt|top|tshirt"},
{0xf54b, false, "shoe prints|footpath|footprints|footsteps|shoeprints|steps|tracks|trail|trail marks|walking"},
{0xf54f, false, "shop|bodega|boutique|building|buy|commerce|mall|market|outlet|purchase|retail|shop|shopping|store"},
{0xe4a5, false, "shop lock|buy|closed|lock|lockdown|market|padlock|privacy|purchase|retail|secure|security|shop|shopping|store|storefront"},
{0xe070, false, "shop slash|blocked|buy|closed|disabled|forbidden|no shopping|purchase|retail|shop|shopping|slash|store|storefront|unavailable"},
{0xf2cc, false, "shower|bath|bathroom|clean|faucet|hygiene|rinse|shower|spray|water|wet"},
{0xe448, false, "shrimp|allergy|crustacean|edible|fishing|marine|ocean|prawn|seafood|seafood allergy|shellfish|shellfish allergy|shrimp|tail"},
{0xf074, false, "shuffle|arrows|crossed|mix|music|playlist|random|randomize|reorder|shuffle|shuffle tracks|swap|switch|tracks|transfer"},
{0xf197, false, "shuttle space|NASA|aerospace|astronaut|launch|orbit|rocket|shuttlecraft|space|space shuttle|space travel|spacecraft|transportation"},
{0xf4d9, false, "sign hanging|announcement|directions|display|hanging sign|notice|placard|real estate|shop sign|signage|signpost|storefront|wayfinding"},
{0xf012, false, "signal|antenna|cell|cellular|connectivity|coverage|mobile|network|online|phone|reception|signal|signal bars|status|strength|wireless"},
{0xf5b7, false, "signature|John Hancock|approval|autograph|cursive|document|endorsement|handwriting|name|sign|signature|signature line|signing|written name"},
{0xf277, false, "signs post|directions|directory|guide|map|marker|navigation|pointer|route|sign|signage|signpost|street sign|trail|wayfinding"},
{0xf7c4, false, "sim card|card|cellular|chip|data|hardware|mobile|network|phone|portable|sim|sim card|simcard|technology|tiny"},
{0xe81b, false, "single quote left|apostrophe-like|citation|dialogue|left single quotation mark|opening quote|punctuation|quotation|quote|speech|text"},
{0xe81c, false, "single quote right|apostrophe|citation|dialogue|note|phrase|punctuation|quotation|quote|right single quotation mark|single quote|speech|text"},
{0xe06d, false, "sink|basin|bathroom|faucet|handwashing|hygiene|kitchen|plumbing|tap|wash|water"},
{0xf0e8, false, "sitemap|directory|flowchart|hierarchy|information architecture|map|navigation|organization|outline|site map|sitemap|structure|web structure"},
{0xf54c, false, "skull|bones|danger|death|face|halloween|horror|monster|poison|skeleton|skull|spooky|x-ray|yorick"},
{0xf714, false, "skull crossbones|alert|bones|crossbones|danger|danger symbol|deadly|death|halloween|hazard|jolly-roger|pirate|poison|skull|skull and crossbones|skull icon|toxic|warning|warning sign"},
{0xf715, false, "slash|block|cancel|close|cross|disable|forbidden|mute|negate|no|off|prohibit|remove|stop|x"},
{0xf7cc, false, "sleigh|christmas|claus|festive|flying sleigh|gift|holiday|north pole|present|reindeer|santa|sled|snow|winter|xmas|yuletide"},
{0xf1de, false, "sliders|adjust|configuration|controls|customize|dashboard|equalizer|filter|interface|mixer|modify|options|panel|preferences|settings|sliders|tuning|volume"},
{0xf75f, false, "smog|air quality|dirty air|environmental|exhaust|fog|haze|pollution|smog|smoggy|smoke|smokescreen|weather"},
{0xf48d, false, "smoking|addiction|cigarette|cigarette smoke|health risk|lung cancer|nicotine|no smoking|smoke|smoker|smoking|smoking area|smoking ban|tobacco"},
{0xf2dc, false, "snowflake|blizzard|cold|freeze|frost|ice|precipitation|snow|snowfall|snowflake|winter"},
{0xf7d0, false, "snowman|cold|decoration|frost|frosty|holiday|snow|snow figure|snow sculpture|snowman|snowman face|snowman icon|snowman without snow|winter|winter fun"},
{0xf7d2, false, "snowplow|clean up|cold|plow|road clearing|snow|snow clearing|snow removal|snowplow|storm|vehicle|winter"},
{0xe06e, false, "soap|bar|bathing|bubbles|clean|cleaning|disinfect|foam|germ|hygiene|hygiene product|lather|sanitizer|soap|suds|wash"},
{0xf696, false, "socks|ankle socks|clothing|cotton socks|cozy|crew socks|feet|flight of the conchords|footwear|hosiery|socks|socks and shoes|stockings|warm|wednesday|wool socks"},
{0xf5ba, false, "solar panel|clean|eco-friendly|electricity|energy|environment|green|panel|photovoltaic|power|renewable|solar|sun|sustainable"},
{0xf0dc, false, "sort|arrange|filter|order|organize|prioritize|ranking|sequence|sort|sort ascending|sort descending"},
{0xf0dd, false, "sort down|arrow|arrow down|decrease|descending|down|down arrow|filter|order|sort|sort down|sort-desc"},
{0xf0de, false, "sort up|arrow|arrow-up|ascending|filter|growth|increase|order|rise|sort|sort-asc|up|upgrade|upward"},
{0xf5bb, false, "spa|aromatherapy|calm|flora|health|massage|mindfulness|plant|rejuvenation|relaxation|self-care|spa|therapy|wellness"},
{0xf67b, false, "spaghetti monster flying|agnosticism|atheism|flying spaghetti monster|fsm|noodly appendage|parody religion|pasta|pastafarian|satire|skeptic"},
{0xf891, false, "spell check|check|correction|dictionary|editing|editor|grammar|language|proofreading|spell check|spellcheck|text|validate|writing"},
{0xf717, false, "spider|arachnid|bug|charlotte|crawl|creepy|eight legs|halloween|insect-like|pest|spider|web"},
{0xf110, false, "spinner|buffering|busy|circle|hourglass|loading|pending|processing|progress|spinner|wait|working"},
{0xe80a, false, "spiral|circular|coil|curl|dizzy|helix|loop|rotate|spin|spiral|spiral staircase|swirl|twist|vortex"},
{0xf5bc, false, "splotch|blob|blotch|drop|ink|mark|paint|smudge|spill|splash|stain"},
{0xf2e5, false, "spoon|cutlery|dining|eating|food|kitchen|scoop|silverware|spoon|tableware|utensil"},
{0xf5bd, false, "spray can|aerosol|art|can|coloring|graffiti|paint|spray|spray bottle|spray paint|stencil|street art|tag"},
{0xf5d0, false, "spray can sparkles|aerosol|air freshener|clean|deodorize|fragrance|fresh|mist|perfume|pine|scent|shine|sparkle|spray|spray can"},
{0xf0c8, false, "square|black square|block|box|geometric|quadrilateral|rectangle|shape|solid square|square|square shape|white square"},
{0xf14c, false, "square arrow up right|arrow|diagonal|direction|export|external|link|navigate|new|open|out|send|share|up-right"},
{0xe69b, false, "square binary|ai|algorithm|binary|code|computing|data|digital|language|llm|model|programming|token"},
{0xf150, false, "square caret down|arrow|caret|down|dropdown|expand|indicator|menu|more|navigation|pointer|square|toggle|triangle"},
{0xf191, false, "square caret left|arrow|back|caret|direction|left|navigation|pointer|previous|square|triangle"},
{0xf152, false, "square caret right|arrow|arrowhead|caret|forward|navigation|next|play|pointer|right|skip|square|triangle"},
{0xf151, false, "square caret up|arrow|arrow-up|arrowhead|caret|caret-square-o-up|collapse|expand|increase|pointer|square|triangle|up|up arrow|up caret|upload"},
{0xf14a, false, "square check|accept|agree|box|button|check|check mark|checkbox|checkmark|confirm|correct|done|enable|mark|ok|select|success|tick|validate|yes"},
{0xf199, false, "square envelope|communication|contact|correspondence|e-mail|email|envelope|inbox|letter|mail|message|message alert|notification|support"},
{0xf45c, false, "square full|block|color block|colored square|filled square|geometric shape|shape|solid square|square"},
{0xf0fd, false, "square h|aid|clinic|directions|emergency|health|healthcare|hospital|letter h|map|medical|sign|wayfinding"},
{0xf146, false, "square minus|close|collapse|hide|hide-content|minimize|minus|negative|reduce|remove|shrink|square|subtract"},
{0xe576, false, "square nfi|aid|essentials|goods|humanitarian|materials|non-food item|provisions|relief|supplies|support items"},
{0xf540, false, "square parking|automobile|car|garage|lot|meter|park|parking|parking-lot|parking-space|space|square|vehicle"},
{0xf14b, false, "square pen|annotate|compose|document|draft|edit|form|modify|note|pen|pencil|signature|update|write"},
{0xe577, false, "square person confined|captivity|confined|detained|enclosed|isolated|locked-in|prisoner|restricted|trapped"},
{0xf098, false, "square phone|call|communication|contact|device|handset|mobile|phone|support|telephone|voice"},
{0xf87b, false, "square phone flip|call|cell|communication|device|flip phone|handset|mobile|phone|support|telephone|voice"},
{0xf0fe, false, "square plus|add|box|create|expand|increase|more|new|plus|positive|shape|square"},
{0xf682, false, "square poll horizontal|chart|comparison|data|feedback|graph|horizontal bars|options|poll|questionnaire|rating|results|statistics|survey|vote|voting"},
{0xf681, false, "square poll vertical|analysis|bar chart|chart|comparison|data|feedback|graph|metrics|poll|results|statistics|survey|vertical bars|vote|voting"},
{0xf698, false, "square root variable|algebra|arithmetic|calculation|equation|formula|math|mathematics|radical|root symbol|square root|variable"},
{0xf143, false, "square rss|atom|blog|broadcast|channel|feed|journal|news|podcast|rss|subscription|syndication|updates|writing|xml"},
{0xf1e1, false, "square share nodes|connect|distribute|export|forward|link|network|send|share|social|upload"},
{0xf360, false, "square up right|arrow|diagonal|direction|exit|external-link|external-link-square|forward|launch|link|navigate|northeast|open|share|shortcut|up-right arrow"},
{0xe578, false, "square virus|contagion|coronavirus|covid-19|disease|germ|illness|infection|outbreak|pandemic|pathogen|virus"},
{0xf2d3, false, "square xmark|cancel|close|cross|cross mark|dismiss|error|exit|incorrect|mark|problem|remove|square|stop|wrong|x"},
{0xe579, false, "staff snake|asclepius|asklepian|caduceus|healing|health|healthcare|medical|medicine|pharmacy|serpent|snake|wellness"},
{0xe289, false, "stairs|ascent|climb|exit|staircase|stairs|stairway|steps|up"},
{0xf5bf, false, "stamp|approval|certification|endorsement|imprint|mark|official|rubber stamp|seal|stamp|validation"},
{0xe5af, false, "stapler|binder|clip|desktop|document|fastening|office|paper|staple|stapler|stationery"},
{0xf005, false, "star|achievement|award|bookmark|favorite|favorite item|highlight|important|night|premium|quality|rating|score|star|top|vip"},
{0xf699, false, "star and crescent|Islam|Islamic symbol|Muslim|Muslim faith|crescent and star|crescent moon|faith|religion|star and crescent"},
{0xf089, false, "star half|achievement|award|feedback|half star|half-filled star|partial rating|rating|review|score|star half|star outline"},
{0xf5c0, false, "star half stroke|achievement|award|favorite|feedback|half star|partial rating|rating|review|score|star half|star half empty|star half full"},
{0xf69a, false, "star of david|David|Israel|Jewish|Jewish star|Judaism|faith|heritage|hexagram|religion|star of David|symbol"},
{0xf621, false, "star of life|ambulance|emergency|emergency medical services|emt|first aid|health|healthcare|lifesaver|medical|paramedic|rescue|star of life"},
{0xf154, false, "sterling sign|GBP|british pound|currency|currency symbol|finance|money|pound|sterling"},
{0xf0f1, false, "stethoscope|auscultation|clinic|diagnosis|doctor|examination|health|healthcare|heart|hospital|medical|medical equipment|medicine|nurse|physician|stethoscope"},
{0xf04d, false, "stop|block|cancel|end|forbidden|halt|no entry|pause|prohibition|red square|square|stop|stop button|stop sign|warning"},
{0xf2f2, false, "stopwatch|chronometer|clock|countdown|stopwatch|stopwatch clock|stopwatch device|stopwatch icon|stopwatch measurement|stopwatch symbol|stopwatch timer|stopwatch tracking|stopwatch watch|time|timer|timing"},
{0xe06f, false, "stopwatch 20|chronometer|clock|countdown|reminder|seconds|stopwatch|stopwatch clock|stopwatch countdown|stopwatch reminder|stopwatch timer|time|timer|timing"},
{0xf54e, false, "store|bodega|boutique|building|business|buy|commerce|mall|market|outlet|purchase|retail|shop|shopping|store|storefront"},
{0xe071, false, "store slash|blocked|building|buy|cancel|closed|disabled|forbidden|no entry|purchase|shop|shopping|slash|stop|store|unavailable"},
{0xf21d, false, "street view|directions|explore|gps|location|map|navigation|panorama|route|street|street-level|travel|view"},
{0xf0cc, false, "strikethrough|cancel|cross out|delete|edit|font|format|line-through|modify|remove|strike|strikethrough|text|type"},
{0xf551, false, "stroopwafel|Dutch|biscuit|caramel|cookie|dessert|snack|stroopwafel|sweets|syrup|treat|waffle"},
{0xf12c, false, "subscript|character|edit|font|formatting|script|style|subscript|text|type|typography"},
{0xf0f2, false, "suitcase|bag|baggage|briefcase|carry-on|holiday|journey|luggage|moving|packing|suitcase|suitcase icon|travel|travel bag|trip|vacation"},
{0xf0fa, false, "suitcase medical|aid|case|emergency|first aid|firstaid|health|help|kit|medical|medical bag|medical kit|supplies|support"},
{0xf5c1, false, "suitcase rolling|baggage|carry-on|journey|luggage|packing|rolling suitcase|suitcase|suitcase with wheels|travel|travel bag|trip|trolley bag|vacation|wheeled luggage"},
{0xf185, false, "sun|bright|daylight|daytime|rays|sol|solar|star|sun|sunlight|sunny|sunshine|warmth|weather"},
{0xe57a, false, "sun plant wilt|arid|droop|drought|dry|heat damage|plant stress|sun damage|thirsty|wilt|wither"},
{0xf12b, false, "superscript|edit|exponent|font|format|math|power|raised|script|superscript|text|typing"},
{0xf5c3, false, "swatchbook|Pantone|color|color chart|color picker|colors|design|hue|paint|palette|sample|shades|swatch|tint|tone"},
{0xf69b, false, "synagogue|Jewish|Judaism|Star of David|community center|faith|house of worship|religion|synagogue|synagogue building|temple"},
{0xf48e, false, "syringe|covid-19|doctor|flu shot|immunization|immunizations|injection|inoculation|medical|medicine|needle|shot|syringe|vaccinate|vaccination|vaccine"},
{0x54, false, "t|alphabet|capital t|character|letter t|lowercase t|symbol|text"},
{0xf0ce, false, "table|chart|columns|data|database|excel|grid|report|rows|sheet|spreadsheet|table"},
{0xf00a, false, "table cells|blocks|boxes|cells|chart|columns|data|excel|grid|layout|matrix|organize|rows|spreadsheet|squares|table"},
{0xe678, false, "table cells column lock|block|cells|column|data|excel|grid|lock|locked-column|protected|restricted|secure|sheet|spreadsheet|table"},
{0xf009, false, "table cells large|blocks|boxes|category|cells|columns|data|excel|grid|layout|matrix|rows|spreadsheet|squares|table"},
{0xe67a, false, "table cells row lock|block|boxes|cells|column|data|excel|grid|lock|locked|protected|row|secure|spreadsheet|table"},
{0xe691, false, "table cells row unlock|access|blocks|boxes|cells|column|data|edit|grid|open|row|spreadsheet|table|unlock|unlocked"},
{0xf0db, false, "table columns|browser|columns|dashboard|data|grid|layout|organize|panes|sections|split|spreadsheet|table|view"},
{0xf00b, false, "table list|category|checklist|columns|completed|data|done|finished|items|list|organized|rows|summary|table|tasks|todo"},
{0xf45d, false, "table tennis paddle ball|ball|bat|game|paddle|ping pong|ping-pong ball|ping-pong paddle|racket|sport|table tennis"},
{0xf3fb, false, "tablet|device|e-reader|gadget|kindle|mobile|portable|screen|slate|tablet|touchscreen"},
{0xf10a, false, "tablet button|device|digital reader|electronic|gadget|ipad|kindle|mobile|screen|slate|tablet|touchscreen"},
{0xf3fa, false, "tablet screen button|device|digital reader|gadget|ipad|kindle|mobile|screen|slate|tablet|touchscreen"},
{0xf490, false, "tablets|capsules|drugs|health|medication|medicine|pharmaceutical|pills|prescription|remedy|tablets|treatment"},
{0xf566, false, "tachograph digital|dashboard|data|digital|distance|driving|gauge|instrument|meter|speed|speedometer|tachograph|vehicle"},
{0xf02b, false, "tag|badge|coupon|discount|label|marker|price|price tag|sale|shopping|sticker|tag|tag price|ticket"},
{0xf02c, false, "tags|clearance|coupon|deal|discount|label|markdown|offer|price|price tag|sale|shopping|tag|tag price"},
{0xf4db, false, "tape|adhesive|duct tape|masking tape|packaging|roll|sealing|sticky|sticky tape|tape|tape dispenser|tape measure|tape roll"},
{0xe57b, false, "tarp|canopy|cover|groundsheet|outdoor|protection|rain cover|shelter|tarp|tarp tent|waterproof"},
{0xe57c, false, "tarp droplet|cover|droplet|moisture|outdoor|protection|rain|shelter|tarp|water|waterproof"},
{0xe84f, false, "taurus|april|astrology|bull|constellation|earth sign|horoscope|may|sign|stars|taurus|zodiac"},
{0xf1ba, false, "taxi|cab|cabbie|car|car service|dropoff|fare|pickup|ride|rideshare|taxi|taxi cab|taxi driver|transportation|travel|vehicle|yellow cab"},
{0xf62e, false, "teeth|bite|braces|chewing|dental|dentist|enamel|gums|hygiene|incisor|molar|mouth|oral|plaque|smile|tooth"},
{0xf62f, false, "teeth open|bite|canines|chewing|dental|dentist|gums|jaw|molars|mouth|oral|smile|teeth|tooth"},
{0xe03f, false, "temperature arrow down|air conditioner|arrow down|chill|cold|cooling|decrease|drop|temperature|thermometer|winter"},
{0xe040, false, "temperature arrow up|air conditioner|climate|heat|heat increase|heater|heating|hot|mercury|rising temperature|temperature|temperature rise|thermometer|warmer|weather"},
{0xf2cb, false, "temperature empty|chilly|climate|cold|empty|freeze|frost|gauge|indicator|low|temperature|thermometer|weather"},
{0xf2c7, false, "temperature full|climate|fever|heat|hot|mercury|status|temperature|thermometer|warmth|weather"},
{0xf2c9, false, "temperature half|climate|cold|degree|gauge|heat|measurement|mercury|sensor|status|temperature|thermometer|weather"},
{0xf769, false, "temperature high|cook|fever|heat|hot|mercury|summer|temperature|thermometer|warm|weather"},
{0xf76b, false, "temperature low|chilly|cold|cold weather|cool|freeze|frost|icy|low temperature|thermometer|winter"},
{0xf2ca, false, "temperature quarter|climate|cold|gauge|heat|level|mercury|status|temperature|thermometer|weather"},
{0xf2c8, false, "temperature three quarters|climate|degree|gauge|heat|mercury|status|temperature|thermometer|warm|weather"},
{0xf7d7, false, "tenge sign|KZT|Kazakhstani currency|Kazakhstani tenge|Tenge|currency|currency symbol|financial symbol|money|payment|price"},
{0xe57d, false, "tent|backpacking|bivouac|campground|camping|camping equipment|camping gear|camping shelter|camping tent|camping trip|campsite|hiking|outdoor|shelter|temporary shelter|tent"},
{0xe57e, false, "tent arrow down to line|arrow down|arrow down to line|bivouac|campground|camping|camping gear|camping site|campsite|outdoor|pitched tent|shelter|temporary shelter|tent|tent setup"},
{0xe57f, false, "tent arrow left right|arrows|bivouac|campground|camping|campsite|direction|left-right|move|navigation|outdoor|shelter|tent|transition|travel"},
{0xe580, false, "tent arrow turn left|arrow|bivouac|campground|camping|campsite|direction|left|navigation|outdoor|shelter|temporary|tent|turn"},
{0xe581, false, "tent arrows down|arrows-down|bivouac|campground|camping|campsite|insert|outdoor|refugee|shelter|tent"},
{0xe582, false, "tents|bivouac|campground|camping|camping gear|camping shelter|camping site|camping tent|campsite|outdoor|outdoor shelter|shelter|temporary shelter|tent"},
{0xf120, false, "terminal|cli|code|coding|command|command line|command prompt|console|developer|development|programming|prompt|script|shell|terminal"},
{0xf034, false, "text height|edit|font|format|formatting|height|resize|size|style|text|type|typography"},
{0xf87d, false, "text slash|block|cancel|disabled|font|forbidden|format|no-text|remove|strike|strikethrough|style|text"},
{0xf035, false, "text width|adjust|alignment|edit|format|layout|paragraph|resize|text|type|typography|width"},
{0xf491, false, "thermometer|cold|covid-19|fever|health|heat|medical|mercury|status|temperature|thermometer"},
{0xf165, false, "thumbs down|disagree|disapprove|dislike|dislike button|downvote|hand gesture|negative|no|thumb down|thumbs down|thumbs-o-down"},
{0xf164, false, "thumbs up|+1|agree|approve|endorsement|good|hand|like|ok|okay|positive|recommend|social|success|support|thumb|thumbs up|vote|yes"},
{0xf08d, false, "thumbtack|drop|location|map|map-pin|marker|office|pin|place|pushpin|stationery|tack|thumbtack"},
{0xe68f, false, "thumbtack slash|block pin|cancel location|disable location|location|map pin off|marker|no pin|pin|pushpin|remove pin|thumbtack|unpin"},
{0xf145, false, "ticket|admission|admission ticket|boarding pass|concert|coupon|entry|event|movie|pass|show|ticket|voucher"},
{0xf3ff, false, "ticket simple|admission|boarding|concert|coupon|entry|event|movie|pass|stub|support|ticket|voucher"},
{0xe29c, false, "timeline|agenda|chronological|deadline|events|history|linear|milestones|progress|roadmap|schedule|sequence|timeline chart"},
{0xf204, false, "toggle off|UI|button|control|disable|inactive|off|option|power|setting|slider|switch|toggle"},
{0xf205, false, "toggle on|active|button|control|enabled|on|power|setting|slider|switch|toggle"},
{0xf7d8, false, "toilet|bathroom|bathroom fixture|commode|flush|john|lavatory|loo|pee|plumbing|poop|porcelain|potty|restroom|restroom fixture|sanitary|throne|toilet|washroom|waste|water closet|wc"},
{0xf71e, false, "toilet paper|bathroom|bathroom roll|bathroom tissue|bidet|clean-up|hygiene|lavatory|paper roll|restroom|restroom essentials|roll|sanitary|tissue|toilet|toilet paper|wipe"},
{0xe072, false, "toilet paper slash|bathroom|blocked|covid-19|disabled|lavatory|no toilet paper|no wipe|out of toilet paper|paperless|prank|restroom|roll|shortage|toilet paper|wipe"},
{0xe583, false, "toilet portable|mobile restroom|outdoor toilet|outhouse|porta john|porta potty|porta-potty|portable restroom|portable toilet|temporary toilet|toilet"},
{0xe584, false, "toilets portable|chemical toilet|event restroom|mobile toilet|outdoor toilet|outhouse|porta-john|porta-potty|portable restroom|portable toilet|toilet"},
{0xf552, false, "toolbox|box|chest|configuration|container|equipment|fix|hardware|kit|maintenance|mechanic|modify|repair|settings|tool|toolbox|tools"},
{0xf5c9, false, "tooth|bicuspid|canine|cavity|dental|dentist|enamel|hygiene|incisor|molar|mouth|oral|root|smile|teeth|tooth"},
{0xf6a1, false, "torii gate|archway|entrance|gate|japan|japanese|religion|shinto|shinto shrine|shrine|spiritual|temple|torii|traditional"},
{0xf76f, false, "tornado|cloud|cyclone|funnel|landspout|storm|tornado|twister|vortex|waterspout|weather|whirlwind"},
{0xf519, false, "tower broadcast|antenna|broadcast|broadcast-tower|communication|emergency-alert|network|radio|reception|signal|tower|transmission|waves|wifi"},
{0xe585, false, "tower cell|antenna|broadcast|cell tower|cellphone|communication|mobile|network|radio|reception|signal|tower|transmission|waves|wireless"},
{0xe586, false, "tower observation|fire tower|lookout|lookout point|observation deck|observation tower|panorama|scenic view|tower|viewing platform|watchtower"},
{0xf722, false, "tractor|agriculture|cultivation|farm|farm machinery|farming|farming equipment|rural|tractor|tractor vehicle|vehicle"},
{0xf25c, false, "trademark|brand|copyright|intellectual property|legal|logo|mark|protection|registered|symbol|tm|trade mark|trademark"},
{0xf637, false, "traffic light|control|go|intersection|light|lights|road|safety|signal|slow|stop|street|traffic|vertical traffic light|warning"},
{0xe041, false, "trailer|camper|caravan|cargo|carry|haul|moving|towing|trailer|trailer hitch|trailer truck|transport|travel|vehicle"},
{0xf238, false, "train|bullet|commute|locomotive|metro|passenger|rail|railway|subway|train|transit|transportation|travel"},
{0xf239, false, "train subway|commuter|metro|public transport|railway|subway|train|transit|transportation|underground|vehicle"},
{0xe5b4, false, "train tram|commute|light rail|public transit|rails|streetcar|train|tram|transportation|trolleybus|urban transit|vehicle"},
{0xf225, false, "transgender|LGBTQ|female|gender|gender identity|gender symbol|intersex|male|nonbinary|queer|trans|transgender|transgender symbol"},
{0xf1f8, false, "trash|bin|delete|discard|garbage|recycle|remove|rubbish|trash|trashcan|waste"},
{0xf829, false, "trash arrow up|back|delete|garbage|oops|recover|recycle|remove|restore|retrieve|revert|trash|undo"},
{0xf2ed, false, "trash can|bin|delete|discard|dumpster|garbage|recycle|remove|rubbish|trash|trashcan|waste"},
{0xf82a, false, "trash can arrow up|back|delete|garbage|recover|recycle|restore|retrieve|revert|trash|trash can|undelete|undo"},
{0xf1bb, false, "tree|autumn|bark|deciduous|environment|evergreen|foliage|forest|growth|leaf|nature|outdoors|plant|seasonal|tree|wood"},
{0xe587, false, "tree city|architecture|buildings|city|cityscape|downtown|environment|green|metropolis|nature|skyline|tree|urban"},
{0xf071, false, "triangle exclamation|alert|alert-triangle|attention|caution|danger|error|exclamation|failed|hazard|important|notice|notification|notify|problem|required|warning|warning-sign"},
{0xf091, false, "trophy|achievement|award|champion|competition|cup|honor|prize|reward|success|trophy|victory|winner"},
{0xe589, false, "trowel|bricklaying|building|cement|construction|equipment|gardening|hand tool|masonry|plastering|tool|trowel"},
{0xe58a, false, "trowel bricks|bricklaying|build|cement|construction|labor|masonry|mortar|renovation|repair|tool|trowel"},
{0xf0d1, false, "truck|cargo|delivery|delivery truck|freight|hauler|lorry|pickup|shipping|transport|truck|truck icon|vehicle"},
{0xe58b, false, "truck arrow right|arrow|cargo|delivery|dispatch|fast|forward|freight|logistics|move|send|shipping|transport|truck"},
{0xe58c, false, "truck droplet|delivery|droplet|fluid|hydration|liquid|supply|tanker|transport|truck|water"},
{0xf48b, false, "truck fast|courier|delivery|express|fast|fedex|freight|logistics|mail|overnight|package|quick|shipping|transport|truck|ups"},
{0xe58d, false, "truck field|agriculture|cargo|delivery|farm|farming|field|pickup|supply|transport|truck"},
{0xe58e, false, "truck field un|UN|United Nations|aid|delivery|field truck|humanitarian|logistics|supplies|transport|truck|vehicle"},
{0xe2b7, false, "truck front|cargo|delivery|freight|front view|lorry|shipping|shuttle|transport|truck|van|vehicle"},
{0xf0f9, false, "truck medical|aid|ambulance|clinic|emergency|emt|er|health|hospital|medical|mobile|paramedic|rescue|support|vehicle"},
{0xf63b, false, "truck monster|4x4|dirt|large tires|monster truck|offroad|racing|stunt|truck|vehicle|wheels"},
{0xf4df, false, "truck moving|cargo|delivery|freight|inventory|load|logistics|moving|relocation|rental|shipping|transport|truck|van|vehicle"},
{0xf63c, false, "truck pickup|cargo|light truck|pickup|pickup truck|pickup truck bed|pickup truck cab|pickup truck icon|pickup truck vehicle|truck|utility truck|vehicle|work truck"},
{0xe58f, false, "truck plane|air freight|airplane|cargo|delivery|freight|logistics|plane|shipping|transport|transport truck|transport vehicle|truck|vehicle"},
{0xf4de, false, "truck ramp box|box|cargo|delivery|freight|inventory|loading|logistics|moving|package|ramp|rental|shipping|transport|truck|vehicle"},
{0xf1e4, false, "tty|TTY|accessibility|assistive device|communication|communication device|deaf|relay service|telephone|teletypewriter|text|text phone"},
{0xe2bb, false, "turkish lira sign|TRY|Turkish Lira|Turkish Lira Sign|Turkish currency|cash|currency|financial|lira|money|payment"},
{0xf3be, false, "turn down|arrow|arrow bend|arrow turning|curve down|curved arrow|direction|down|navigation|rotate down|turn down"},
{0xf3bf, false, "turn up|arrow|boost|increase|level-up|raise|right arrow curving up|turn up|upward curve|volume up"},
{0xf26c, false, "tv|broadcast|display|entertainment|flat screen|home theater|monitor|screen|smart tv|television|tv|tv set|video"},
{0x55, false, "u|alphabet|character|latin letter u|letter u|lowercase u|symbol|uppercase u"},
{0xf0e9, false, "umbrella|drizzle|protection|rain|shade|shelter|storm|umbrella|waterproof|weather|wet"},
{0xf5ca, false, "umbrella beach|beach|holiday|protection|recreation|resort|sand|seaside|shade|summer|sun|sunshade|tropical|umbrella|vacation"},
{0xf0cd, false, "underline|edit|emphasis|emphasize|formatting|highlight|style|text|typography|underline|writing"},
{0xf29a, false, "universal access|access|accessibility|assistive|disability|disabled|handicap|inclusive|people|universal access|users|wheelchair"},
{0xf09c, false, "unlock|access|admin|key|lock|open|padlock|password|permission|privacy|protect|security|unlock|unlocked"},
{0xf13e, false, "unlock keyhole|access|admin|authentication|key|keyhole|open lock|password|privacy|protect|security|unlock|unlocked"},
{0xf338, false, "up down|adjust|arrow|arrows-v|direction|down arrow|expand|height|move|resize|scroll|tall|up arrow|up-down|vertical"},
{0xf0b2, false, "up down left right|adjust|arrow|arrows|compass|directions|drag|enlarge|expand|four-way|move|navigation|pointer|position|reorder|resize"},
{0xf30c, false, "up long|arrow|arrow-up|direction|increase|long-arrow-up|move up|rise|up|upgrade|upload|upward"},
{0xf424, false, "up right and down left from center|arrows|diagonal|enlarge|expand|fullscreen|grow|increase|maximize|resize|scale|zoom"},
{0xf35d, false, "up right from square|arrow-up-right|export|external-link|launch|link|new|open|outside|redirect|share|window"},
{0xf093, false, "upload|arrow up|backup|cloud|data transfer|import|publish|save|send|send file|transfer|upload"},
{0xf007, false, "user|account|avatar|default|employee|gender-neutral|identity|individual|member|person|profile|silhouette|user|username"},
{0xf4fb, false, "user astronaut|astronaut|avatar|cosmonaut|explorer|helmet|nasa|space|space suit|space traveler|spaceman|suit"},
{0xf4fc, false, "user check|active|approve|check|confirm|employee|enabled|person|user|validate|verified|working"},
{0xf4fd, false, "user clock|attendance|clock|employee|login-time|person|profile|punctuality|schedule|shift|time|timer|user|working-hours"},
{0xf0f0, false, "user doctor|covid-19|doctor|health|healthcare|medical|nurse|occupation|physician|profile|surgeon|worker"},
{0xf4fe, false, "user gear|account|employee|gear|people|person|preferences|profile|settings|user|user-management|users"},
{0xf501, false, "user graduate|academic|cap|diploma|education|graduate|graduation|learner|mortarboard|person|student|user"},
{0xf500, false, "user group|community|crowd|employees|group|members|people|silhouettes|team|together|user|users"},
{0xf728, false, "user injured|accident|accident victim|disabled|emergency|employee|health|hurt|injured|injury|medical|person|safety|user|worker"},
{0xf502, false, "user lock|access|account|employee|lock|login|padlock|privacy|profile|protected|secure|security|user"},
{0xf503, false, "user minus|delete|employee|minus|negative|remove|remove-account|remove-person|remove-user|subtract|user"},
{0xf504, false, "user ninja|assassin|avatar|covert|deadly|fighter|hidden|ninja|shadow|silent|sneaky|spy|stealth|stealthy|warrior"},
{0xf82f, false, "user nurse|caregiver|covid-19|doctor|health|healthcare|hospital|medical|midwife|nurse|physician|practitioner|surgeon|worker"},
{0xf4ff, false, "user pen|account|avatar|edit|employee|modify|people|person|profile|user|users"},
{0xf234, false, "user plus|add|add user|avatar|create user|employee|follow|join|member|new user|person|plus|positive|profile|sign up|signup|team|user"},
{0xf21b, false, "user secret|anonymous|detective|disguise|hidden|identity|incognito|person|privacy|secret|sleuth|spy|user"},
{0xf505, false, "user shield|account|employee|guard|privacy|profile|protect|protection|safety|security|shield|user"},
{0xf506, false, "user slash|ban|block|disable|disconnect|employee|forbidden|no user|remove|user disabled|user off"},
{0xf507, false, "user tag|account|avatar|contact|employee|identity|member|people|person|profile|user"},
{0xf508, false, "user tie|administrator|avatar|business|clothing|employee|executive|formal|manager|office|person|professional|profile|suit|tie|user"},
{0xf235, false, "user xmark|block|cancel|close|delete|deny|employee|reject|remove|uncheck|user|x"},
{0xf0c0, false, "users|accounts|collaboration|community|contacts|employees|group|members|people|persons|profiles|team|user|users"},
{0xe591, false, "users between lines|crowd|employees|group|multiple|people|team|together|users"},
{0xf509, false, "users gear|administration|employee|gear|group|manage|people|settings|team|user management|users"},
{0xe592, false, "users line|community|crowd|employee|group|members|people|team|together|users"},
{0xe593, false, "users rays|audience|community|crowd|employees|focused|group|people|rays|team|users"},
{0xe594, false, "users rectangle|community|contacts|crowd|employees|group|members|people|profile|team|users"},
{0xe073, false, "users slash|banned|blocked|disabled|disconnect|employee|group|no access|people|removed|slash|user|users"},
{0xe595, false, "users viewfinder|audience|crowd|focus|group|highlight|identify|people|selection|spotlight|targeted|user|zoom"},
{0xf2e7, false, "utensils|cooking|cutlery|dining|dinner|eat|eating utensils|food|fork|knife|meal|restaurant|silverware|spoon|tableware"},
{0x56, false, "v|alphabet|capital v|character|letter v|lowercase v|symbol|typography"},
{0xf5b6, false, "van shuttle|airport|commute|minibus|passenger|public-transportation|ride|shuttle|transit|transportation|travel|van|vehicle"},
{0xe2c5, false, "vault|bank|deposit|finance|investment|lock|money|premium|privacy|protection|safe|salary|savings|secure|treasure|vault"},
{0xf221, false, "venus|female|female gender|female gender symbol|female icon|female sex|female sign|female symbol|feminism|gender|girl|woman|woman symbol"},
{0xf226, false, "venus double|LGBTQ|double venus|female|female couple|female symbol|feminism|gender|gender identity|lesbian|queer|womanhood|women"},
{0xf228, false, "venus mars|female|gender|gender identity|gender signs|gender symbols|heterosexual|interlocked|male|male and female|relationship|sex"},
{0xe085, false, "vest|apparel|biker|clothing|fashion|outerwear|sleeveless|style|vest|waistcoat"},
{0xe086, false, "vest patches|biker|club|emblem|fashion|insignia|jacket|motorcycle|patches|style|vest"},
{0xf492, false, "vial|ampule|chemistry|container|drug|experiment|flask|lab|laboratory|medicine|pharmaceutical|sample|science|test|test tube|vial"},
{0xe596, false, "vial circle check|ampule|approved|check|chemical|chemistry|confirmed|health|lab|laboratory|medicine|ok|success|test tube|vaccine|validate|vial|working"},
{0xe597, false, "vial virus|ampule|coronavirus|covid-19|flu|immunization|infection|lab|laboratory|medicine|pandemic|syringe|test|test tube|vaccine|vial|virus"},
{0xf493, false, "vials|ampule|chemistry|experiment|lab|laboratory|medical|research|sample|science|test tube|testing|vial"},
{0xf03d, false, "video|camcorder|camera|clip|film|footage|media|movie|playback|record|recording|streaming|video|video-camera"},
{0xf4e2, false, "video slash|block|camera off|disabled|disconnect|film|hide|mute|no video|off|record|stop|video"},
{0xf6a7, false, "vihara|buddhism|buddhist|meditation|monastery|religious building|sanctuary|shrine|spiritual center|temple"},
{0xe850, false, "virgo|astrology|august|constellation|earth sign|horoscope|maiden|september|sign|stars|virgin|virgo|zodiac"},
{0xe074, false, "virus|bug|contagion|coronavirus|covid-19|disease|flu|illness|infection|outbreak|pandemic|pathogen|sick|vaccine|viral|virus"},
{0xe4a8, false, "virus covid|contagion|coronavirus|covid|covid-19|disease|epidemic|health|infection|outbreak|pandemic|vaccine|viral|virus"},
{0xe4a9, false, "virus covid slash|blocked|bug|covid-19|disabled|disease|health|infection|no virus|pandemic|quarantine|stop virus|viral|virus"},
{0xe075, false, "virus slash|antivirus|blocked|bug|coronavirus|covid-19|cure|disabled|eliminate|flu|health|infection|no virus|pandemic|protection|sick|vaccine|viral|virus"},
{0xe076, false, "viruses|bugs|contagious|coronavirus|covid-19|disease|flu|illness|infection|pandemic|pathogen|sick|spread|vaccine|viral|virus|viruses"},
{0xf897, false, "voicemail|answering machine|audio message|inbox|message|missed call|phone|phone message|recorded message|voice message|voicemail"},
{0xf770, false, "volcano|caldera|crater|eruption|eruption cloud|geology|lava|magma|mountain|natural disaster|smoke|volcanic activity|volcanic ash|volcanic mountain|volcano"},
{0xf45f, false, "volleyball|ball|beach|court|game|indoor|net|olympics|outdoor|serve|spike|sport|team sport|volleyball"},
{0xf6a8, false, "volume|audio|audio level|media|music|sound|sound control|speaker|speaker medium|volume|volume control"},
{0xf028, false, "volume high|audio|audio on|high volume|increase volume|loud|louder|max volume|music|sound|sound up|speaker|speaker on|volume"},
{0xf027, false, "volume low|audio|audio control|decrease|low volume|mute|quiet|quieter|reduce|soft|sound|sound level|speaker|volume"},
{0xf026, false, "volume off|audio off|disable sound|music off|mute|no sound|quiet|silent|sound off|speaker off|volume mute"},
{0xf6a9, false, "volume xmark|audio|audio off|disable sound|mute|mute speaker|no sound|off|silent|sound|speaker|volume"},
{0xf729, false, "vr cardboard|3d|augmented reality|cardboard|goggles|google|headset|immersive|virtual reality|vr|vr headset"},
{0x57, false, "w|alphabet|capital w|character|letter w|lowercase w|symbol|text|typography"},
{0xf8ef, false, "walkie talkie|communication|emergency radio|field radio|handheld radio|intercom|portable|radio|receiver|talkie|transmitter|two-way radio|walkie-talkie|wireless"},
{0xf555, false, "wallet|billfold|bills|budget|cash|coins|currency|finance|funds|money|payment|pocketbook|purse|salary|spending|wallet"},
{0xf0d0, false, "wand magic|casting|charm|enchantment|fantasy|mage|magic|mystical|sorcery|spell|supernatural|wand|witch|wizard"},
{0xe2ca, false, "wand magic sparkles|enchantment|fantasy|magic|magic wand|sorcery|sparkle|spell|trick|wand|witch|wizard"},
{0xf72b, false, "wand sparkles|charm|enchantment|fantasy|halloween|holiday|magic|mystical|sorcery|sparkles|spell|supernatural|wand|witch|wizard"},
{0xf494, false, "warehouse|building|depot|distribution|facility|inventory|logistics|stockroom|storage|supply|warehouse"},
{0xf773, false, "water|aqua|drop|fluid|hydration|lake|liquid|ocean|refreshment|river|sea|stream|swim|water|wave|wet"},
{0xf5c5, false, "water ladder|aquatic|boat|climb|dock|ladder|marine|pool|recreation|safety|swimming|water"},
{0xf83e, false, "wave square|audio|data|equalizer|frequency|graph|monitor|music|oscillation|pulse|signal|sound|vibration|wave|waveform"},
{0xe682, false, "web awesome|award|awesome|badge|coding|components|crown|developer|frontend|programming|web"},
{0xf5cd, false, "weight hanging|anvil|balance|exercise|gym|hanging|heavy|load|measurement|scale|strength|weight|weightlifting"},
{0xf496, false, "weight scale|balance|bathroom|body|fitness|health|mass|measurement|monitor|scale|tracking|weigh|weight"},
{0xe2cd, false, "wheat awn|agriculture|autumn|cereal|crop|fall|farming|grain|harvest|wheat"},
{0xe598, false, "wheat awn circle exclamation|agriculture|alert|allergy|crop|famine|food|gluten|grain|hunger|starvation|straw|warning|wheat"},
{0xf193, false, "wheelchair|accessibility|accessible|disabled|handicap|mobility|people|users|wheelchair"},
{0xe2ce, false, "wheelchair move|access|accessibility|disabled|handicap|impairment|mobility|move|physical disability|transport|wheelchair|wheelchair symbol"},
{0xf7a0, false, "whiskey glass|alcohol|bar|beverage|bourbon|drink|glass|liquor|neat|rye|scotch|spirit|tumbler|tumbler glass|whiskey|whisky"},
{0xf1eb, false, "wifi|access point|connection|connectivity|hotspot|internet|network|online|router|signal|wifi|wifi network|wifi signal|wireless|wireless internet|wireless signal"},
{0xf72e, false, "wind|air|airflow|blow|breeze|cyclone|draft|gust|seasonal|tornado|ventilation|weather|windstorm|windy"},
{0xf2d0, false, "window maximize|UI|browser|computer|enlarge|expand|fullscreen|interface|maximize|screen|window"},
{0xf2d1, false, "window minimize|UI|collapse|desktop|hide|interface|minimize|reduce|screen|shrink|window"},
{0xf2d2, false, "window restore|application|browser|computer|desktop|interface|maximize|resize|restore|screen|window"},
{0xf72f, false, "wine bottle|alcohol|beverage|bottle|cabernet|cork|drink|grapes|merlot|red wine|sauvignon|vineyard|vintage|white wine|wine|winery"},
{0xf4e3, false, "wine glass|alcohol|bar|beverage|cabernet|celebration|cocktail|drink|glass|grapes|merlot|red wine|sauvignon|toast|white wine|wine|wine glass"},
{0xf5ce, false, "wine glass empty|alcohol|bar|beverage|cheers|cocktail|drink|empty|glass|grapes|red wine|toast|white wine|wine"},
{0xf159, false, "won sign|KRW|Korean currency|South Korea|currency|currency symbol|financial|money|symbol|won|won sign"},
{0xe599, false, "worm|bug|compost|crawl|dirt|earthworm|garden|insect|nature|pest|slimy|soil|worm|wriggle"},
{0xf0ad, false, "wrench|adjust|configuration|construction|equipment|fix|maintenance|mechanic|modify|plumbing|repair|settings|spanner|tool|update|wrench"},
{0x58, false, "x|cancel|clear|close|cross|delete|dismiss|exit|letter x|multiply|remove|uncheck|x"},
{0xf497, false, "x ray|bone scan|bones|clinic|diagnostic|fracture|health|hospital|imaging|medical|radiology|scan|skeleton|transparent|x-ray|xray"},
{0xf00d, false, "xmark|cancel|cancel sign|close|cross|cross mark|delete|deny|dismissal|error|exit|incorrect|multiplication|multiply|no|problem|reject|remove|stop|wrong|x"},
{0xe59a, false, "xmarks lines|barricade|barrier|block|caution|closed|danger|fence|no entry|restricted|roadblock|stop|warning"},
{0x59, false, "y|alphabet|capital y|character|letter y|lowercase y|symbol|text|typography|yay|yes"},
{0xf157, false, "yen sign|Japanese currency|Japanese yen|currency|finance|money|payment|price|symbol|yen|yen sign"},
{0xf6ad, false, "yin yang|balance|daoism|duality|eastern religion|harmony|opposites|philosophy|spirituality|symbol|tao|taoism|taoist|yang|yin|yin yang"},
{0x5a, false, "z|alphabet z|character z|latin letter|letter z|lowercase z|symbol z|uppercase z"},
{0xe080, true, "42 group|42|42 group|coding bootcamp|coding school|programming academy|programming school|school 42|software development|software engineering school|tech education"},
{0xf26e, true, "500px|500 px|500px|image sharing|photo community|photo network|photo sharing|photographers|photography|photos|portfolio"},
{0xf368, true, "accessible icon|access|accessibility|accessibility symbol|accessible icon project|disability|disabled|handicap|inclusive|mobility|person|user|wheelchair|wheelchair user"},
{0xf369, true, "accusoft|Accusoft|Accusoft software|SDK|developer tools|document imaging|document processing|imaging software|software development kit"},
{0xf170, true, "adn|ADN|app dot net|app.net|microblogging|networking|online community|social media|social network"},
{0xf36a, true, "adversal|Adversal|ad network|ad platform|ad service|advertising|digital ads|marketing network|online advertising"},
{0xf36b, true, "affiliatetheme|Affiliatetheme|affiliate|affiliate marketing|affiliate network|affiliate program|marketing|theme|wordpress|wordpress theme"},
{0xf834, true, "airbnb|Airbnb|accommodation|air bnb|holiday rental|homestay|hospitality|lodging|rental|short term rental|travel|vacation|vacation home|vacation rental"},
{0xf36c, true, "algolia|Algolia|hosted search|instant search|search|search API|search engine|search platform|search provider|search service|search tool|search-as-a-service|site search"},
{0xf642, true, "alipay|Alipay|QR code|ali pay|cashless|china|digital wallet|e-wallet|fintech|mobile pay|mobile wallet|online payment|payments"},
{0xf270, true, "amazon|Amazon|amazon.com|delivery|ecommerce|marketplace|online shopping|online store|prime|retail|shipping|shopping|webstore"},
{0xf42c, true, "amazon pay|Amazon|Amazon Pay|buy|checkout|digital wallet|e-commerce|online payment|pay|payment|wallet"},
{0xf36d, true, "amilia|Amilia|amilia|ecommerce|event registration|membership management|memberships|online registration|payment processing|registration|registration software"},
{0xf17b, true, "android|android|android logo|google|google android|green robot|mobile|operating system|os|phone|robot|smartphone"},
{0xf209, true, "angellist|AngelList|angel investing|funding|investing|investors|job board|startup funding|startup jobs|startups|venture capital"},
{0xf36e, true, "angrycreative|Angry Creative|WordPress|agency|branding|creative agency|design studio|digital agency|marketing|web design"},
{0xf420, true, "angular|Angular|AngularJS|Google|JavaScript|SPA|TypeScript|framework|frontend|single-page application|web app"},
{0xf36f, true, "app store|App Store|Apple App Store|Mac apps|app marketplace|app store icon|download|iOS apps|iPad apps|iPhone apps|mobile apps"},
{0xf370, true, "app store ios|App Store|Apple|iOS App Store|iOS apps|iOS download|iOS marketplace|iPad apps|iPhone apps|mobile apps"},
{0xf371, true, "apper|Apper|app|app development|application|enterprise apps|mobile app|software"},
{0xf179, true, "apple|apple|apple computer|apple logo|electronics|fruit|ios|ipad|iphone|mac|macos|operating system|os|osx|technology"},
{0xf415, true, "apple pay|Apple Pay|Apple Wallet|NFC payment|checkout|contactless payment|digital wallet|mobile payment|pay with phone|tap to pay"},
{0xe867, true, "arch linux"},
{0xf77a, true, "artstation|art|artist|artstation|artwork|community|creative|design|digital art|gallery|portfolio"},
{0xf372, true, "asymmetrik|asymmetrik|asymmetrik brand|asymmetrik company|asymmetrik logo|asymmetrik software|asymmetrik technology"},
{0xf77b, true, "atlassian|Atlassian|Bitbucket|Confluence|DevOps|Jira|Trello|agile|collaboration|project management|software"},
{0xf373, true, "audible|amazon audible|audible|audio platform|audiobook|audiobook app|audiobook service|audiobooks|listening|spoken word"},
{0xf41c, true, "autoprefixer|automation|autoprefixer|build tool|css|frontend|prefix|stylesheet|web development"},
{0xf374, true, "avianex|aircraft|airline|avian ex|avianex|aviation|flight|travel"},
{0xf421, true, "aviato|aviato|brand|software|startup|tech company|technology"},
{0xf375, true, "aws|amazon|amazon web services|aws cloud|aws logo|aws platform|cloud|cloud computing|web services"},
{0xf2d5, true, "bandcamp|album|artist|audio|bandcamp|indie|marketplace|music|platform|songs|streaming"},
{0xf835, true, "battle net|battle net|battle.net|blizzard|blizzard entertainment|esports|game launcher|gaming|multiplayer|online games|pc games"},
{0xf1b4, true, "behance|adobe behance|art|behance|creative|creative community|design|portfolio|projects|showcase"},
{0xe3d9, true, "bilibili|Bilibili|B站|Chinese video platform|anime|bilibili|comics|gaming|live streaming|streaming|video"},
{0xf378, true, "bimobject|3d models|architecture|bim|bim library|bimobject|building information modeling|cad|construction|design"},
{0xf171, true, "bitbucket|atlassian|bitbucket|code|devops|git|repository|software development|source code|version control"},
{0xf379, true, "bitcoin|bitcoin|bitcoin logo|bitcoin symbol|blockchain|btc|crypto|cryptocurrency|decentralized currency|digital currency|virtual currency"},
{0xf37a, true, "bity|bitcoin|bity|blockchain|crypto exchange|cryptocurrency|digital currency"},
{0xf27e, true, "black tie|administrator|black tie|bow tie|dress code|evening wear|event|formal|formalwear|gala|suit|tuxedo"},
{0xf37b, true, "blackberry|RIM|blackberry|blackberry brand|blackberry device|blackberry logo|blackberry phone|mobile|smartphone"},
{0xf37c, true, "blogger|blog|blogger|blogging|blogspot|content creator|google blog|publishing|writing"},
{0xf37d, true, "blogger b|blog|blog platform|blogger|blogging|blogspot|content creation|google blogger|publishing|writing"},
{0xe671, true, "bluesky|app|bluesky|decentralized|platform|social media|social network"},
{0xf293, true, "bluetooth|bluetooth|connection|device|pairing|signal|technology|wireless"},
{0xf294, true, "bluetooth b|bluetooth|bluetooth device|bluetooth icon|bluetooth logo|bluetooth symbol|connectivity|wireless|wireless technology"},
{0xe855, true, "board game geek"},
{0xf836, true, "bootstrap|UI framework|bootstrap|components|css framework|front-end|grid system|open source|responsive|twbs|web development"},
{0xe340, true, "bots|ai|ai assistant|artificial intelligence|automated|automation|bots|chatbot|messaging|robot|virtual assistant"},
{0xe63c, true, "brave|ad blocker|brave|brave browser|chromium|fast browser|internet|privacy|secure browser|web browser"},
{0xe63d, true, "brave reverse|ad blocker|blockchain|brave|brave browser|cryptocurrency|fast browser|internet|privacy|security|web browser"},
{0xf15a, true, "btc|bitcoin|blockchain|btc|btc coin|btc token|coin|crypto|cryptocurrency|digital currency|token"},
{0xf837, true, "buffer|buffer|content management|marketing|posts|scheduling|social media|social media management|social media platform|social media tool|social network"},
{0xf37f, true, "buromobelexperte|German brand|buromobel|buromobel experte|experte|furniture brand|office furniture"},
{0xf8a6, true, "buy n large|bnL|buy n large|buy-n-large|corporation|fictional brand|large retailer|mega company|parody|sci-fi"},
{0xf20d, true, "buysellads|ad network|ad platform|advertising|buy sell ads|buysellads|digital ads|marketing|media buying"},
{0xf785, true, "canadian maple leaf|canada|canadian|emblem|leaf|maple|nature|plant|symbol"},
{0xe7d4, true, "cash app|cash app|cashapp|digital wallet|finance|mobile payment|money transfer|payment|peer-to-peer|receive money|send money|venmo alternative"},
{0xf42d, true, "cc amazon pay|amazon|amazon pay|buy|checkout|digital wallet|ecommerce|online shopping|pay|payment|purchase"},
{0xf1f3, true, "cc amex|american express|amex|banking|card|credit card|finance|payment"},
{0xf416, true, "cc apple pay|apple|apple pay|applepay|contactless|digital wallet|mobile payment|pay|payment|tap to pay|wallet"},
{0xf24c, true, "cc diners club|banking|card|club card|credit card|diners club|dinersclub|finance|payment"},
{0xf1f2, true, "cc discover|banking|card network|cc|credit|credit card|debit|discover|financial|payment"},
{0xf24b, true, "cc jcb|banking|card|credit card|debit|financial|jcb|mastercard alternative|payment|transaction"},
{0xf1f1, true, "cc mastercard|card|credit card|mastercard|mastercard brand|mastercard card|mastercard logo|mastercard payment|payment"},
{0xf1f4, true, "cc paypal|cc|credit card|digital wallet|ecommerce|money transfer|online payment|payment|paypal|paypal card|paypal credit"},
{0xf1f5, true, "cc stripe|billing|card|cc|credit card|ecommerce|fintech|online payment|payment|stripe|subscription"},
{0xf1f0, true, "cc visa|banking|card|credit card|debit|financial|mastercard alternative|payment|visa|visa card|visa logo"},
{0xf380, true, "centercode|QA|beta testing|center code|centercode|feedback platform|quality assurance|software testing|testing|user testing"},
{0xf789, true, "centos|centos|enterprise linux|linux|linux distribution|operating system|os|server"},
{0xf268, true, "chrome|browser|chrome|google|google chrome|internet|search engine|web browser"},
{0xf838, true, "chromecast|cast|chromecast|dongle|google chromecast|google device|media player|screen mirroring|streaming|television|tv|wireless display"},
{0xe851, true, "circle zulip"},
{0xe861, true, "claude"},
{0xe07d, true, "cloudflare|cdn|cf|cloud services|cloudflare|content delivery network|ddos protection|dns|firewall|internet security|web performance"},
{0xf383, true, "cloudscale|cloud computing|cloud hosting|cloud infrastructure|cloud provider|cloud services|cloudscale|cloudscale.ch|data center|hosting|server"},
{0xf384, true, "cloudsmith|artifact storage|cloud packages|cloudsmith|cloudsmith.io|continuous integration|devops|package management|software repository"},
{0xf385, true, "cloudversify|cloud platform|cloud services|cloudversify|cloudversify brand|cloudversify company|cloudversify logo"},
{0xe360, true, "cmplid|cmplid|compliance|compliance management|compliance software|governance|regulatory|risk management"},
{0xf1cb, true, "codepen|code editor|codepen|codepen.io|coding|front-end|online editor|playground|programming|sandbox|web development"},
{0xf284, true, "codiepie|codie pie|codiepie|content creator|gaming|influencer|streamer|youtube"},
{0xf78d, true, "confluence|atlassian|collaboration|confluence|documentation|knowledge base|project management|teamwork|wiki"},
{0xf20e, true, "connectdevelop|coding|connect develop|connectdevelop|connectdevelop brand|developer community|developer network|programming|software development"},
{0xf26d, true, "contao|cms|contao|content management|open source|web development|website"},
{0xf89e, true, "cotton bureau|apparel|brand|clothing|clothing brand|cotton bureau|fashion|t-shirts|tshirts"},
{0xf388, true, "cpanel|control panel|cpanel|hosting|hosting dashboard|server management|site management|web admin|web hosting|website control"},
{0xf25e, true, "creative commons|attribution|cc|copyright|creative commons|free use|license|open content|public domain|share alike"},
{0xf4e7, true, "creative commons by|attribution|cc|copyright|creative commons|license|open content|permission|share"},
{0xf4e8, true, "creative commons nc|cc|copyright|creative commons|intellectual property|license|nc|no commercial use|non commercial"},
{0xf4e9, true, "creative commons nc eu|attribution|cc|copyright|creative commons|eu|europe|license|nc|noncommercial|open content"},
{0xf4ea, true, "creative commons nc jp|cc|cc license|copyright|creative commons|japan|jp|license|nc|non commercial|open license"},
{0xf4eb, true, "creative commons nd|cc|content sharing|copyright|copyright license|creative commons|license|nd|no derivatives|reuse restriction"},
{0xf4ec, true, "creative commons pd|cc|copyright free|creative commons|free use|no copyright|open license|pd|public domain"},
{0xf4ed, true, "creative commons pd alt|cc|copyright free|creative commons|free use|no copyright|open license|pd|public domain"},
{0xf4ee, true, "creative commons remix|attribution|cc|collaboration|creative commons|free use|license|open content|remix|sharing"},
{0xf4ef, true, "creative commons sa|attribution|cc|cc-sa|commons license|copyright|creative commons|license|open license|share alike"},
{0xf4f0, true, "creative commons sampling|audio|cc|copyright|creative commons|license|music|remix|reuse|sampling"},
{0xf4f1, true, "creative commons sampling plus|attribution|cc|copyright|creative commons|free use|license|open content|sampling plus"},
{0xf4f2, true, "creative commons share|attribution|cc|copyright|creative commons|creative commons license|free use|license|open content|public domain|share"},
{0xf4f3, true, "creative commons zero|cc0|copyright free|creative commons zero|free use|no rights reserved|open license|public domain|zero copyright"},
{0xf6c9, true, "critical role|Critical Role|Dungeons & Dragons|RPG|campaign|d&d|dnd|fantasy|role-playing|streaming|tabletop|voice actors|web series"},
{0xe6a2, true, "css|cascading style sheets|css|rebecca purple|stylesheet|web design|web development"},
{0xf13c, true, "css3|code|css|css3|frontend|programming|stylesheet|web|web development"},
{0xf38b, true, "css3 alt|cascade|css|css3|frontend|frontend development|style|stylesheet|web|web design|web development"},
{0xf38c, true, "cuttlefish|animal|cephalopod|cuttlefish|marine|mollusk|ocean|sea creature|seafood"},
{0xf38d, true, "d and d|dnd|dragons|dungeons|dungeons & dragons|dungeons and dragons|game|gaming|role-playing|roleplay|rpg|tabletop"},
{0xf6ca, true, "d and d beyond|Dungeons & Dragons|campaign|d&d|dice|dnd|dungeons and dragons|fantasy|gaming|role-playing|rpg|tabletop"},
{0xe052, true, "dailymotion|dailymotion|media|online video|platform|streaming|video|video sharing|videos"},
{0xe693, true, "dart lang|dart|dartlang|development|flutter|google|language|programming|sdk"},
{0xf210, true, "dashcube|analytics|dash cube|dashboard|dashcube|data|metrics|reporting"},
{0xe60b, true, "debian|debian|debian linux|distribution|distro|linux|open source|operating system|os|penguin|software"},
{0xe077, true, "deezer|audio|deezer|music|playlist|podcast|radio|songs|streaming"},
{0xf1a5, true, "delicious|bookmarks|del.icio.us|delicious|favorites|link sharing|save|share|social bookmarking"},
{0xf38e, true, "deploydog|CI|DevOps|automation|cloud deployment|continuous integration|deploy dog|deploydog|deployment|software deployment"},
{0xf38f, true, "deskpro|Deskpro|IT support|customer service|customer support|help desk|helpdesk|service desk|software|support|ticketing"},
{0xf6cc, true, "dev|code|coding|dev|developer|development|engineer|programming|software|tech|technology"},
{0xf1bd, true, "deviantart|art community|artist|artwork|creative|da|design|deviantart|digital art|illustration|portfolio"},
{0xf790, true, "dhl|DHL|Dalsey|Hillblom|Lynn|courier|delivery|express|freight|german|logistics|package|shipping"},
{0xf791, true, "diaspora|community|decentralized|diaspora|open source|platform|social media|social network"},
{0xf1a6, true, "digg|bookmarking|content sharing|digg|news aggregator|social media|social news"},
{0xf391, true, "digital ocean|cloud|cloud computing|devops|digital ocean|do|droplets|hosting|infrastructure|platform|server"},
{0xf392, true, "discord|app|chat|communication|community|discord|gaming|messaging|server|social|voice"},
{0xf393, true, "discourse|chat|community|conversation|discourse|discussion|discussion board|forum|messaging|online forum|social platform"},
{0xe7d5, true, "disqus|chat|comments|community|discussion|disqus|forum|messaging|social"},
{0xf394, true, "dochub|digital signature|dochub|document hub|document management|document signing|e-signature|pdf editor|pdf signing|pdf tools"},
{0xf395, true, "docker|cloud|container|containers|deployment|devops|docker|image|platform|software|virtualization"},
{0xf396, true, "draft2digital|author platform|book distribution|d2d|digital publishing|draft2digital|ebook|publishing|self-publishing"},
{0xf17d, true, "dribbble|art|community|creative|design|designer|dribbble|dribble|inspiration|portfolio|showcase|social"},
{0xf16b, true, "dropbox|backup|cloud drive|cloud storage|collaboration|dropbox|file hosting|file sharing|file sync|online storage"},
{0xf1a9, true, "drupal|cms|content management system|drupal|drupal cms|open source|php|web development|website"},
{0xe812, true, "duolingo|app|courses|duolingo|education|foreign language|language|language learning|learning|owl|study"},
{0xf399, true, "dyalog|apl language|dyalog|dyalog brand|dyalog logo|dyalog software|programming language|software company"},
{0xf39a, true, "earlybirds|Early Birds|calendar|earlybirds|earlybirds app|productivity|scheduling|task planning|team collaboration|time management"},
{0xf4f4, true, "ebay|auction|buy|classifieds|ebay|ecommerce|marketplace|online store|retail|sell|shopping"},
{0xf282, true, "edge|browser|edge|ie|internet|microsoft|microsoft edge|web"},
{0xe078, true, "edge legacy|browser|edge|internet|legacy|microsoft|microsoft edge|old edge|web browser"},
{0xf430, true, "elementor|cms|drag and drop|elementor|frontend editor|page builder|plugin|theme builder|web design|website builder|wordpress"},
{0xe7d6, true, "eleventy|11ty|SSG|eleventy|static site generator|web development"},
{0xf5f1, true, "ello|art|community|creative|ello|network|platform|social|social media"},
{0xf423, true, "ember|ember|emberjs|framework|frontend|javascript|js|ui|web"},
{0xf1d1, true, "empire|empire|film|franchise|galactic empire|lucasfilm|movie|sci-fi|star wars|starwars"},
{0xf299, true, "envira|envira|envira gallery|gallery|image|leaf|photo|wordpress"},
{0xf39d, true, "erlang|concurrency|development|erlang|functional|language|programming|software|telecom"},
{0xf42e, true, "ethereum|blockchain|crypto|cryptocurrency|defi|digital currency|eth|ether|ethereum|smart contract|token"},
{0xf2d7, true, "etsy|artisan|crafts|creative goods|ecommerce|etsy|etsy shop|handmade|marketplace|online store|vintage"},
{0xf839, true, "evernote|cloud notes|digital notebook|evernote|memo|note|notebook|notes|organization|productivity|reminder"},
{0xf23e, true, "expeditedssl|certificate authority|encryption|expeditedssl|https|security|ssl|ssl certificate|ssl provider|web security"},
{0xf09a, true, "facebook|facebook|facebook-official|fb|meta|social media|social network|social platform"},
{0xf39e, true, "facebook f|facebook|facebook logo|fb|meta|social|social media|social network"},
{0xf39f, true, "facebook messenger|chat|facebook|fb|instant messaging|message|messenger|messenger app|social"},
{0xf6dc, true, "fantasy flight games|Dungeons & Dragons|FFG|Fantasy Flight Games|RPG|board games|card games|d&d|dnd|fantasy|role-playing games|strategy games|tabletop games"},
{0xf797, true, "fedex|FedEx|Federal Express|courier|delivery|express|freight|logistics|package|shipping"},
{0xe865, true, "fediverse"},
{0xf798, true, "fedora|distribution|distro|fedora|linux|open source|operating system|os|red hat|rpm"},
{0xf799, true, "figma|app|collaboration|design|figma|interface|prototyping|ui|ux|vector|webdesign"},
{0xe69f, true, "files pinwheel|archive|data|document|file manager|file organization|files|folder|pinwheel|rotate|storage|sync"},
{0xf269, true, "firefox|browser|browser icon|firefox|firefox browser|internet|mozilla|web"},
{0xe007, true, "firefox browser|browser|browser icon|firefox|internet|mozilla|web|web browser"},
{0xf2b0, true, "first order|1st order|first order|hierarchy|primary|priority|ranking|top level"},
{0xf50a, true, "first order alt|alt|alternative|brand|first order|first-order|logo"},
{0xf3a1, true, "firstdraft|content creation|document|draft|first draft|firstdraft|publishing|writing"},
{0xf16e, true, "flickr|flickr|images|photo community|photo hosting|photo sharing|photography|photos|social media"},
{0xf44d, true, "flipboard|Flipboard|articles|content|magazine|news|news aggregator|news app|reading|social media"},
{0xe694, true, "flutter|flutter|flutter SDK|flutter UI|flutter app|flutter brand|flutter development|flutter framework|flutter logo|flutter mobile|flutter web"},
{0xf417, true, "fly|cloud computing|cloud platform|deployment|devops|fly|fly.io|hosting|serverless"},
{0xf2b4, true, "font awesome|branding|fa|font-awesome|icon set|logo|typeface"},
{0xf280, true, "fonticons|font icons|fonticons|glyphs|icon font|icon set|symbols|typography|vector icons"},
{0xf3a2, true, "fonticons fi|branding|fi|font icon|fonticons|icon|logo"},
{0xe860, true, "forgejo"},
{0xf286, true, "fort awesome|castle|defense|fort|fortress|fortress icon|medieval|stronghold"},
{0xf3a3, true, "fort awesome alt|castle|defense|fort|fortress|fortress wall|medieval|military|stronghold"},
{0xf211, true, "forumbee|collaboration tool|discussion platform|forum bee|forumbee|online community|social network"},
{0xf180, true, "foursquare|check-in|checkin|foursquare|fsq|local|location|maps|places|social|venue"},
{0xf2c5, true, "free code camp|bootcamp|code|coding|developer|education|fcc|freecodecamp|learning|online course|programming"},
{0xf3a4, true, "freebsd|bsd|free bsd|freebsd|network|open source|operating system|os|server|unix"},
{0xf50b, true, "fulcrum|analytics tool|business intelligence|data platform|data visualization|fulcrum|fulcrum analytics"},
{0xf50c, true, "galactic republic|clone wars|galactic republic|galaxy|jedi|republic|sci-fi|science fiction|space|star wars|starwars"},
{0xf50d, true, "galactic senate|galactic senate|star wars|star wars emblem|star wars franchise|star wars galaxy|star wars icon|star wars logo|star wars symbol|starwars"},
{0xf265, true, "get pocket|article|bookmarking|getpocket|pocket|pocket app|read later|reading list|save|save article|save for later"},
{0xf260, true, "gg|esports|game over|gamer|gaming|gg|good game|victory|win"},
{0xf261, true, "gg circle|gg|gg brand|gg circle|gg icon|gg logo|gg symbol"},
{0xf1d3, true, "git|branch|code|commit|developer|git|merge|open source|programming|repository|software|source control|version control"},
{0xf841, true, "git alt|branch|code|commit|dev|developer|git|repository|software|source control|version control"},
{0xe863, true, "gitee"},
{0xf09b, true, "github|code|collaboration|development|git|github|octocat|programming|repository|software|version control"},
{0xf113, true, "github alt|code|developer|git|github|octocat|programming|repository|software|version control"},
{0xf3a6, true, "gitkraken|code management|developer tool|git|git client|gitkraken|repository|software development|source control|version control"},
{0xf296, true, "gitlab|CI/CD|DevOps|GitLab|code hosting|continuous deployment|continuous integration|gitlab|repository|software development|version control"},
{0xf426, true, "gitter|chat|chat platform|collaboration|communication|community|developer chat|gitter|messaging|team chat"},
{0xf2a5, true, "glide|app builder|app development|glide|glideapps|mobile app|no code|no-code|platform|software"},
{0xf2a6, true, "glide g|app builder|app maker|glide|glideapps|mobile app|no-code|platform|software|web app"},
{0xe85d, true, "globaleaks"},
{0xf3a7, true, "gofore|consulting|digital services|finnish company|gofore|gofore oy|software development"},
{0xe40f, true, "golang|backend|code|developer|go|golang|gopher|language|programming|software"},
{0xf3a8, true, "goodreads|book community|book recommendations|book reviews|books|goodreads|literature|reading|reading tracker|social reading"},
{0xf3a9, true, "goodreads g|book community|book reviews|books|g|goodreads|literature|reading|social reading"},
{0xf1a0, true, "google|google|google brand|google company|google icon|google logo|google products|google services|search engine"},
{0xf3aa, true, "google drive|cloud|documents|drive|files|gdrive|google|google drive|storage"},
{0xe079, true, "google pay|contactless pay|digital wallet|google pay|google wallet|gpay|mobile payment|nfc payment|online payment|payment|tap to pay"},
{0xf3ab, true, "google play|android store|app store|google apps|google play|google play store|playstore"},
{0xf2b3, true, "google plus|google plus|google+|google-plus|google-plus-circle|google-plus-official|gplus"},
{0xf0d5, true, "google plus g|google|google social|google-plus|gplus|social media|social network"},
{0xe63b, true, "google scholar|academic|citations|google|google scholar|papers|research|scholar"},
{0xf1ee, true, "google wallet|card|contactless|digital wallet|ecommerce|finance|google pay|google wallet|mobile payment|money|online payment|payment|payments|tap to pay|transaction|wallet"},
{0xf184, true, "gratipay|charity|contribution|crowdfunding|donation|funding|gratipay|support|tip"},
{0xf2d6, true, "grav|account|avatar|grav|gravatar|identity|picture|profile|user"},
{0xf3ac, true, "gripfire|brand|esports|gaming|grip fire|gripfire|logo|streaming|video games"},
{0xf3ad, true, "grunt|automation|build tool|grunt|gruntjs|javascript|nodejs|task runner"},
{0xe07e, true, "guilded|chat|communication|community|esports|gaming|guilded|platform|social|teams|voice"},
{0xf3ae, true, "gulp|automation|build|gulp|gulpjs|javascript|nodejs|streaming|task runner"},
{0xf1d4, true, "hacker news|developer news|hacker news|hn|news aggregator|programming|social news|startup news|tech news|technology"},
{0xf5f7, true, "hackerrank|challenges|code practice|coding|competitive programming|developer|hacker rank|hackerrank|interview|programming|tech"},
{0xe499, true, "hashnode|articles|blogging|content platform|developer blog|developer community|developer platform|hashnode|programming|tech blog|writing"},
{0xf452, true, "hips|anatomy|body|fitness|health|hips|wellness"},
{0xf3b0, true, "hire a helper|cleaning company|cleaning service|domestic help|hire a helper|home cleaning|home help|housekeeper|maid service|professional cleaner"},
{0xe07f, true, "hive|blockchain|crypto|cryptocurrency|decentralized|hive|hive blockchain|hive social|social media|web3"},
{0xf427, true, "hooli|Hooli|Silicon Valley|brand|software|tech company|technology"},
{0xf592, true, "hornbill|animal|beak|bird|exotic bird|hornbill|nature|tropical bird|wildlife"},
{0xf3b1, true, "hotjar|UX|analytics|conversion rate|feedback|heatmap|hotjar|session recording|user behavior|user experience|website tracking"},
{0xf27c, true, "houzz|architecture|decor|home design|home improvement|housing|houzz|interior design|real estate|remodeling|renovation"},
{0xf13b, true, "html5|coding|frontend|html|html5|internet|markup|programming|web|web design|web development"},
{0xf3b2, true, "hubspot|business growth|crm|customer relationship management|email marketing|hubspot|inbound marketing|lead generation|marketing automation|marketing platform|sales software"},
{0xe869, true, "hugging face"},
{0xe013, true, "ideal|banking|digital wallet|ecommerce|finance|ideal|ideal logo|money transfer|online payment|payment"},
{0xf2d8, true, "imdb|entertainment|films|imdb|internet movie database|movies|ratings|reviews|tv"},
{0xf16d, true, "instagram|IG|Instagram|app|feed|filter|influencer|photo sharing|reels|social media|social network|stories"},
{0xe081, true, "instalod|app|download|file transfer|installation|instaload|instalod|software"},
{0xf7af, true, "intercom|chat|communication|customer service|customer support|helpdesk|intercom|live chat|messaging"},
{0xf26b, true, "internet explorer|browser|explorer|ie|internet explorer|legacy browser|microsoft|web"},
{0xf7b0, true, "invision|app|collaboration|design|interface|invision|prototyping|ui|ux"},
{0xf208, true, "ioxhost|cloud hosting|hosting|internet service|ioxhost|server|web hosting|web services"},
{0xf83a, true, "itch io|digital games|game marketplace|game store|gaming platform|indie developer|indie games|itch.io"},
{0xf3b4, true, "itunes|apple|apple music|audio player|digital music|itunes|media player|music app|music download|music library|music store"},
{0xf3b5, true, "itunes note|apple music|audio|itunes|melody|music|note|song|sound"},
{0xf4e4, true, "java|coding|coffee|java|java language|java platform|java programming|jvm|programming|software development"},
{0xf50e, true, "jedi order|jedi|jedi emblem|jedi order|jedi symbol|star wars|star wars emblem|star wars logo|star wars symbol|starwars"},
{0xf3b6, true, "jenkins|automation|automation server|build server|ci|continuous integration|devops|jenkins|open source|pipeline|software development"},
{0xf7b1, true, "jira|agile|atlassian|bug tracking|issue tracker|jira|kanban|project management|scrum|software development|task management"},
{0xf3b7, true, "joget|app builder|business process management|joget|joget workflow|low code|no code|workflow automation"},
{0xf1aa, true, "joomla|cms|content management system|joomla|joomla cms|joomla logo|open source|php|web platform|website"},
{0xf3b8, true, "js|coding|developer|javascript|js|language|programming|script|web|web development"},
{0xf1cc, true, "jsfiddle|code editor|code snippet|coding sandbox|frontend playground|javascript playground|js|js fiddle|jsfiddle|online editor|programming tool|web development"},
{0xe852, true, "julia"},
{0xe67b, true, "jxl|codec|graphics|image format|jpeg xl|jxl|photo|picture"},
{0xf5fa, true, "kaggle|AI|analytics|competitions|data analysis|data platform|data science|datasets|kaggle|machine learning"},
{0xe7d7, true, "kakao talk|chat|instant messaging|kakao|kakao talk|kakaotalk|korean messenger|messaging|messenger|mobile chat|social app"},
{0xf4f5, true, "keybase|chat|cryptography|encryption|identity|keybase|messaging|security|verification"},
{0xf3ba, true, "keycdn|caching|cdn|cloud|content delivery network|hosting|internet|keycdn|web performance"},
{0xf3bb, true, "kickstarter|backer|campaign|creative|crowdfunding|fundraising|kickstarter|pledge|projects|startup|support"},
{0xf3bc, true, "kickstarter k|creative|crowdfunding|fundraising|kickstarter|ks|projects|startup"},
{0xe856, true, "ko fi"},
{0xf42f, true, "korvue|korvue|korvue app|korvue brand|korvue logo|korvue software"},
{0xe857, true, "kubernetes"},
{0xf3bd, true, "laravel|artisan|backend|developer|eloquent|laravel|mvc|open source|php|php framework|web framework"},
{0xf202, true, "lastfm|artist|audio|band|last.fm|lastfm|music|playlist|radio|scrobble|social music|streaming"},
{0xf212, true, "leanpub|author platform|book platform|digital publishing|ebooks|leanpub|online books|publishing|self-publishing"},
{0xe86a, true, "leetcode"},
{0xf41d, true, "less|coding|css|design|frontend|less|lesscss|preprocessor|style|stylesheet|web development"},
{0xe62d, true, "letterboxd|cinema|film community|films|letterboxd|movie|movies app|ratings|reviews|social network|watchlist"},
{0xf3c0, true, "line|border|divider|line|lines|path|rule|separator|stroke"},
{0xf08c, true, "linkedin|business|career|jobs|linkedin|linkedin-square|professional network|social media"},
{0xf0e1, true, "linkedin in|business networking|linkedin|linkedin icon|linkedin logo|linkin|professional network|social media"},
{0xe7d8, true, "linktree|bio link|link aggregator|link landing page|link tree|links|linktree|profile links|social links"},
{0xf2b8, true, "linode|VPS|cloud computing|cloud hosting|cloud infrastructure|cloud server|hosting provider|linode|linode cloud|virtual server"},
{0xf17c, true, "linux|distro|kernel|linux|open source|operating system|penguin|tux"},
{0xe7e2, true, "lumon|lumon|lumon balcony|lumon brand|lumon company|lumon glass|lumon logo"},
{0xe7e3, true, "lumon drop|brand|company|drop|logo|lumon|lumon drop"},
{0xf3c3, true, "lyft|app|car service|lyft|mobility|ride|rideshare|taxi|transportation|travel"},
{0xf3c4, true, "magento|adobe magento|cms|ecommerce|magento|marketplace|online store|platform|shopping"},
{0xf59e, true, "mailchimp|automation|campaign|chimp|email marketing|email service|mail service|mailchimp|marketing|marketing platform|newsletter"},
{0xf50f, true, "mandalorian|armor|beskar|bounty hunter|din djarin|disney plus|helmet|mandalorian|sci-fi|star wars|tv show|warrior"},
{0xf60f, true, "markdown|developer|documentation|formatting|markdown|markup|md|readme|syntax|text|writing"},
{0xf4f6, true, "mastodon|decentralized|federated|fediverse|mastodon|microblogging|network|open source|platform|social|social media"},
{0xf136, true, "maxcdn|caching|cdn|cloudflare alternative|content delivery network|hosting|internet service|maxcdn|web performance"},
{0xf8ca, true, "mdb|backend|cloud database|data storage|database|database service|document database|mdb|mongo|mongodb|nosql"},
{0xf3c6, true, "medapps|health services|health technology|healthcare apps|medapps|medical apps|medical software"},
{0xf23a, true, "medium|articles|blog|blogging|content|medium|platform|publishing|social media|stories|writing"},
{0xf3c8, true, "medrt|arbitration|conflict management|dispute resolution|legal|mediation|medrt"},
{0xf2e0, true, "meetup|community|event|gathering|group|meetup|meetup.com|network|social"},
{0xf5a3, true, "megaport|cloud|connectivity|data center|interconnection|megaport|network|service provider|telecommunications"},
{0xf7b3, true, "mendeley|academic|bibliography|citation|library|literature|mendeley|papers|reference manager|research|scholarly"},
{0xe49b, true, "meta|meta|meta brand|meta data|meta information|meta tag|metadata"},
{0xe01a, true, "microblog|blogging platform|content sharing|microblog|microblogging|online journal|short posts|social media|social network|status update"},
{0xf3ca, true, "microsoft|azure|microsoft|ms|msft|office|software|technology|windows|windows logo|xbox"},
{0xe62f, true, "mintbit|blockchain|crypto|cryptocurrency|digital currency|mint bit|mintbit|token"},
{0xf3cb, true, "mix|audio|blend|combine|dj|media|mix|mixer|mixing|music|sound"},
{0xf289, true, "mixcloud|DJ mixes|audio platform|mixcloud|music sharing|music streaming|online radio|podcasts|radio shows|streaming service"},
{0xe056, true, "mixer|DJ mixer|audio control|audio mixer|mixer|mixing console|mixing desk|music mixer|sound mixer|soundboard"},
{0xf3cc, true, "mizuni|mizuni|mizuni brand|mizuni company|mizuni logo|mizuni software|mizuni technology"},
{0xf285, true, "modx|cms|content management|content management system|modx|modx cms|open source|web platform|website"},
{0xf3d0, true, "monero|altcoin|blockchain|crypto|cryptocurrency|decentralized|digital currency|monero|privacy coin|xmr"},
{0xf3d2, true, "napster|audio|brand|logo|media|mp3|music|napster|playlist|streaming"},
{0xf612, true, "neos|blockchain|crypto|crypto coin|crypto token|cryptocurrency|digital currency|neos|neos wallet"},
{0xe530, true, "nfc directional|connect|contactless|data transfer|near field communication|nfc|proximity|scan|signal|tap|transfer|wireless|wireless payment"},
{0xe531, true, "nfc symbol|connect|contactless|data|near field communication|nfc|scan|signal|tap|transfer|wireless|wireless payment"},
{0xf5a8, true, "nimblr|nimblr|nimblr app|nimblr brand|nimblr logo|nimblr platform|nimblr social"},
{0xf419, true, "node|JavaScript|Node|Node.js|backend|development|programming|runtime|server"},
{0xf3d3, true, "node js|backend|development|event-driven|javascript|js|node.js|nodejs|npm|programming|runtime|server"},
{0xe7d9, true, "notion|collaboration|knowledge base|note-taking|notes|notion|notion.so|organization|productivity|project management|workspace"},
{0xf3d4, true, "npm|JavaScript|Node Package Manager|Node.js|libraries|modules|node modules|npm|package manager|packages"},
{0xf3d5, true, "ns8|NS8|cybersecurity|fraud prevention|ns8|online protection|risk management|security|website security"},
{0xf3d6, true, "nutritionix|app|calories|database|diet|fitness|food|health|nutrition|nutritionix|tracking"},
{0xe879, true, "obsidian"},
{0xe082, true, "octopus deploy|automation|cd|ci|cloud deployment|continuous delivery|continuous integration|deploy|deployment|devops|octopus|octopus deploy|release management|software release"},
{0xf263, true, "odnoklassniki|odnoklassniki|odnoklassniki.ru|ok|ok.ru|russian social network|social media|social network"},
{0xe5c6, true, "odysee|blockchain video|content sharing|decentralized video|odysee|video hosting|video platform"},
{0xf510, true, "old republic|galactic republic|jedi|old republic|republic|sith|star wars|star wars the old republic|swtor"},
{0xe7cf, true, "openai|ai|ai research|artificial intelligence|chatgpt|dall-e|gpt|language model|machine learning|open ai|openai"},
{0xf23d, true, "opencart|cart|ecommerce|marketplace|online store|open source|opencart|retail|shopping|shopping cart|web store"},
{0xf19b, true, "openid|authentication|identity|login|open id|openid|sign in|single sign-on|sso"},
{0xe86b, true, "openstreetmap"},
{0xe62b, true, "opensuse|green chameleon|linux|linux distribution|linux distro|openSUSE|opensource|opensuse|operating system|suse"},
{0xf26a, true, "opera|browser|browsing|fast browser|internet|opera|opera browser|secure browser|web|web browser"},
{0xf23c, true, "optin monster|conversion optimization|email marketing|lead generation|marketing tool|optin monster|optinmonster|popup builder"},
{0xf8d2, true, "orcid|academic id|orcid|research profile|researcher|researcher id|researcher identifier|scholarly id"},
{0xf41a, true, "osi|communication|layers|network model|networking|open systems interconnection|osi|protocol"},
{0xe4a0, true, "padlet|classroom tool|digital board|education|note sharing|online collaboration|padlet|virtual bulletin"},
{0xf3d7, true, "page4|brand|logo|p4|page 4|page4|pagefour"},
{0xf18c, true, "pagelines|eco|environment|green|leaf|leaves|nature|organic|pagelines|plant|sustainable|tree"},
{0xf3d8, true, "palfed|palestine|palestine federation|palestinian|palestinian federation|palfed"},
{0xe7da, true, "pandora|audio|brand|entertainment|internet radio|music|pandora|pandora radio|streaming"},
{0xf3d9, true, "patreon|content creator|creator|crowdfunding|donations|fan funding|membership|patreon|patron|subscription|support"},
{0xf1ed, true, "paypal|checkout|digital wallet|ecommerce|finance|merchant|money transfer|online payment|pay|payment|payments|paypal|transaction"},
{0xe083, true, "perbyte|digital|perbyte|perbyte brand|perbyte logo|software|technology"},
{0xf3da, true, "periscope|app|broadcast|camera|live streaming|live video|mobile app|periscope|social media|streaming|video"},
{0xf3db, true, "phabricator|code review|collaboration|development|open source|phabricator|project management|repository|software|version control"},
{0xf3dc, true, "phoenix framework|backend|development|elixir|open source|phoenix|phoenix framework|programming|server|software|web framework"},
{0xf511, true, "phoenix squadron|phoenix|phoenix squadron|pilot|rebellion|resistance|sci-fi|space battle|squadron|star wars|starfighter"},
{0xf457, true, "php|php|php code|php developer|php framework|php language|php logo|php programming|php script"},
{0xf2ae, true, "pied piper|brand|fable|flute|legend|music|pied piper|piper|story"},
{0xf1a8, true, "pied piper alt|alt|brand|company|logo|pied piper|pied-piper|piper|software|startup|technology"},
{0xf4e5, true, "pied piper hat|clothing|costume|folklore|hat|jester|mascot|medieval|pied piper"},
{0xf1a7, true, "pied piper pp|brand|logo|pied piper|pied-piper|piper|software|startup|technology"},
{0xf0d2, true, "pinterest|boards|ideas|image sharing|inspiration|pin|pins|pinterest|social media|social network|visual discovery"},
{0xf231, true, "pinterest p|boards|ideas|image sharing|inspiration|pin|pinterest|social media|visual discovery"},
{0xe43a, true, "pix|free images|images|media|photo sharing|photography|photos|pictures|pix|pixabay|stock photos"},
{0xe7db, true, "pixelfed|decentralized|fediverse|image hosting|open source|photo sharing|pixel fed|pixelfed|social media|social network"},
{0xe640, true, "pixiv|anime|art sharing|creative community|digital art platform|illustration site|japanese art community|manga|pixiv|pixiv logo"},
{0xf3df, true, "playstation|console|controller|entertainment|game system|gaming|playstation|ps|sony|video game|videogame"},
{0xe858, true, "postgresql"},
{0xf288, true, "product hunt|app discovery|community|innovation|launch|new apps|ph|product hunt|products|startup|tech"},
{0xf3e1, true, "pushed|action|button|click|interaction|press|push|pushed"},
{0xf3e2, true, "python|coding|development|programming|python|python brand|python language|python logo|python programming|scripting|software"},
{0xf1d6, true, "qq|chat|chinese messenger|communication|instant messaging|qq|social media|tencent"},
{0xf459, true, "quinscape|quinscape|quinscape brand|quinscape company|quinscape icon|quinscape logo"},
{0xf2c4, true, "quora|answers|community|discussion|forum|knowledge|q&a|questions|quora|social network"},
{0xf4f7, true, "r project|R|R language|R programming|R software|R-project|data analysis|data science|programming language|statistical computing"},
{0xf7bb, true, "raspberry pi|SBC|diy|electronics|maker|pi|raspberry pi|raspberry pi foundation|raspberry-pi|raspberrypi|single board computer"},
{0xf2d9, true, "ravelry|crafts|crochet|fiber arts|knitting|patterns|ravelry|yarn"},
{0xf41b, true, "react|component|facebook|framework|frontend|javascript|jsx|library|react|reactjs|ui|web app|web development"},
{0xf75d, true, "reacteurope|developer event|frontend|javascript|programming|react conference|react europe|reactjs|tech conference|web development"},
{0xf4d5, true, "readme|documentation|guide|help|info|information|instructions|manual|readme|tutorial"},
{0xf1d0, true, "rebel|alliance|fighter|freedom|insurgent|rebel|rebellion|resistance|sci-fi|star wars|symbol"},
{0xf3e3, true, "red river|environment|nature|outdoors|red river|redriver|river|water"},
{0xf1a1, true, "reddit|community|discussion|forum|karma|meme|online community|reddit|reddit logo|social media|social network|subreddit|upvote"},
{0xf281, true, "reddit alien|alien|community|forum|mascot|reddit|snoo|social media|subreddit|upvote"},
{0xf7bc, true, "redhat|enterprise linux|linux|open source|operating system|os|red hat|redhat|rhel|software"},
{0xf18b, true, "renren|chinese social media|renren|renren brand|renren network|social network|social platform"},
{0xf3e6, true, "replyd|Replyd|brand|communication|messaging|replyd|social"},
{0xf4f8, true, "researchgate|RG|academic|collaboration|network|publications|research|researchers|researchgate|scholarly|scientists"},
{0xf3e7, true, "resolving|brand|company|corporate|logo|resolving|resolving icon"},
{0xf5b2, true, "rev|audio|captions|dictation|rev|rev.com|speech to text|subtitles|transcription|transcription service|video"},
{0xf3e8, true, "rocketchat|chat|chat app|chat platform|chat service|collaboration|communication|messaging|rocket chat|rocketchat|team chat"},
{0xf3e9, true, "rockrms|church administration|church management|church software|donation tracking|event management|membership management|nonprofit software|rock church|rock rms|rockrms"},
{0xe07a, true, "rust|coding|developer|fast|programming language|rust|rust language|rust programming|safe|software|systems programming"},
{0xf267, true, "safari|apple|browser|internet|ios|mac|safari|web"},
{0xf83b, true, "salesforce|business|cloud|crm|customer relationship management|enterprise|marketing|saas|sales|sales force|salesforce"},
{0xf41e, true, "sass|css preprocessor|frontend|sass|sass brand|sass logo|sass-lang|style language|stylesheet|web development"},
{0xe859, true, "scaleway"},
{0xf3ea, true, "schlix|blogging|cms|content management|schlix|schlix cms|website"},
{0xe570, true, "screenpal|Recording software|Screen capture tool|Screen recording|Screen sharing|Screen video|ScreenPal|Screencast|Screencastify|Video capture|Video tutorial"},
{0xf28a, true, "scribd|audiobooks|digital library|documents|ebooks|literature|online books|publishing|reading|scribd|subscription"},
{0xf3eb, true, "searchengin|SEO|analytics|digital marketing|marketing|online marketing|search|search engine|searchengin|web search"},
{0xf2da, true, "sellcast|broadcast|media|sell cast|sellcast|streaming|video"},
{0xf213, true, "sellsy|CRM|SaaS|Sellsy|billing|business management|invoicing|sales|software"},
{0xf3ec, true, "servicestack|.net|api framework|backend|cloud services|dotnet|microservices|service stack|servicestack|software development|web services"},
{0xf214, true, "shirtsinbulk|apparel supplier|bulk apparel|bulk clothing|bulk orders|bulk t-shirts|clothing wholesale|shirts in bulk|shirtsinbulk|wholesale fashion|wholesale shirts"},
{0xe60c, true, "shoelace|boot|footwear|lace|shoelace|shoelaces|shoes|sneaker|string|tie"},
{0xe057, true, "shopify|ecommerce|marketplace|online shop|online store|retail|sales|shopify|shopping"},
{0xf5b5, true, "shopware|e-commerce|ecommerce software|online shop|online store|retail software|shopping platform|shopware|webshop"},
{0xe663, true, "signal messenger|app|calls|chat|communication|encrypted|messaging|messenger|private|secure|signal|text"},
{0xf215, true, "simplybuilt|building company|construction|home builder|housing|real estate|simply built|simplybuilt"},
{0xf3ee, true, "sistrix|analytics|digital marketing|marketing|search engine optimization|seo|seo software|seo tool|sistrix|website analysis"},
{0xf512, true, "sith|dark lord|dark side|darth|force user|sith|star wars|star wars villain|starwars|villain"},
{0xe44a, true, "sitrox|Sitrox|Sitrox brand|Sitrox company|Sitrox logo|Sitrox technology|sitrox"},
{0xf7c6, true, "sketch|app|design|illustration|mac|macos|prototyping|sketch|software|ui|ux|vector"},
{0xf216, true, "skyatlas|astronomy|atlas|celestial|constellation|map|navigation|sky atlas|skyatlas|space|star chart"},
{0xf17e, true, "skype|calling|chat|communication|conference|messaging|microsoft|online meeting|skype|video call|voip"},
{0xf198, true, "slack|chat|collaboration|communication|hashtag|messaging|slack|team|workspace"},
{0xf1e7, true, "slideshare|content sharing|document sharing|presentation|professional presentations|slide deck|slide hosting|slide share|slideshare|slideshow"},
{0xf2ab, true, "snapchat|app|chat|filters|ghost|messaging|snap|snapchat|snaps|social media|stories"},
{0xe85e, true, "solana"},
{0xf1be, true, "soundcloud|audio|music|online music|platform|podcast|social audio|songs|soundcloud|streaming|tracks"},
{0xf7d3, true, "sourcetree|atlassian|code management|git|git client|repository|scm|software development|source code|sourcetree|version control"},
{0xe5ac, true, "space awesome|adventure|astronautics|exploration|launch|rocket|shuttle|space|spaceship"},
{0xf3f3, true, "speakap|corporate social network|employee app|internal communication|speakap|team collaboration|workplace chat"},
{0xf83c, true, "speaker deck|conferences|presentations|presentations platform|sharing|slide deck|slides|speakerdeck|talks"},
{0xf1bc, true, "spotify|album|artist|audio|music|playlist|podcast|songs|sound|spotify|streaming"},
{0xf1b5, true, "square behance|adobe behance|art|behance|creative|design|portfolio|projects|showcase"},
{0xe6a3, true, "square bluesky|app|bluesky|decentralized|platform|social media|social network"},
{0xe844, true, "square deskpro"},
{0xf397, true, "square dribbble|art|branding|community|creative|design|designer|dribbble|dribble|portfolio|social"},
{0xf082, true, "square facebook|facebook|facebook app|facebook logo|fb|fb icon|social media|social network|social platform"},
{0xe7e4, true, "square figma|app|collaboration|design|figma|interface|prototyping|software|ui|ux|vector"},
{0xe5ad, true, "square font awesome|brand|fa|font awesome|fontawesome|icon set|logo"},
{0xf35c, true, "square font awesome stroke|brand|fa|font-awesome|icon|logo|square|typeface"},
{0xf1d2, true, "square git|code|development|git|git square|repository|software|source control|version control"},
{0xf092, true, "square github|code|development|git|github|octocat|programming|repository|software|version control"},
{0xe5ae, true, "square gitlab|ci|code|collaboration|continuous integration|devops|git|gitlab|repository|software|version control"},
{0xf0d4, true, "square google plus|google plus|google social|google+|gplus|social media|social network"},
{0xf3af, true, "square hacker news|community|developer|hacker news|hn|news|programming|social|startup|tech|technology"},
{0xe055, true, "square instagram|app|brand|camera|insta|instagram|photo|social media"},
{0xf3b9, true, "square js|api|developer|ecommerce|fintech|javascript|js|payments|programming|sdk|square"},
{0xf203, true, "square lastfm|audio|brand|last.fm|lastfm|media|music|social|streaming"},
{0xe62e, true, "square letterboxd|cinema|film|letterboxd|movie|movies|rating|reviews|social|streaming|watchlist"},
{0xe7d0, true, "square linkedin|business|linkedin|linkedin-logo|linkedin-square|network|professional network|social|social media"},
{0xf264, true, "square odnoklassniki|odnoklassniki|odnoklassniki.ru|ok|russian internet|russian social network|social media|social network"},
{0xe01e, true, "square pied piper|brand|pied piper|piedpiper|piper|software|startup|tech"},
{0xf0d3, true, "square pinterest|board|ideas|image sharing|inspiration|pin|pinterest|social media"},
{0xf1a2, true, "square reddit|community|discussion|forum|reddit|reddit logo|rslash|social media|subreddit|upvote"},
{0xf2ad, true, "square snapchat|app|chat|filter|ghost|messaging|snap|snapchat|snapcode|social|stories"},
{0xf1b7, true, "square steam|digital|distribution|games|gaming|online|pc|platform|steam|store|valve|video games"},
{0xe619, true, "square threads|meta|microblogging|online community|social media|social network|square threads|threads"},
{0xf174, true, "square tumblr|blog|blogging|microblog|platform|post|social|tmb|tumblr"},
{0xf081, true, "square twitter|bird|message|microblogging|post|social media|social network|tweet|tweetbird|twitter"},
{0xe67c, true, "square upwork|contract|freelance|freelancer|gig economy|jobs|marketplace|online work|remote work|upwork|work platform"},
{0xf2aa, true, "square viadeo|brand|business|networking|professional network|social network|viadeo"},
{0xf194, true, "square vimeo|brand|media|social|streaming|video|vimeo"},
{0xe683, true, "square web awesome|UI|awesome|coding|components|crown|front-end|programming|user interface|web|web development"},
{0xe684, true, "square web awesome stroke|awesome|coding|components|crown|design|developer|programming|software|web"},
{0xf40c, true, "square whatsapp|chat|communication|instant messaging|message|messaging|mobile app|social|whatsapp|whatsapp logo"},
{0xe61a, true, "square x twitter|elon musk|microblogging|social media|social network|tweet|twitter|x|x app"},
{0xf169, true, "square xing|business networking|careers|jobs|networking site|professional network|social network|xing|xing brand|xing logo"},
{0xf431, true, "square youtube|brand|media|play|social|square|streaming|video|youtube"},
{0xf5be, true, "squarespace|blogging|cms|content management|ecommerce|online store|sqsp|squarespace|web design|website builder|website hosting|website platform"},
{0xf18d, true, "stack exchange|Q&A|answers|community|developer|forum|knowledge sharing|programming|questions|stack exchange|stackexchange"},
{0xf16c, true, "stack overflow|Q&A|answers|coding|community|developer|forum|programming|questions|stack overflow|stackoverflow|tech"},
{0xf842, true, "stackpath|cdn|cloud security|cloud services|content delivery network|cybersecurity|edge computing|internet security|network services|stackpath|web performance"},
{0xf3f5, true, "staylinked|barcode scanning|enterprise mobility|linkin|mobile computing|staylinked|warehouse software"},
{0xf1b6, true, "steam|digital distribution|game launcher|games|gaming|online store|pc games|platform|steam|valve|video games"},
{0xf3f6, true, "steam symbol|PC games|digital distribution|game launcher|game store|gaming|online gaming|platform|steam|valve|video games"},
{0xf3f7, true, "sticker mule|Sticker Mule|branded stickers|custom labels|custom stickers|decal|label printing|printing service|promotional stickers|stickers"},
{0xf428, true, "strava|cycling|exercise|fitness|gps|running|sports|strava|tracking|training|workout"},
{0xf429, true, "stripe|billing|credit card|ecommerce|fintech|gateway|merchant|online payment|payment|payments|stripe|subscription"},
{0xf42a, true, "stripe s|billing|credit card|ecommerce|financial|fintech|online payments|payment|payments|stripe|subscription"},
{0xe5c7, true, "stubber|admission|coupon|event ticket|receipt|stub|stub ticket|stubber|ticket|voucher"},
{0xf3f8, true, "studiovinari|brand|company|logo|studio vinari|studiovinari|vinari"},
{0xf1a4, true, "stumbleupon|bookmarking|content|discovery|internet|network|sharing|social|stumble|stumbleupon|web"},
{0xf1a3, true, "stumbleupon circle|bookmark|discovery|network|sharing|social|stumble|stumbleupon|su"},
{0xf2dd, true, "superpowers|abilities|comic|fantasy|hero|powers|special abilities|strength|superhero|superhuman|superpowers"},
{0xf3f9, true, "supple|Supple|Supple brand|Supple company|Supple logo|supple"},
{0xe833, true, "supportnow|customer support|helpdesk|online support|support brand|support now|support platform|support service|supportnow|tech support"},
{0xf7d6, true, "suse|enterprise linux|linux|linux distribution|open source|operating system|os|sle|suse|suse linux"},
{0xe868, true, "svelte"},
{0xf8e1, true, "swift|app development|apple swift|code|developer|ios|macos|programming language|software|swift|swift programming"},
{0xf83d, true, "symfony|backend|mvc|open source|php|php framework|php library|symfony|symfony framework|web development"},
{0xe8ab, true, "symfonycasts"},
{0xe866, true, "tailwind css"},
{0xf4f9, true, "teamspeak|VoIP|chat app|communication|gaming voice|online gaming|teamspeak|ts|voice chat"},
{0xf2c6, true, "telegram|app|chat|communication|instant messaging|messaging|messenger app|mobile app|social media|telegram|telegram messenger"},
{0xf1d5, true, "tencent weibo|chinese social media|messaging|microblog|platform|social|tencent|weibo"},
{0xe7ff, true, "tex|document|formula|latex|markup|math|scientific|tex|typesetting"},
{0xf69d, true, "the red yeti|brand|content creator|esports|gaming|red yeti|streamer|the red|the red yeti|yeti"},
{0xf5c6, true, "themeco|brand|builder|creative|digital products|page builder|templates|theme|themeco|themes|web design|website|wordpress"},
{0xf2b2, true, "themeisle|theme isle|themeisle|website templates|website themes|wordpress|wordpress plugins|wordpress themes"},
{0xf731, true, "think peaks|analytics|business intelligence|charts|data|graphs|peaks|think peaks|thinkpeaks|visualization"},
{0xe618, true, "threads|chat|communication|conversation|messaging|meta|social media|social network|threads"},
{0xe85f, true, "threema"},
{0xe7dc, true, "tidal|album|artist|audio|hi-fi|music|playlist|songs|streaming|tidal"},
{0xe07b, true, "tiktok|app|dance|lip sync|music|short video|social media|tik tok|tiktok|trends|video|viral"},
{0xe838, true, "tor browser|anonymity|anonymous browsing|censorship circumvention|dark web|internet privacy|onion|privacy|secure browsing|tor|tor browser"},
{0xf513, true, "trade federation|clone wars|federation|galactic|sci-fi|separatists|space|star wars|star wars logo|starship|trade federation"},
{0xf181, true, "trello|atlassian|boards|collaboration|kanban|productivity|project management|task management|trello|workflow"},
{0xf173, true, "tumblr|blogging|microblogging|social media|social network|tmb|tumblr|tumblr logo"},
{0xf1e8, true, "twitch|broadcast|chat|esports|gaming|live|platform|streamer|streaming|twitch|twitch.tv|video game"},
{0xf099, true, "twitter|bird|microblogging|social media|social network|tweet|tweets|twitter|x platform"},
{0xe840, true, "typescript"},
{0xf42b, true, "typo3|cms|content management|content management system|open source|php|typo|typo3|web development"},
{0xf402, true, "uber|Uber|app|car service|driver|mobility|ride|rideshare|taxi|transportation|travel"},
{0xf7df, true, "ubuntu|canonical|distro|linux|linux distribution|open source|operating system|os|ubuntu"},
{0xf403, true, "uikit|components|design system|framework|frontend|toolkit|ui kit|uikit|user interface|web development"},
{0xe86d, true, "ultralytics"},
{0xe86e, true, "ultralytics hub"},
{0xe86f, true, "ultralytics yolo"},
{0xf8e8, true, "umbraco|.net|cms|content management|dotnet|open source|platform|umbraco|web development|website"},
{0xe084, true, "uncharted|action game|adventure game|naughty dog|playstation|ps4|ps5|treasure hunt|uncharted|uncharted game|uncharted series"},
{0xf404, true, "uniregistry|domain marketplace|domain name|domain registrar|domain registration|uniregistry|web domains"},
{0xe854, true, "unison"},
{0xe049, true, "unity|3d|cross-platform|developer|game development|game engine|gaming|interactive|real-time|unity|unity3d"},
{0xe85c, true, "unreal engine"},
{0xe07c, true, "unsplash|free images|images|photo platform|photo sharing|photography|photos|pictures|stock photos|unsplash"},
{0xf405, true, "untappd|app|beer|beer lover|brewery|check-in|craft beer|drinks|rating|social|untappd"},
{0xf7e0, true, "ups|UPS|United Parcel Service|courier|delivery|freight|logistics|package|parcel|shipping"},
{0xe641, true, "upwork|contract work|freelance|freelancer|freelancing platform|gig economy|online jobs|remote work|upwork|work marketplace"},
{0xf287, true, "usb|connector|data transfer|external drive|flash drive|memory stick|port|storage|thumb drive|universal serial bus|usb"},
{0xf7e1, true, "usps|American|USA|USPS|United States Postal Service|delivery|mail|package|postal|shipping"},
{0xf407, true, "ussunnah|brand|islamic|muslim|sunnah|us sunnah|ussunnah"},
{0xf408, true, "vaadin|frontend framework|java web framework|open source|ui toolkit|vaadin|vaadin framework|web components"},
{0xe85a, true, "venmo"},
{0xe85b, true, "venmo v"},
{0xf237, true, "viacoin|altcoin|blockchain|crypto|cryptocurrency|digital currency|viacoin|vtc"},
{0xf2a9, true, "viadeo|business networking|career|jobs|professional network|professional profile|social network|viadeo"},
{0xf409, true, "viber|calls|chat|communication|instant message|messaging|mobile app|text|viber|viber messenger|voip"},
{0xe88a, true, "vim"},
{0xf40a, true, "vimeo|film|media|movies|online video|streaming|video|video platform|videos|vimeo"},
{0xf27d, true, "vimeo v|platform|social media|streaming|video|vimeo|vimeo logo"},
{0xf1ca, true, "vine|app|brand|looping video|platform|short video|six seconds|social media|video|vine|vineapp"},
{0xf189, true, "vk|chat|community|messaging|network|russian|social|social media|vk|vkontakte"},
{0xf40b, true, "vnv|vnv|vnv brand|vnv logo|vnv network"},
{0xe7dd, true, "vsco|image editing|photo editor|photo filter|photo sharing|photography|social media|vsco|vsco app"},
{0xf41f, true, "vuejs|MVVM|SPA|UI|framework|frontend|javascript|js|progressive framework|vue|vue.js|web development"},
{0xe7de, true, "w3c|internet standards|w3c|web accessibility|web design|web development|web standards|web technologies|world wide web consortium"},
{0xe087, true, "watchman monitoring|IT monitoring|brand|monitoring|network monitoring|server monitoring|system monitoring|watchman|watchman monitoring"},
{0xf83f, true, "waze|commute|directions|driving|gps|maps|navigation|route|traffic|travel|waze"},
{0xe682, true, "web awesome|award|awesome|badge|coding|components|crown|developer|frontend|programming|web"},
{0xe65c, true, "webflow|no-code|web design|web development|web platform|webflow|webflow logo|website builder"},
{0xf5cc, true, "weebly|drag and drop|ecommerce|online store|site builder|small business|web design|web hosting|website builder|website platform|weebly"},
{0xf18a, true, "weibo|chinese social media|microblog|sina weibo|social media|social network|weibo|weibo logo"},
{0xf1d7, true, "weixin|chat|chinese messenger|instant messaging|messaging|mobile app|social media|wechat|weixin|weixin app"},
{0xf232, true, "whatsapp|call|chat|communication|instant message|messaging|mobile chat|social media|text|video call|voice call|whatsapp|whatsapp messenger"},
{0xf40d, true, "whmcs|automation|billing|client management|hosting automation|hosting control panel|web hosting|web services|whmcs"},
{0xf266, true, "wikipedia w|encyclopedia|information|knowledge|online encyclopedia|reference|wiki|wiki logo|wikipedia"},
{0xf17a, true, "windows|desktop|laptop|microsoft|microsoft windows|operating system|os|pc|software|windows"},
{0xe2d0, true, "wirsindhandwerk|artisan|craftsman|german craftsmanship|handwerk|skilled worker|trade|wir sind handwerk"},
{0xf5cf, true, "wix|online platform|site builder|web design|web hosting|website builder|website platform|wix|wix.com"},
{0xf730, true, "wizards of the coast|Dungeons & Dragons|Wizards of the Coast|collectible card game|d&d|dnd|fantasy|gaming|magic the gathering|mtg|role-playing game|rpg|tabletop"},
{0xe088, true, "wodu|Wodu|Wodu app|Wodu brand|Wodu logo|Wodu platform|Wodu service"},
{0xf514, true, "wolf pack battalion|battalion|group|military unit|pack|squad|tactical|team|unit|wolf|wolf pack"},
{0xf19a, true, "wordpress|blog|blogging platform|cms|content management|open source|php|publishing|website|wordpress|wp"},
{0xf411, true, "wordpress simple|blog|cms|content management|platform|publishing|website|wordpress|wp"},
{0xf297, true, "wpbeginner|wordpress beginner|wordpress guide|wordpress help|wordpress learning|wordpress tips|wordpress tutorial|wpbeginner"},
{0xf2de, true, "wpexplorer|blog|tech blog|tutorials|web development|website|wordpress|wp explorer|wpexplorer"},
{0xf298, true, "wpforms|contact form|form builder|form creation|form plugin|form software|form tool|online forms|wordpress forms|wordpress plugin|wpforms"},
{0xf3e4, true, "wpressr|blogging|cms|content management|website|wordpress|wpressr"},
{0xe61b, true, "x twitter|blue bird|microblogging|social|social media|social network|tweet|tweets|twitter|x"},
{0xf412, true, "xbox|microsoft xbox|xbox|xbox brand|xbox console|xbox controller|xbox game|xbox gaming|xbox series"},
{0xf168, true, "xing|business networking|career|jobs|networking site|professional network|professional profile|social network|xing|xing logo"},
{0xe864, true, "xmpp"},
{0xf23b, true, "y combinator|accelerator|entrepreneurship|seed funding|startup|tech incubator|venture capital|y combinator|yc"},
{0xf19e, true, "yahoo|internet company|verizon|yahoo|yahoo brand|yahoo finance|yahoo logo|yahoo mail|yahoo messenger|yahoo search|yahoo sports"},
{0xf840, true, "yammer|collaboration tool|corporate messaging|enterprise social network|microsoft 365|microsoft yammer|office 365|team communication|workplace chat|yammer"},
{0xf413, true, "yandex|internet|russian search engine|search|technology|web|yandex|yandex browser|yandex mail|yandex maps|yandex taxi"},
{0xf414, true, "yandex international|internet|russian tech|search engine|technology|web|yandex|yandex international|yandex logo"},
{0xf7e3, true, "yarn|craft|crochet|fabric|fiber|knitting|sewing|textile|thread|wool|yarn"},
{0xf1e9, true, "yelp|business|food|local|places|ratings|recommendations|restaurant|reviews|services|yelp"},
{0xf2b1, true, "yoast|content optimization|plugin|search engine optimization|seo|seo tool|website ranking|wordpress|yoast|yoast seo"},
{0xf167, true, "youtube|broadcast|channel|media|online video|play|streaming|video|video platform|vlog|youtube"},
{0xf63f, true, "zhihu|answers|chinese q&a|community|knowledge sharing|question|social network|zhihu|知乎"},
{0xe87b, true, "zoom"},
{0xe853, true, "zulip"}
};
